@@ -224,7 +224,6 @@ public class ConfigurationTest {
 
         ConfigurationResponse response = client.configure(data);
 
-        System.out.println("status: " + response.getStatus());
         System.out.println("adminCert: " + response.getAdminCert().getCert());
         List<SystemCertData> certs = response.getSystemCerts();
         Iterator<SystemCertData> iterator = certs.iterator();
@@ -258,22 +257,6 @@ public class ConfigurationTest {
         data.setRemoveData("true");
         data.setSecureConn("false");
 
-        data.setBackupKeys("true");
-        data.setBackupFile("/tmp/testca.p12");
-        data.setBackupPassword("redhat123");
-
-        data.setAdminEmail("alee@redhat.com");
-        data.setAdminName("admin");
-        data.setAdminPassword("redhat123");
-        data.setAdminProfileID("caAdminCert");
-        data.setAdminUID("admin");
-        String subjectdn = "CN=CA Administrator of Instance testca, UID=admin, E=alee@redhat.com, o=testca2";
-        data.setAdminSubjectDN(subjectdn);
-
-        String crmf_request = generateCRMFRequest(token, "2048", subjectdn, false);
-        data.setAdminCertRequest(crmf_request);
-        data.setAdminCertRequestType("crmf");
-
         // create system certs
         List<SystemCertData> systemCerts = new ArrayList<SystemCertData>();
         SystemCertData cert1 = new SystemCertData();
@@ -360,22 +343,6 @@ public class ConfigurationTest {
         data.setRemoveData("true");
         data.setSecureConn("false");
 
-        data.setBackupKeys("true");
-        data.setBackupFile("/tmp/testsubca.p12");
-        data.setBackupPassword("redhat123");
-
-        data.setAdminEmail("alee@redhat.com");
-        data.setAdminName("admin");
-        data.setAdminPassword("redhat123");
-        data.setAdminProfileID("caAdminCert");
-        data.setAdminUID("admin");
-        String subjectdn = "CN=CA Administrator of Instance testsubca, UID=admin, E=alee@redhat.com, o=testsubca";
-        data.setAdminSubjectDN(subjectdn);
-
-        String crmf_request = generateCRMFRequest(token, "2048", subjectdn, false);
-        data.setAdminCertRequest(crmf_request);
-        data.setAdminCertRequestType("crmf");
-
         data.setIssuingCA("https://" + host + ":9224");
 
         // create system certs
@@ -462,22 +429,6 @@ public class ConfigurationTest {
         data.setRemoveData("true");
         data.setSecureConn("false");
 
-        data.setBackupKeys("true");
-        data.setBackupFile("/tmp/testexternalca.p12");
-        data.setBackupPassword("redhat123");
-
-        data.setAdminEmail("alee@redhat.com");
-        data.setAdminName("admin");
-        data.setAdminPassword("redhat123");
-        data.setAdminProfileID("caAdminCert");
-        data.setAdminUID("admin");
-        String subjectdn = "CN=CA Administrator of Instance testexternalca, UID=admin, E=alee@redhat.com, o=testexternalca";
-        data.setAdminSubjectDN(subjectdn);
-
-        String crmf_request = generateCRMFRequest(token, "2048", subjectdn, false);
-        data.setAdminCertRequest(crmf_request);
-        data.setAdminCertRequestType("crmf");
-
         data.setIssuingCA("External CA");
 
         // create system certs
@@ -564,22 +515,6 @@ public class ConfigurationTest {
         data.setRemoveData("true");
         data.setSecureConn("false");
 
-        data.setBackupKeys("true");
-        data.setBackupFile("/tmp/testexternalca.p12");
-        data.setBackupPassword("redhat123");
-
-        data.setAdminEmail("alee@redhat.com");
-        data.setAdminName("admin");
-        data.setAdminPassword("redhat123");
-        data.setAdminProfileID("caAdminCert");
-        data.setAdminUID("admin");
-        String subjectdn = "CN=CA Administrator of Instance testexternalca, UID=admin, E=alee@redhat.com, o=testexternalca";
-        data.setAdminSubjectDN(subjectdn);
-
-        String crmf_request = generateCRMFRequest(token, "2048", subjectdn, false);
-        data.setAdminCertRequest(crmf_request);
-        data.setAdminCertRequestType("crmf");
-
         data.setIssuingCA("External CA");
 
         // create system certs
@@ -679,8 +614,6 @@ public class ConfigurationTest {
         data.setRemoveData("true");
         data.setSecureConn("false");
 
-        data.setBackupKeys("false");
-
         // create system certs
         List<SystemCertData> systemCerts = new ArrayList<SystemCertData>();
         SystemCertData cert3 = new SystemCertData();
@@ -722,22 +655,6 @@ public class ConfigurationTest {
         data.setRemoveData("true");
         data.setSecureConn("false");
 
-        data.setBackupKeys("true");
-        data.setBackupFile("/tmp/testkra.p12");
-        data.setBackupPassword("redhat123");
-
-        data.setAdminEmail("alee@redhat.com");
-        data.setAdminName("admin");
-        data.setAdminPassword("redhat123");
-        data.setAdminProfileID("caAdminCert");
-        data.setAdminUID("admin");
-        String subjectdn = "CN=KRA Administrator of Instance testkra, UID=admin, E=alee@redhat.com, o=testkra22";
-        data.setAdminSubjectDN(subjectdn);
-
-        String crmf_request = generateCRMFRequest(token, "2048", subjectdn, false);
-        data.setAdminCertRequest(crmf_request);
-        data.setAdminCertRequestType("crmf");
-
         data.setIssuingCA("https://" + host + ":9224");
 
         // create system certs
@@ -825,22 +742,6 @@ public class ConfigurationTest {
         data.setRemoveData("true");
         data.setSecureConn("false");
 
-        data.setBackupKeys("true");
-        data.setBackupFile("/tmp/testocsp.p12");
-        data.setBackupPassword("redhat123");
-
-        data.setAdminEmail("alee@redhat.com");
-        data.setAdminName("admin");
-        data.setAdminPassword("redhat123");
-        data.setAdminProfileID("caAdminCert");
-        data.setAdminUID("admin");
-        String subjectdn = "CN=OCSP Administrator of Instance testocsp, UID=admin, E=alee@redhat.com, o=testocsp22";
-        data.setAdminSubjectDN(subjectdn);
-
-        String crmf_request = generateCRMFRequest(token, "2048", subjectdn, false);
-        data.setAdminCertRequest(crmf_request);
-        data.setAdminCertRequestType("crmf");
-
         data.setIssuingCA("https://" + host + ":9224");
 
         // create system certs
@@ -917,22 +818,6 @@ public class ConfigurationTest {
         data.setRemoveData("true");
         data.setSecureConn("false");
 
-        data.setBackupKeys("true");
-        data.setBackupFile("/tmp/testtks.p12");
-        data.setBackupPassword("redhat123");
-
-        data.setAdminEmail("alee@redhat.com");
-        data.setAdminName("admin");
-        data.setAdminPassword("redhat123");
-        data.setAdminProfileID("caAdminCert");
-        data.setAdminUID("admin");
-        String subjectdn = "CN=TKS Administrator of Instance testtks, UID=admin, E=alee@redhat.com, o=testtks22";
-        data.setAdminSubjectDN(subjectdn);
-
-        String crmf_request = generateCRMFRequest(token, "2048", subjectdn, false);
-        data.setAdminCertRequest(crmf_request);
-        data.setAdminCertRequestType("crmf");
-
         data.setIssuingCA("https://" + host + ":9224");
 
         // create system certs
