@@ -1,6 +1,6 @@
 # Authors:
 #     Endi S. Dewata <edewata@redhat.com>
-#     Dinesh Prasnath M K <dmoluguw@redhat.com>
+#     Dinesh Prasanth M K <dmoluguw@redhat.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the Lesser GNU General Public License as published by
@@ -42,8 +42,11 @@ except ImportError:
 
 import pki
 
-CSR_HEADER = '-----BEGIN NEW CERTIFICATE REQUEST-----'
-CSR_FOOTER = '-----END NEW CERTIFICATE REQUEST-----'
+CSR_HEADER = '-----BEGIN CERTIFICATE REQUEST-----'
+CSR_FOOTER = '-----END CERTIFICATE REQUEST-----'
+
+LEGACY_CSR_HEADER = '-----BEGIN NEW CERTIFICATE REQUEST-----'
+LEGACY_CSR_FOOTER = '-----END NEW CERTIFICATE REQUEST-----'
 
 CERT_HEADER = '-----BEGIN CERTIFICATE-----'
 CERT_FOOTER = '-----END CERTIFICATE-----'
@@ -59,10 +62,18 @@ logger = logging.LoggerAdapter(
     extra={'indent': ''})
 
 
-def convert_data(data, input_format, output_format, header=None, footer=None):
+def convert_data(data, input_format, output_format,
+                 header=None, footer=None,
+                 headers=None, footers=None):
+    '''
+    This method converts a PEM file to base-64 and vice versa.
+    It supports CSR, certificate, and PKCS #7 certificate chain.
+    '''
+
     if input_format == output_format:
         return data
 
+    # converting from base-64 to PEM
     if input_format == 'base64' and output_format == 'pem':
 
         # join base-64 data into a single line
@@ -74,16 +85,30 @@ def convert_data(data, input_format, output_format, header=None, footer=None):
         # add header and footer
         return '%s\n%s\n%s\n' % (header, '\n'.join(lines), footer)
 
+    # converting from PEM to base-64
     if input_format == 'pem' and output_format == 'base64':
 
+        # initialize list of headers if not provided
+        if not headers:
+            headers = [header]
+
+        # initialize list of footers if not provided
+        if not footers:
+            footers = [footer]
+
         # join multiple lines into a single line
         lines = []
         for line in data.splitlines():
             line = line.rstrip('\r\n')
-            if line == header:
+
+            # if the line is a header, skip
+            if line in headers:
                 continue
-            if line == footer:
+
+            # if the line is a footer, skip
+            if line in footers:
                 continue
+
             lines.append(line)
 
         return ''.join(lines)
@@ -94,7 +119,9 @@ def convert_data(data, input_format, output_format, header=None, footer=None):
 
 def convert_csr(csr_data, input_format, output_format):
     return convert_data(csr_data, input_format, output_format,
-                        CSR_HEADER, CSR_FOOTER)
+                        CSR_HEADER, CSR_FOOTER,
+                        headers=[CSR_HEADER, LEGACY_CSR_HEADER],
+                        footers=[CSR_FOOTER, LEGACY_CSR_FOOTER])
 
 
 def convert_cert(cert_data, input_format, output_format):
@@ -108,10 +135,15 @@ def convert_pkcs7(pkcs7_data, input_format, output_format):
 
 
 def get_file_type(filename):
+    '''
+    This method detects the content of a PEM file. It supports
+    CSR, certificate, PKCS #7 certificate chain.
+    '''
+
     with open(filename, 'r') as f:
         data = f.read()
 
-    if data.startswith(CSR_HEADER):
+    if data.startswith(CSR_HEADER) or data.startswith(LEGACY_CSR_HEADER):
         return 'csr'
 
     if data.startswith(CERT_HEADER):
@@ -274,7 +306,7 @@ class NSSDatabase(object):
             '-@', self.password_file
         ]
 
-        logger.debug('Command: %s', ' '.join(cmd))
+        logger.debug('Command: %s', ' '.join(map(str, cmd)))
         subprocess.check_call(cmd)
 
         migration = (
@@ -329,11 +361,12 @@ class NSSDatabase(object):
                     '-P', token,
                     '-f', password_file,
                     '-n', nickname,
+                    '-a',
                     '-i', cert_file,
                     '-t', ''
                 ]
 
-                logger.debug('Command: %s', ' '.join(cmd))
+                logger.debug('Command: %s', ' '.join(map(str, cmd)))
                 rc = subprocess.call(cmd)
 
                 if rc:
@@ -351,11 +384,12 @@ class NSSDatabase(object):
                     '-d', self.directory,
                     '-f', self.internal_password_file,
                     '-n', nickname,
+                    '-a',
                     '-i', cert_file,
                     '-t', trust_attributes
                 ]
 
-                logger.debug('Command: %s', ' '.join(cmd))
+                logger.debug('Command: %s', ' '.join(map(str, cmd)))
                 subprocess.check_call(cmd)
 
         finally:
@@ -389,7 +423,7 @@ class NSSDatabase(object):
         if trust_attributes:
             cmd.extend(['--trust', trust_attributes])
 
-        logger.debug('Command: %s', ' '.join(cmd))
+        logger.debug('Command: %s', ' '.join(map(str, cmd)))
         subprocess.check_call(cmd)
 
     def modify_cert(self, nickname, trust_attributes):
@@ -408,7 +442,7 @@ class NSSDatabase(object):
             '-t', trust_attributes
         ])
 
-        logger.debug('Command: %s', ' '.join(cmd))
+        logger.debug('Command: %s', ' '.join(map(str, cmd)))
         subprocess.check_call(cmd)
 
     def create_noise(self, noise_file, size=2048):
@@ -419,7 +453,7 @@ class NSSDatabase(object):
             str(size)
         ]
 
-        logger.debug('Command: %s', ' '.join(cmd))
+        logger.debug('Command: %s', ' '.join(map(str, cmd)))
         subprocess.check_call(cmd)
 
     def create_request(
@@ -557,7 +591,7 @@ class NSSDatabase(object):
 
                 cmd.append(','.join(exts))
 
-            logger.debug('Command: %s', ' '.join(cmd))
+            logger.debug('Command: %s', ' '.join(map(str, cmd)))
 
             # generate binary request
             p = subprocess.Popen(cmd,
@@ -753,7 +787,7 @@ class NSSDatabase(object):
 
             keystroke += '\n'
 
-        logger.debug('Command: %s', ' '.join(cmd))
+        logger.debug('Command: %s', ' '.join(map(str, cmd)))
 
         p = subprocess.Popen(cmd,
                              stdin=subprocess.PIPE,
@@ -827,7 +861,7 @@ class NSSDatabase(object):
             '-d', self.directory
         ]
 
-        logger.debug('Command: %s', ' '.join(cmd))
+        logger.debug('Command: %s', ' '.join(map(str, cmd)))
         subprocess.check_call(cmd)
 
     def get_cert(self, nickname, token=None, output_format='pem',
@@ -870,7 +904,7 @@ class NSSDatabase(object):
             if output_format_option:
                 cmd.extend([output_format_option])
 
-            logger.debug('Command: %s', ' '.join(cmd))
+            logger.debug('Command: %s', ' '.join(map(str, cmd)))
 
             p = subprocess.Popen(cmd,
                                  stdout=subprocess.PIPE,
@@ -894,7 +928,7 @@ class NSSDatabase(object):
                 logger.warning('certutil returned non-zero exit code (bug #1539996)')
 
             if output_format == 'base64':
-                cert_data = base64.b64encode(cert_data)
+                cert_data = base64.b64encode(cert_data).decode('utf-8')
             if output_text and not isinstance(cert_data, six.string_types):
                 cert_data = cert_data.decode('ascii')
 
@@ -1006,7 +1040,7 @@ class NSSDatabase(object):
 
             cmd.extend([full_name])
 
-            logger.debug('Command: %s', ' '.join(cmd))
+            logger.debug('Command: %s', ' '.join(map(str, cmd)))
             subprocess.check_call(cmd)
 
         finally:
@@ -1040,7 +1074,7 @@ class NSSDatabase(object):
                 '-n', nickname
             ])
 
-            logger.debug('Command: %s', ' '.join(cmd))
+            logger.debug('Command: %s', ' '.join(map(str, cmd)))
             subprocess.check_call(cmd)
 
         finally:
@@ -1132,7 +1166,7 @@ class NSSDatabase(object):
                 '--output-suffix', suffix
             ]
 
-            logger.debug('Command: %s', ' '.join(cmd))
+            logger.debug('Command: %s', ' '.join(map(str, cmd)))
             subprocess.check_call(cmd)
 
             # Count the number of certs in the chain.
@@ -1211,7 +1245,7 @@ class NSSDatabase(object):
             if overwrite:
                 cmd.extend(['--overwrite'])
 
-            logger.debug('Command: %s', ' '.join(cmd))
+            logger.debug('Command: %s', ' '.join(map(str, cmd)))
             subprocess.check_call(cmd)
 
         finally:
@@ -1284,7 +1318,7 @@ class NSSDatabase(object):
             if nicknames:
                 cmd.extend(nicknames)
 
-            logger.debug('Command: %s', ' '.join(cmd))
+            logger.debug('Command: %s', ' '.join(map(str, cmd)))
             subprocess.check_call(cmd)
 
         finally:
