@@ -18,23 +18,12 @@
 package com.netscape.certsrv.apps;
 
 import java.math.BigInteger;
-import java.security.NoSuchAlgorithmException;
-import java.security.cert.Certificate;
-import java.security.cert.CertificateEncodingException;
-import java.security.cert.X509CRL;
 import java.security.cert.X509Certificate;
 import java.util.Date;
 import java.util.Enumeration;
 import java.util.Hashtable;
 import java.util.Locale;
-import java.util.Vector;
 
-import org.dogtagpki.legacy.policy.IGeneralNameAsConstraintsConfig;
-import org.dogtagpki.legacy.policy.IGeneralNamesAsConstraintsConfig;
-import org.dogtagpki.legacy.policy.IGeneralNamesConfig;
-import org.dogtagpki.legacy.policy.ISubjAltNameConfig;
-import org.mozilla.jss.CertificateUsage;
-import org.mozilla.jss.util.PasswordCallback;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -44,36 +33,18 @@ import com.netscape.certsrv.authority.IAuthority;
 import com.netscape.certsrv.authorization.IAuthzSubsystem;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IArgBlock;
-import com.netscape.certsrv.base.ICRLPrettyPrint;
-import com.netscape.certsrv.base.ICertPrettyPrint;
 import com.netscape.certsrv.base.IConfigStore;
-import com.netscape.certsrv.base.IExtPrettyPrint;
-import com.netscape.certsrv.base.IPrettyPrintFormat;
 import com.netscape.certsrv.base.ISecurityDomainSessionTable;
 import com.netscape.certsrv.base.ISubsystem;
-import com.netscape.certsrv.ca.ICRLIssuingPoint;
 import com.netscape.certsrv.ca.ICertificateAuthority;
-import com.netscape.certsrv.connector.IHttpConnection;
-import com.netscape.certsrv.connector.IPKIMessage;
 import com.netscape.certsrv.connector.IRemoteAuthority;
-import com.netscape.certsrv.connector.IRequestEncoder;
 import com.netscape.certsrv.connector.IResender;
 import com.netscape.certsrv.dbs.IDBSubsystem;
 import com.netscape.certsrv.dbs.crldb.ICRLIssuingPointRecord;
 import com.netscape.certsrv.dbs.repository.IRepositoryRecord;
 import com.netscape.certsrv.jobs.IJobsScheduler;
 import com.netscape.certsrv.kra.IKeyRecoveryAuthority;
-import com.netscape.certsrv.ldap.ELdapException;
-import com.netscape.certsrv.ldap.ILdapAuthInfo;
-import com.netscape.certsrv.ldap.ILdapConnFactory;
-import com.netscape.certsrv.ldap.ILdapConnInfo;
-import com.netscape.certsrv.logging.IAuditor;
 import com.netscape.certsrv.logging.ILogSubsystem;
-import com.netscape.certsrv.logging.ILogger;
-import com.netscape.certsrv.notification.IEmailFormProcessor;
-import com.netscape.certsrv.notification.IEmailResolver;
-import com.netscape.certsrv.notification.IEmailResolverKeys;
-import com.netscape.certsrv.notification.IEmailTemplate;
 import com.netscape.certsrv.notification.IMailNotification;
 import com.netscape.certsrv.ocsp.IOCSPAuthority;
 import com.netscape.certsrv.password.IPasswordCheck;
@@ -85,17 +56,11 @@ import com.netscape.certsrv.security.ICryptoSubsystem;
 import com.netscape.certsrv.selftests.ISelfTestSubsystem;
 import com.netscape.certsrv.tks.ITKSAuthority;
 import com.netscape.certsrv.usrgrp.IUGSubsystem;
-import com.netscape.cmsutil.net.ISocketFactory;
 import com.netscape.cmsutil.password.IPasswordStore;
 
 import netscape.ldap.LDAPConnection;
 import netscape.ldap.LDAPException;
 import netscape.ldap.LDAPSSLSocketFactoryExt;
-import netscape.ldap.LDAPSocketFactory;
-import netscape.security.util.ObjectIdentifier;
-import netscape.security.x509.Extension;
-import netscape.security.x509.GeneralName;
-import netscape.security.x509.X509CertInfo;
 
 /**
  * This represents the CMS server. Plugins can access other
@@ -244,28 +209,6 @@ public final class CMS {
         return _engine.isInRunningState();
     }
 
-    /**
-     * Returns the logger of the current server. The logger can
-     * be used to log critical informational or critical error
-     * messages.
-     *
-     * @return logger
-     */
-    public static ILogger getLogger() {
-        return _engine.getLogger();
-    }
-
-    /**
-     * Returns the auditor of the current server. The auditor can
-     * be used to audit critical informational or critical error
-     * messages.
-     *
-     * @return auditor
-     */
-    public static IAuditor getAuditor() {
-        return _engine.getAuditor();
-    }
-
     /**
      * Creates a repository record in the internal database.
      *
@@ -785,32 +728,6 @@ public final class CMS {
         return _engine.getStartupTime();
     }
 
-    /**
-     * Retrieves the HTTP Connection for use with connector.
-     *
-     * @param authority remote authority
-     * @param factory socket factory
-     * @return http connection to the remote authority
-     */
-    public static IHttpConnection getHttpConnection(IRemoteAuthority authority,
-            ISocketFactory factory) {
-        return _engine.getHttpConnection(authority, factory);
-    }
-
-    /**
-     * Retrieves the HTTP Connection for use with connector.
-     *
-     * @param authority remote authority
-     * @param factory socket factory
-     * @param timeout return error if connection cannot be established within
-     *            the timeout period
-     * @return http connection to the remote authority
-     */
-    public static IHttpConnection getHttpConnection(IRemoteAuthority authority,
-            ISocketFactory factory, int timeout) {
-        return _engine.getHttpConnection(authority, factory, timeout);
-    }
-
     /**
      * Retrieves the request sender for use with connector.
      *
@@ -980,317 +897,6 @@ public final class CMS {
         return _engine.getAdminPort();
     }
 
-    /**
-     * Creates a general name constraints.
-     *
-     * @param generalNameChoice type of general name
-     * @param value general name string
-     * @return general name object
-     * @exception EBaseException failed to create general name constraint
-     */
-    public static GeneralName form_GeneralNameAsConstraints(String generalNameChoice, String value)
-            throws EBaseException {
-        return _engine.form_GeneralName(generalNameChoice, value);
-    }
-
-    /**
-     * Creates a general name.
-     *
-     * @param generalNameChoice type of general name
-     * @param value general name string
-     * @return general name object
-     * @exception EBaseException failed to create general name
-     */
-    public static GeneralName form_GeneralName(String generalNameChoice,
-            String value) throws EBaseException {
-        return _engine.form_GeneralName(generalNameChoice, value);
-    }
-
-    /**
-     * Get default parameters for subject alt name configuration.
-     *
-     * @param name configuration name
-     * @param params configuration parameters
-     */
-    public static void getSubjAltNameConfigDefaultParams(String name,
-            Vector<String> params) {
-        _engine.getSubjAltNameConfigDefaultParams(name, params);
-    }
-
-    /**
-     * Get extended plugin info for subject alt name configuration.
-     *
-     * @param name configuration name
-     * @param params configuration parameters
-     */
-    public static void getSubjAltNameConfigExtendedPluginInfo(String name,
-            Vector<String> params) {
-        _engine.getSubjAltNameConfigExtendedPluginInfo(name, params);
-    }
-
-    /**
-     * Creates subject alt name configuration.
-     *
-     * @param name configuration name
-     * @param config configuration store
-     * @param isValueConfigured true if value is configured
-     * @exception EBaseException failed to create subject alt name configuration
-     */
-    public static ISubjAltNameConfig createSubjAltNameConfig(String name, IConfigStore config, boolean isValueConfigured)
-            throws EBaseException {
-        return _engine.createSubjAltNameConfig(
-                name, config, isValueConfigured);
-    }
-
-    /**
-     * Retrieves default general name configuration.
-     *
-     * @param name configuration name
-     * @param isValueConfigured true if value is configured
-     * @param params configuration parameters
-     */
-    public static void getGeneralNameConfigDefaultParams(String name,
-            boolean isValueConfigured, Vector<String> params) {
-        _engine.getGeneralNameConfigDefaultParams(name,
-                isValueConfigured, params);
-    }
-
-    /**
-     * Retrieves default general names configuration.
-     *
-     * @param name configuration name
-     * @param isValueConfigured true if value is configured
-     * @param params configuration parameters
-     */
-    public static void getGeneralNamesConfigDefaultParams(String name,
-            boolean isValueConfigured, Vector<String> params) {
-        _engine.getGeneralNamesConfigDefaultParams(name,
-                isValueConfigured, params);
-    }
-
-    /**
-     * Retrieves extended plugin info for general name configuration.
-     *
-     * @param name configuration name
-     * @param isValueConfigured true if value is configured
-     * @param info configuration parameters
-     */
-    public static void getGeneralNameConfigExtendedPluginInfo(String name,
-            boolean isValueConfigured, Vector<String> info) {
-        _engine.getGeneralNameConfigExtendedPluginInfo(name,
-                isValueConfigured, info);
-    }
-
-    /**
-     * Retrieves extended plugin info for general name configuration.
-     *
-     * @param name configuration name
-     * @param isValueConfigured true if value is configured
-     * @param info configuration parameters
-     */
-    public static void getGeneralNamesConfigExtendedPluginInfo(String name,
-            boolean isValueConfigured, Vector<String> info) {
-        _engine.getGeneralNamesConfigExtendedPluginInfo(name,
-                isValueConfigured, info);
-    }
-
-    /**
-     * Created general names configuration.
-     *
-     * @param name configuration name
-     * @param config configuration store
-     * @param isValueConfigured true if value is configured
-     * @param isPolicyEnabled true if policy is enabled
-     * @exception EBaseException failed to create subject alt name configuration
-     */
-    public static IGeneralNamesConfig createGeneralNamesConfig(String name,
-            IConfigStore config, boolean isValueConfigured,
-            boolean isPolicyEnabled) throws EBaseException {
-        return _engine.createGeneralNamesConfig(name, config, isValueConfigured,
-                isPolicyEnabled);
-    }
-
-    /**
-     * Created general name constraints configuration.
-     *
-     * @param name configuration name
-     * @param config configuration store
-     * @param isValueConfigured true if value is configured
-     * @param isPolicyEnabled true if policy is enabled
-     * @exception EBaseException failed to create subject alt name configuration
-     */
-    public static IGeneralNameAsConstraintsConfig createGeneralNameAsConstraintsConfig(String name,
-            IConfigStore config, boolean isValueConfigured,
-            boolean isPolicyEnabled) throws EBaseException {
-        return _engine.createGeneralNameAsConstraintsConfig(
-                name, config, isValueConfigured, isPolicyEnabled);
-    }
-
-    /**
-     * Created general name constraints configuration.
-     *
-     * @param name configuration name
-     * @param config configuration store
-     * @param isValueConfigured true if value is configured
-     * @param isPolicyEnabled true if policy is enabled
-     * @exception EBaseException failed to create subject alt name configuration
-     */
-    public static IGeneralNamesAsConstraintsConfig createGeneralNamesAsConstraintsConfig(String name,
-            IConfigStore config, boolean isValueConfigured,
-            boolean isPolicyEnabled) throws EBaseException {
-        return _engine.createGeneralNamesAsConstraintsConfig(
-                name, config, isValueConfigured, isPolicyEnabled);
-    }
-
-    /**
-     * Returns the finger print of the given certificate.
-     *
-     * @param cert certificate
-     * @return finger print of certificate
-     */
-    public static String getFingerPrint(Certificate cert)
-            throws CertificateEncodingException, NoSuchAlgorithmException {
-        return _engine.getFingerPrint(cert);
-    }
-
-    /**
-     * Returns the finger print of the given certificate.
-     *
-     * @param certDer DER byte array of the certificate
-     * @return finger print of certificate
-     */
-    public static String getFingerPrints(byte[] certDer)
-            throws NoSuchAlgorithmException {
-        return _engine.getFingerPrints(certDer);
-    }
-
-    /**
-     * Returns the finger print of the given certificate.
-     *
-     * @param cert certificate
-     * @return finger print of certificate
-     */
-    public static String getFingerPrints(Certificate cert)
-            throws NoSuchAlgorithmException, CertificateEncodingException {
-        return _engine.getFingerPrints(cert);
-    }
-
-    /**
-     * Creates a HTTP PKI Message that can be sent to a remote
-     * authority.
-     *
-     * @return a new PKI Message for remote authority
-     */
-    public static IPKIMessage getHttpPKIMessage() {
-        return _engine.getHttpPKIMessage();
-    }
-
-    /**
-     * Creates a request encoder. A request cannot be sent to
-     * the remote authority in its regular format.
-     *
-     * @return a request encoder
-     */
-    public static IRequestEncoder getHttpRequestEncoder() {
-        return _engine.getHttpRequestEncoder();
-    }
-
-    /**
-     * Converts a BER-encoded byte array into a MIME-64 encoded string.
-     *
-     * @param data data in byte array format
-     * @return base-64 encoding for the data
-     */
-    public static String BtoA(byte data[]) {
-        return _engine.BtoA(data);
-    }
-
-    /**
-     * Converts a MIME-64 encoded string into a BER-encoded byte array.
-     *
-     * @param data base-64 encoding for the data
-     * @return data data in byte array format
-     */
-    public static byte[] AtoB(String data) {
-        return _engine.AtoB(data);
-    }
-
-    /**
-     * Retrieves the ldap connection information from the configuration
-     * store.
-     *
-     * @param config configuration parameters of ldap connection
-     * @return a LDAP connection info
-     */
-    public static ILdapConnInfo getLdapConnInfo(IConfigStore config)
-            throws EBaseException, ELdapException {
-        return _engine.getLdapConnInfo(config);
-    }
-
-    /**
-     * Creates a LDAP SSL socket with the given nickname. The
-     * certificate associated with the nickname will be used
-     * for client authentication.
-     *
-     * @param certNickname nickname of client certificate
-     * @return LDAP SSL socket factory
-     */
-    public static LDAPSSLSocketFactoryExt getLdapJssSSLSocketFactory(
-            String certNickname) {
-        return _engine.getLdapJssSSLSocketFactory(certNickname);
-    }
-
-    /**
-     * Creates a LDAP SSL socket.
-     *
-     * @return LDAP SSL socket factory
-     */
-    public static LDAPSSLSocketFactoryExt getLdapJssSSLSocketFactory() {
-        return _engine.getLdapJssSSLSocketFactory();
-    }
-
-    public static LDAPSocketFactory getLDAPSocketFactory(boolean secure) {
-        return _engine.getLDAPSocketFactory(secure);
-    }
-
-    /**
-     * Creates a LDAP Auth Info object.
-     *
-     * @return LDAP authentication info
-     */
-    public static ILdapAuthInfo getLdapAuthInfo() {
-        return _engine.getLdapAuthInfo();
-    }
-
-    /**
-     * Retrieves the LDAP connection factory.
-     *
-     * @return bound LDAP connection pool
-     */
-    public static ILdapConnFactory getLdapBoundConnFactory(String id)
-            throws ELdapException {
-        return _engine.getLdapBoundConnFactory(id);
-    }
-
-    /**
-     * Retrieves the LDAP connection factory.
-     *
-     * @return anonymous LDAP connection pool
-     */
-    public static ILdapConnFactory getLdapAnonConnFactory(String id)
-            throws ELdapException {
-        return _engine.getLdapAnonConnFactory(id);
-    }
-
-    /**
-     * Retrieves the default X.509 certificate template.
-     *
-     * @return default certificate template
-     */
-    public static X509CertInfo getDefaultX509CertInfo() {
-        return _engine.getDefaultX509CertInfo();
-    }
-
     /**
      * Retrieves the certifcate in MIME-64 encoded format
      * with header and footer.
@@ -1302,74 +908,6 @@ public final class CMS {
         return _engine.getEncodedCert(cert);
     }
 
-    /**
-     * Verifies all system certs
-     * with tags defined in <subsystemtype>.cert.list
-     */
-    public static void verifySystemCerts() throws Exception {
-        _engine.verifySystemCerts();
-    }
-
-    /**
-     * Verify a system cert by tag name
-     * with tags defined in <subsystemtype>.cert.list
-     */
-    public static void verifySystemCertByTag(String tag) throws Exception {
-        _engine.verifySystemCertByTag(tag);
-    }
-
-    /**
-     * Verify a system cert by certificate nickname
-     */
-    public static void verifySystemCertByNickname(String nickname, String certificateUsage) throws Exception {
-        _engine.verifySystemCertByNickname(nickname, certificateUsage);
-    }
-
-    /**
-     * get the CertificateUsage as defined in JSS CryptoManager
-     */
-    public static CertificateUsage getCertificateUsage(String certusage) {
-        return _engine.getCertificateUsage(certusage);
-    }
-
-    /**
-     * Checks if the given certificate is a signing certificate.
-     *
-     * @param cert certificate
-     * @return true if the given certificate is a signing certificate
-     */
-    public static boolean isSigningCert(X509Certificate cert) {
-        return _engine.isSigningCert(cert);
-    }
-
-    /**
-     * Checks if the given certificate is an encryption certificate.
-     *
-     * @param cert certificate
-     * @return true if the given certificate is an encryption certificate
-     */
-    public static boolean isEncryptionCert(X509Certificate cert) {
-        return _engine.isEncryptionCert(cert);
-    }
-
-    /**
-     * Retrieves the email form processor.
-     *
-     * @return email form processor
-     */
-    public static IEmailFormProcessor getEmailFormProcessor() {
-        return _engine.getEmailFormProcessor();
-    }
-
-    /**
-     * Retrieves the email form template.
-     *
-     * @return email template
-     */
-    public static IEmailTemplate getEmailTemplate(String path) {
-        return _engine.getEmailTemplate(path);
-    }
-
     /**
      * Retrieves the email notification handler.
      *
@@ -1379,87 +917,6 @@ public final class CMS {
         return _engine.getMailNotification();
     }
 
-    /**
-     * Retrieves the email key resolver.
-     *
-     * @return email key resolver
-     */
-    public static IEmailResolverKeys getEmailResolverKeys() {
-        return _engine.getEmailResolverKeys();
-    }
-
-    /**
-     * Checks if the given OID is valid.
-     *
-     * @param attrName attribute name
-     * @param value attribute value
-     * @return object identifier of the given attrName
-     */
-    public static ObjectIdentifier checkOID(String attrName, String value)
-            throws EBaseException {
-        return _engine.checkOID(attrName, value);
-    }
-
-    /**
-     * Retrieves the email resolver that checks for subjectAlternateName.
-     *
-     * @return email key resolver
-     */
-    public static IEmailResolver getReqCertSANameEmailResolver() {
-        return _engine.getReqCertSANameEmailResolver();
-    }
-
-    /**
-     * Retrieves the extension pretty print handler.
-     *
-     * @param e extension
-     * @param indent indentation
-     * @return extension pretty print handler
-     */
-    public static IExtPrettyPrint getExtPrettyPrint(Extension e, int indent) {
-        return _engine.getExtPrettyPrint(e, indent);
-    }
-
-    /**
-     * Retrieves the certificate pretty print handler.
-     *
-     * @param delimiter delimiter
-     * @return certificate pretty print handler
-     */
-    public static IPrettyPrintFormat getPrettyPrintFormat(String delimiter) {
-        return _engine.getPrettyPrintFormat(delimiter);
-    }
-
-    /**
-     * Retrieves the CRL pretty print handler.
-     *
-     * @param crl CRL
-     * @return CRL pretty print handler
-     */
-    public static ICRLPrettyPrint getCRLPrettyPrint(X509CRL crl) {
-        return _engine.getCRLPrettyPrint(crl);
-    }
-
-    /**
-     * Retrieves the CRL cache pretty print handler.
-     *
-     * @param ip CRL issuing point
-     * @return CRL pretty print handler
-     */
-    public static ICRLPrettyPrint getCRLCachePrettyPrint(ICRLIssuingPoint ip) {
-        return _engine.getCRLCachePrettyPrint(ip);
-    }
-
-    /**
-     * Retrieves the certificate pretty print handler.
-     *
-     * @param cert certificate
-     * @return certificate pretty print handler
-     */
-    public static ICertPrettyPrint getCertPrettyPrint(X509Certificate cert) {
-        return _engine.getCertPrettyPrint(cert);
-    }
-
     public static String getConfigSDSessionId() {
         return _engine.getConfigSDSessionId();
     }
@@ -1496,24 +953,6 @@ public final class CMS {
         _engine.putPasswordCache(tag, pw);
     }
 
-    /**
-     * Retrieves the password callback.
-     *
-     * @return default password callback
-     */
-    public static PasswordCallback getPasswordCallback() {
-        return _engine.getPasswordCallback();
-    }
-
-    /**
-     * Retrieves command queue
-     *
-     * @return command queue
-     */
-    public static ICommandQueue getCommandQueue() {
-        return _engine.getCommandQueue();
-    }
-
     public static IConfigStore createFileConfigStore(String path) throws EBaseException {
         return _engine.createFileConfigStore(path);
     }
@@ -1562,4 +1001,34 @@ public final class CMS {
     public static boolean isExcludedLdapAttr(String key) {
         return _engine.isExcludedLdapAttr(key);
     }
+
+    /**
+     * Check whether the string is contains password
+     *
+     * @param name key string
+     * @return whether key is a password or not
+     */
+    public static boolean isSensitive(String name) {
+        return (name.startsWith("__") ||
+                name.endsWith("password") ||
+                name.endsWith("passwd") ||
+                name.endsWith("pwd") ||
+                name.equalsIgnoreCase("admin_password_again") ||
+                name.equalsIgnoreCase("directoryManagerPwd") ||
+                name.equalsIgnoreCase("bindpassword") ||
+                name.equalsIgnoreCase("bindpwd") ||
+                name.equalsIgnoreCase("passwd") ||
+                name.equalsIgnoreCase("password") ||
+                name.equalsIgnoreCase("pin") ||
+                name.equalsIgnoreCase("pwd") ||
+                name.equalsIgnoreCase("pwdagain") ||
+                name.equalsIgnoreCase("uPasswd") ||
+                name.equalsIgnoreCase("PASSWORD_CACHE_ADD") ||
+                name.startsWith("p12Password") ||
+                name.equalsIgnoreCase("host_challenge") ||
+                name.equalsIgnoreCase("card_challenge") ||
+                name.equalsIgnoreCase("card_cryptogram") ||
+                name.equalsIgnoreCase("drm_trans_desKey") ||
+                name.equalsIgnoreCase("cert_request"));
+    }
 }
