@@ -31,16 +31,12 @@ import org.mozilla.jss.asn1.TeletexString;
 import org.mozilla.jss.asn1.UTF8String;
 import org.mozilla.jss.asn1.UniversalString;
 import org.mozilla.jss.crypto.CryptoToken;
-import org.mozilla.jss.crypto.KeyPairAlgorithm;
-import org.mozilla.jss.crypto.KeyPairGenerator;
 import org.mozilla.jss.crypto.PrivateKey;
 import org.mozilla.jss.pkix.primitive.AVA;
 import org.mozilla.jss.pkix.primitive.Name;
 import org.mozilla.jss.util.Password;
 
 import com.netscape.cmsutil.crypto.CryptoUtil;
-import com.netscape.cmsutil.util.Cert;
-import com.netscape.cmsutil.util.Utils;
 
 import netscape.security.pkcs.PKCS10;
 import netscape.security.x509.Extensions;
@@ -234,9 +230,8 @@ public class PKCS10Client {
             KeyPair pair = null;
 
             if (alg.equals("rsa")) {
-                KeyPairGenerator kg = token.getKeyPairGenerator(KeyPairAlgorithm.RSA);
-                kg.initialize(rsa_keylen);
-                pair = kg.genKeyPair();
+                pair = CryptoUtil.generateRSAKeyPair(token, rsa_keylen);
+
             }  else if (alg.equals("ec")) {
                 // used with SSL server cert that does ECDH ECDSA
                 org.mozilla.jss.crypto.KeyPairGeneratorSpi.Usage usages_mask_ECDH[] = {
@@ -249,7 +244,7 @@ public class PKCS10Client {
                   org.mozilla.jss.crypto.KeyPairGeneratorSpi.Usage.DERIVE
                 };
 
-                pair = CryptoUtil.generateECCKeyPair(tokenName,  ecc_curve ,
+                pair = CryptoUtil.generateECCKeyPair(token, ecc_curve,
                        null,
                        usages_mask, ec_temporary /*temporary*/,
                        ec_sensitive /*sensitive*/, ec_extractable /*extractable*/);
@@ -308,18 +303,13 @@ public class PKCS10Client {
                     subjectName, pair, extns);
 
             if (certReq == null) {
-                System.out.println("PKCS10Client: cert request null");
+                System.out.println("PKCS10Client: Unable to create certificate request");
                 System.exit(1);
-            } else
-                if(verbose) {
-                    System.out.println("PKCS10Client: CertificationRequest created.");
-                }
+                return;
+            }
 
-            byte[] certReqb = certReq.toByteArray();
-            String b64E = Utils.base64encode(certReqb, true);
-
-            if(verbose) {
-                System.out.println("PKCS10Client: b64encode completes.");
+            if (verbose) {
+                System.out.println("PKCS10Client: Certificate request created");
             }
 
             // print out keyid to be used in cmc popLinkWitnessV2
@@ -332,19 +322,15 @@ public class PKCS10Client {
                 System.out.println("");
             }
 
+            certReq.print(System.out);
 
-            System.out.println(Cert.REQUEST_HEADER);
-            System.out.print(b64E);
-            System.out.println(Cert.REQUEST_FOOTER);
+            try (FileOutputStream fos = new FileOutputStream(ofilename);
+                    PrintStream ps = new PrintStream(fos)) {
+                certReq.print(ps);
+            }
+
+            System.out.println("PKCS10Client: Certificate request written into " + ofilename);
 
-            PrintStream ps = null;
-            ps = new PrintStream(new FileOutputStream(ofilename));
-            ps.println(Cert.REQUEST_HEADER);
-            ps.print(b64E);
-            ps.println(Cert.REQUEST_FOOTER);
-            ps.flush();
-            ps.close();
-            System.out.println("PKCS10Client: done. Request written to file: "+ ofilename);
         } catch (Exception e) {
             System.out.println("PKCS10Client: Exception caught: "+e.toString());
             System.exit(1);
