@@ -93,6 +93,7 @@ import com.netscape.cms.logging.SignedAuditLogger;
 import com.netscape.cmsutil.crypto.CryptoUtil;
 import com.netscape.cmsutil.util.Utils;
 
+import netscape.security.extensions.CertInfo;
 import netscape.security.pkcs.PKCS10;
 import netscape.security.x509.X500Name;
 import netscape.security.x509.X509CertImpl;
@@ -113,7 +114,7 @@ import netscape.security.x509.X509Key;
 public class CMCAuth implements IAuthManager, IExtendedPluginInfo,
         IProfileAuthenticator {
 
-    private static ILogger mLogger = CMS.getLogger();
+    private static Logger mLogger = Logger.getLogger();
     private static Logger signedAuditLogger = SignedAuditLogger.getLogger();
 
     ////////////////////////
@@ -126,6 +127,7 @@ public class CMCAuth implements IAuthManager, IExtendedPluginInfo,
 
     /* authentication plug-in configuration store */
     private IConfigStore mConfig;
+    private boolean mBypassClientAuth = false;
     private static final String HEADER = "-----BEGIN NEW CERTIFICATE REQUEST-----";
     private static final String TRAILER = "-----END NEW CERTIFICATE REQUEST-----";
     public static final String TOKEN_CERT_SERIAL = "certSerialToRevoke";
@@ -212,6 +214,8 @@ public class CMCAuth implements IAuthManager, IExtendedPluginInfo,
         mName = name;
         mImplName = implName;
         mConfig = config;
+        mBypassClientAuth =
+                CMS.getConfigStore().getBoolean("cmc.bypassClientAuth", false);
 
         log(ILogger.LL_INFO, "Initialization complete!");
     }
@@ -519,8 +523,7 @@ public class CMCAuth implements IAuthManager, IExtendedPluginInfo,
                                         new PKCS10(ostream.toByteArray(), sigver);
 
                                 // xxx do we need to do anything else?
-                                X509CertInfo certInfo =
-                                        CMS.getDefaultX509CertInfo();
+                                X509CertInfo certInfo = new CertInfo();
 
                                 // fillPKCS10(certInfo,pkcs10,authToken,null);
 
@@ -579,8 +582,7 @@ public class CMCAuth implements IAuthManager, IExtendedPluginInfo,
                                 Name name = template.getSubject();
 
                                 // xxx do we need to do anything else?
-                                X509CertInfo certInfo =
-                                        CMS.getDefaultX509CertInfo();
+                                X509CertInfo certInfo = new CertInfo();
 
                                 // reset value of auditCertSubject
                                 if (name != null) {
@@ -881,28 +883,33 @@ public class CMCAuth implements IAuthManager, IExtendedPluginInfo,
                             X509Certificate clientCert =
                                     (X509Certificate) auditContext.get(SessionContext.SSL_CLIENT_CERT);
                             if (clientCert == null) {
-                            //    createAuditSubjectFromCert(auditContext, x509Certs[0]);
-                                msg = "missing SSL client authentication certificate;";
-                                CMS.debug(method + msg);
-                                s.close();
-                                throw new EMissingCredential(
-                                        CMS.getUserMessage("CMS_AUTHENTICATION_NO_CERT"));
-                            }
-                            netscape.security.x509.X500Name clientPrincipal =
-                                    (X500Name) clientCert.getSubjectDN();
-
-                            netscape.security.x509.X500Name cmcPrincipal =
-                                    (X500Name) x509Certs[0].getSubjectDN();
-
-                            // check ssl client cert against cmc signer
-                            if (!clientPrincipal.equals(cmcPrincipal)) {
-                                msg = "SSL client authentication certificate and CMC signer do not match";
-                                CMS.debug(method + msg);
-                                s.close();
-                                throw new EInvalidCredentials(
-                                        CMS.getUserMessage("CMS_AUTHENTICATION_INVALID_CREDENTIAL") + ":" + msg);
+                                if (mBypassClientAuth) {
+                                    msg = "missing SSL client authentication certificate; allowed";
+                                    CMS.debug(method + msg);
+                                } else {
+                                    msg = "missing SSL client authentication certificate;";
+                                    CMS.debug(method + msg);
+                                    s.close();
+                                    throw new EMissingCredential(
+                                            CMS.getUserMessage("CMS_AUTHENTICATION_NO_CERT"));
+                                }
                             } else {
-                                CMS.debug(method + "ssl client cert principal and cmc signer principal match");
+                                netscape.security.x509.X500Name clientPrincipal =
+                                        (X500Name) clientCert.getSubjectDN();
+
+                                netscape.security.x509.X500Name cmcPrincipal =
+                                        (X500Name) x509Certs[0].getSubjectDN();
+
+                                // check ssl client cert against cmc signer
+                                if (!clientPrincipal.equals(cmcPrincipal)) {
+                                    msg = "SSL client authentication certificate and CMC signer do not match";
+                                    CMS.debug(method + msg);
+                                    s.close();
+                                    throw new EInvalidCredentials(
+                                            CMS.getUserMessage("CMS_AUTHENTICATION_INVALID_CREDENTIAL") + ":" + msg);
+                                } else {
+                                    CMS.debug(method + "ssl client cert principal and cmc signer principal match");
+                                }
                             }
 
                             PublicKey signKey = cert.getPublicKey();
