@@ -96,6 +96,7 @@ import com.netscape.cms.logging.SignedAuditLogger;
 import com.netscape.cmsutil.crypto.CryptoUtil;
 import com.netscape.cmsutil.util.Utils;
 
+import netscape.security.extensions.CertInfo;
 import netscape.security.pkcs.PKCS10;
 import netscape.security.x509.KeyIdentifier;
 import netscape.security.x509.PKIXExtensions;
@@ -128,7 +129,7 @@ import netscape.security.x509.X509Key;
 public class CMCUserSignedAuth implements IAuthManager, IExtendedPluginInfo,
         IProfileAuthenticator {
 
-    private static ILogger mLogger = CMS.getLogger();
+    private static Logger mLogger = Logger.getLogger();
     private static Logger signedAuditLogger = SignedAuditLogger.getLogger();
 
     ////////////////////////
@@ -643,7 +644,7 @@ public class CMCUserSignedAuth implements IAuthManager, IExtendedPluginInfo,
                                 } //selfSigned
 
                                 // xxx do we need to do anything else?
-                                X509CertInfo certInfo = CMS.getDefaultX509CertInfo();
+                                X509CertInfo certInfo = new CertInfo();
 
                                 // fillPKCS10(certInfo,pkcs10,authToken,null);
 
@@ -677,7 +678,7 @@ public class CMCUserSignedAuth implements IAuthManager, IExtendedPluginInfo,
                                 Name name = template.getSubject();
 
                                 // xxx do we need to do anything else?
-                                X509CertInfo certInfo = CMS.getDefaultX509CertInfo();
+                                X509CertInfo certInfo = new CertInfo();
 
                                 // reset value of requestCertSubject
                                 if (name != null) {
