@@ -42,6 +42,9 @@ import com.netscape.certsrv.base.IExtendedPluginInfo;
 import com.netscape.certsrv.ldap.ELdapException;
 import com.netscape.certsrv.ldap.ILdapConnFactory;
 import com.netscape.certsrv.logging.ILogger;
+import com.netscape.cms.logging.Logger;
+import com.netscape.cmscore.ldapconn.LdapAnonConnFactory;
+import com.netscape.cmscore.ldapconn.LdapBoundConnFactory;
 import com.netscape.cmsutil.util.Utils;
 
 import netscape.ldap.LDAPAttribute;
@@ -117,7 +120,7 @@ public abstract class DirBasedAuthentication
     protected ILdapConnFactory mConnFactory = null;
 
     /* the system logger */
-    protected ILogger mLogger = CMS.getLogger();
+    protected Logger mLogger = Logger.getLogger();
 
     /* the subject DN pattern */
     protected DNPattern mPattern = null;
@@ -289,9 +292,9 @@ public abstract class DirBasedAuthentication
         if (mBoundConnEnable) {
             mTag = mLdapConfig.getString(PROP_LDAP_BOUND_TAG);
             CMS.debug(method + " getting ldap bound conn factory using id= " + mTag);
-            mConnFactory = CMS.getLdapBoundConnFactory(mTag);
+            mConnFactory = new LdapBoundConnFactory(mTag);
         } else {
-            mConnFactory = CMS.getLdapAnonConnFactory("DirBasedAuthentication");
+            mConnFactory = new LdapAnonConnFactory("DirBasedAuthentication");
         }
         if (mConnFactory != null) // else can try again later when needed
             mConnFactory.init(mLdapConfig);
@@ -397,9 +400,9 @@ public abstract class DirBasedAuthentication
                 if (mBoundConnEnable) {
                     mTag = mLdapConfig.getString(PROP_LDAP_BOUND_TAG);
                     CMS.debug(method + " getting ldap bound conn factory using id= " + mTag);
-                    mConnFactory = CMS.getLdapBoundConnFactory(mTag);
+                    mConnFactory = new LdapBoundConnFactory(mTag);
                 } else {
-                    mConnFactory = CMS.getLdapAnonConnFactory("DirBasedAuthentication");
+                    mConnFactory = new LdapAnonConnFactory("DirBasedAuthentication");
                 }
                 if (mConnFactory != null) {
                     mConnFactory.init(mLdapConfig);
