@@ -33,6 +33,7 @@ import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.authentication.AuthToken;
 import com.netscape.certsrv.authentication.EInvalidCredentials;
 import com.netscape.certsrv.authentication.IAuthCredentials;
+import com.netscape.certsrv.authentication.IAuthToken;
 import com.netscape.certsrv.authentication.ISharedToken;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
@@ -43,6 +44,7 @@ import com.netscape.certsrv.dbs.certdb.ICertRecord;
 import com.netscape.certsrv.dbs.certdb.ICertificateRepository;
 import com.netscape.certsrv.ldap.ILdapConnFactory;
 import com.netscape.certsrv.logging.ILogger;
+import com.netscape.cmscore.ldapconn.LdapBoundConnFactory;
 import com.netscape.cmsutil.crypto.CryptoUtil;
 import com.netscape.cmsutil.util.Utils;
 
@@ -223,7 +225,7 @@ public class SharedSecret extends DirBasedAuthentication
             CMS.debug(msg);
             throw new EBaseException(msg);
         }
-        shrTokLdapFactory = CMS.getLdapBoundConnFactory("SharedSecret");
+        shrTokLdapFactory = new LdapBoundConnFactory("SharedSecret");
         if (shrTokLdapFactory == null) {
             msg = method + "CMS.getLdapBoundConnFactory returned null for SharedSecret";
             CMS.debug(msg);
@@ -233,18 +235,25 @@ public class SharedSecret extends DirBasedAuthentication
     }
 
     /**
-     * getSharedToken(String identification) provides
+     * getSharedToken(String identification, IAuthToken authToken) provides
      *  support for id_cmc_identification shared secret based enrollment
      *
+     * @param identification maps to the uid in user's ldap record
+     * @param authToken the IAuthToken that will be filled with the DN
+     *        in user's ldap record
+     *
      * Note: caller should clear the memory for the returned token
      *       after each use
      */
-    public char[] getSharedToken(String identification)
+    public char[] getSharedToken(String identification, IAuthToken authToken)
             throws EBaseException {
-        String method = "SharedSecret.getSharedToken(String identification): ";
+        String method = "SharedSecret.getSharedToken(String identification, IAuthToken authToken): ";
         String msg = "";
         CMS.debug(method + "begins.");
 
+        if ((identification == null) || (authToken == null)) {
+            throw new EBaseException(method + "paramsters identification or authToken cannot be null");
+        }
         LDAPConnection shrTokLdapConnection = null;
         LDAPSearchResults res = null;
         LDAPEntry entry = null;
@@ -287,6 +296,9 @@ public class SharedSecret extends DirBasedAuthentication
                 throw new EBaseException(msg);
             }
 
+            CMS.debug(method + "found user ldap entry: userdn = " + userdn);
+            authToken.set(IAuthToken.TOKEN_CERT_SUBJECT, userdn);
+
             res = shrTokLdapConnection.search(userdn, LDAPv2.SCOPE_BASE,
                     "(objectclass=*)", new String[] { mShrTokAttr }, false);
             if (res != null && res.hasMoreElements()) {
@@ -395,6 +407,11 @@ public class SharedSecret extends DirBasedAuthentication
         String method = "SharedSecret.getSharedToken(BigInteger serial): ";
         String msg = "";
 
+        if (serial == null) {
+            throw new EBaseException(method + "paramster serial cannot be null");
+        }
+        CMS.debug(method + serial.toString());
+
         ICertRecord record = null;
         try {
             record = certRepository.readCertificateRecord(serial);
