@@ -41,7 +41,6 @@ import java.security.PrivateKey;
 import java.security.Provider;
 import java.security.Signature;
 import java.security.SignatureException;
-import java.security.interfaces.RSAPrivateKey;
 import java.text.ParseException;
 import java.text.SimpleDateFormat;
 import java.util.Date;
@@ -81,6 +80,7 @@ import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.logging.LogSource;
 import com.netscape.certsrv.logging.SignedAuditEvent;
 import com.netscape.certsrv.logging.SystemEvent;
+import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmsutil.util.Utils;
 
 import netscape.ldap.client.JDAPAVA;
@@ -99,6 +99,7 @@ import netscape.ldap.client.JDAPFilterSubString;
  **/
 public class LogFile implements ILogEventListener, IExtendedPluginInfo {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(LogFile.class);
     private static Logger signedAuditLogger = SignedAuditLogger.getLogger();
 
     public static final String PROP_TYPE = "type";
@@ -285,7 +286,7 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
             try {
                 mSAuditCertNickName = config.getString(
                                           PROP_SIGNED_AUDIT_CERT_NICKNAME);
-                CMS.debug("LogFile: init(): audit log signing enabled. signedAuditCertNickname=" + mSAuditCertNickName);
+                logger.debug("LogFile: audit log signing enabled. signedAuditCertNickname: " + mSAuditCertNickName);
             } catch (EBaseException e) {
                 throw new ELogException(CMS.getUserMessage("CMS_BASE_GET_PROPERTY_FAILED",
                         config.getName() + "."
@@ -318,14 +319,14 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
             unselectedEvents.add(event);
         }
 
-        CMS.debug("Event filters:");
+        logger.debug("Event filters:");
         IConfigStore filterStore = config.getSubStore(PROP_SIGNED_AUDIT_FILTERS);
         for (Enumeration<String> e = filterStore.getPropertyNames(); e.hasMoreElements(); ) {
             String eventType = e.nextElement();
 
             // get event filter
             String strFilter = filterStore.get(eventType);
-            CMS.debug(" - " + eventType + ": " + strFilter);
+            logger.debug(" - " + eventType + ": " + strFilter);
 
             // parse filter
             JDAPFilter filter = JDAPFilter.getFilter(strFilter);
@@ -335,7 +336,7 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
         try {
             init(config);
         } catch (IOException e) {
-            throw new ELogException(CMS.getUserMessage("CMS_LOG_UNEXPECTED_EXCEPTION", e.toString()));
+            throw new ELogException("Unable to initialize LogFile: " + e.getMessage(), e);
         }
 
         // set up signing here to ensure audit logs generated during
@@ -343,7 +344,7 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
         if (mOn && mLogSigning) {
 
             try {
-                CMS.debug("LogFile: setting up log signing");
+                logger.debug("LogFile: setting up log signing");
                 setupSigning();
 
                 signedAuditLogger.log(CMS.getLogMessage(
@@ -424,20 +425,10 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
             // synchronized. We just want to avoid an infinite loop.
             mInSignedAuditLogFailureMode = true;
 
-            // Block all new incoming requests
-            if (CMS.areRequestsDisabled() == false) {
-                // XXX is this a race condition?
-                CMS.disableRequests();
-            }
+            logger.error("LogFile: Disabling subsystem due to signed logging failure");
 
-            // Terminate all requests in process
-            CMS.terminateRequests();
-
-            // Call graceful shutdown of the CMS server
-            // Call force shutdown to get added functionality of
-            // making sure to kill the web server.
-
-            CMS.forceShutdown();
+            CMSEngine engine = (CMSEngine) CMS.getCMSEngine();
+            engine.disableSubsystem();
         }
     }
 
@@ -454,46 +445,23 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
 
         mConfig = config;
 
-        try {
-            mTrace = config.getBoolean(PROP_TRACE, false);
-        } catch (EBaseException e) {
-            throw new ELogException(CMS.getUserMessage("CMS_BASE_GET_PROPERTY_FAILED",
-                    config.getName() + "." + PROP_TRACE));
-        }
-
-        try {
-            mType = config.getString(PROP_TYPE, "system");
-        } catch (EBaseException e) {
-            throw new ELogException(CMS.getUserMessage("CMS_BASE_GET_PROPERTY_FAILED",
-                    config.getName() + "." + PROP_TYPE));
-        }
-
-        try {
-            mRegister = config.getBoolean(PROP_REGISTER, true);
-        } catch (EBaseException e) {
-            throw new ELogException(CMS.getUserMessage("CMS_BASE_GET_PROPERTY_FAILED",
-                    config.getName() + "." + PROP_REGISTER));
-        }
+        mTrace = config.getBoolean(PROP_TRACE, false);
+        mType = config.getString(PROP_TYPE, "system");
+        mRegister = config.getBoolean(PROP_REGISTER, true);
 
         if (mOn) {
             if (mRegister) {
-                CMS.getLogger().getLogQueue().addLogEventListener(this);
+                Logger.getLogger().getLogQueue().addLogEventListener(this);
             }
         } else {
             // shutdown the listener, remove the listener
             if (mRegister) {
-                CMS.getLogger().getLogQueue().removeLogEventListener(this);
+                Logger.getLogger().getLogQueue().removeLogEventListener(this);
                 shutdown();
             }
         }
 
-        try {
-            mLevel = config.getInteger(PROP_LEVEL, 3);
-        } catch (EBaseException e) {
-            e.printStackTrace();
-            throw new ELogException(CMS.getUserMessage("CMS_BASE_GET_PROPERTY_FAILED",
-                    config.getName() + "." + PROP_LEVEL));
-        }
+        mLevel = config.getInteger(PROP_LEVEL, 3);
 
         try {
             // retrieve the subsystem
@@ -529,10 +497,10 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
                                        + instID + "_" + "audit";
 
         } catch (Exception e2) {
-            throw new ELogException(
-                          CMS.getUserMessage("CMS_BASE_GET_PROPERTY_FAILED",
-                                              config.getName() + "." +
-                                                      PROP_FILE_NAME));
+            String message = CMS.getUserMessage("CMS_BASE_GET_PROPERTY_FAILED",
+                    config.getName() + "." + PROP_FILE_NAME);
+            logger.error("LogFile: " + message + ": " + e2.getMessage(), e2);
+            throw new ELogException(message, e2);
         }
 
         // the default value is determined by the eventType.
@@ -543,15 +511,19 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
         } else if (mType.equals(ILogger.PROP_AUDIT)) {
             defaultFileName = "logs/transactions";
         } else {
-            throw new ELogException(CMS.getUserMessage("CMS_LOG_INVALID_LOG_TYPE",
-                    config.getName(), mType));
+            String message = CMS.getUserMessage("CMS_LOG_INVALID_LOG_TYPE",
+                    config.getName(), mType);
+            logger.error("LogFile: " + message);
+            throw new ELogException(message);
         }
 
         try {
             fileName = config.getString(PROP_FILE_NAME, defaultFileName);
         } catch (EBaseException e) {
-            throw new ELogException(CMS.getUserMessage("CMS_BASE_GET_PROPERTY_FAILED",
-                    config.getName() + "." + PROP_FILE_NAME));
+            String message = CMS.getUserMessage("CMS_BASE_GET_PROPERTY_FAILED",
+                    config.getName() + "." + PROP_FILE_NAME);
+            logger.error("LogFile: " + message + ": " + e.getMessage(), e);
+            throw new ELogException(message, e);
         }
 
         if (mOn) {
@@ -571,7 +543,7 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
         if (fileName == null)
             throw new ELogException(CMS.getUserMessage("CMS_LOG_INVALID_FILE_NAME", "null"));
 
-        CMS.debug("Creating " + getClass().getSimpleName() + "(" + fileName + ")");
+        logger.debug("LogFile: Creating " + getClass().getSimpleName() + "(" + fileName + ")");
 
         //If we want to reuse the old log files
         //mFileName = fileName + "." + mLogFileDateFormat.format(mDate);
@@ -596,7 +568,7 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
             Provider[] providers = java.security.Security.getProviders();
             int ps = providers.length;
             for (int i = 0; i < ps; i++) {
-                CMS.debug("LogFile: provider " + i + "= " + providers[i].getName());
+                logger.debug("LogFile: provider " + i + "= " + providers[i].getName());
             }
 
             CryptoManager cm = CryptoManager.getInstance();
@@ -604,9 +576,9 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
             // find CertServer's private key
             X509Certificate cert = cm.findCertByNickname(mSAuditCertNickName);
             if (cert != null) {
-                CMS.debug("LogFile: setupSignig(): found cert:" + mSAuditCertNickName);
+                logger.debug("LogFile: setupSignig(): found cert:" + mSAuditCertNickName);
             } else {
-                CMS.debug("LogFile: setupSignig(): cert not found:" + mSAuditCertNickName);
+                logger.warn("LogFile: setupSignig(): cert not found:" + mSAuditCertNickName);
             }
             mSigningKey = cm.findPrivKeyByCert(cert);
 
@@ -799,8 +771,9 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
                 try {
                     Utils.exec("chmod 00640 " + mFile.getCanonicalPath());
                 } catch (IOException e) {
-                    CMS.debug("Unable to change file permissions on "
-                             + mFile.toString());
+                    String message = "Unable to change file permissions on "
+                             + mFile + ": " + e.getMessage();
+                    logger.warn(message, e);
                 }
             }
             mLogWriter = new BufferedWriter(
@@ -810,21 +783,24 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
             // initialized yet. That's ok, we will push our first signature
             // in setupSigning().
             if (mLogSigning && (mSignature != null)) {
-                try {
-                    pushSignature();
-                } catch (ELogException le) {
-                    ConsoleError.send(
-                            new SystemEvent(CMS.getUserMessage("CMS_LOG_ILLEGALARGUMENT",
-                                    mFileName)));
-                }
+                pushSignature();
             }
+
+        } catch (ELogException e) {
+            String message = CMS.getUserMessage("CMS_LOG_ILLEGALARGUMENT", mFileName);
+            logger.warn("LogFile: " + message + ": " + e.getMessage(), e);
+            ConsoleError.send(new SystemEvent(message));
+
         } catch (IllegalArgumentException iae) {
-            ConsoleError.send(
-                    new SystemEvent(CMS.getUserMessage("CMS_LOG_ILLEGALARGUMENT",
-                            mFileName)));
+            String message = CMS.getUserMessage("CMS_LOG_ILLEGALARGUMENT", mFileName);
+            logger.warn("LogFile: " + message + ": " + iae.getMessage(), iae);
+            ConsoleError.send(new SystemEvent(message));
+
         } catch (GeneralSecurityException gse) {
             // error with signed audit log, shutdown CMS
-            ConsoleError.send(new SystemEvent(CMS.getUserMessage("CMS_LOG_OPEN_FAILED", mFileName, gse.toString())));
+            String message = CMS.getUserMessage("CMS_LOG_OPEN_FAILED", mFileName, gse.getMessage());
+            logger.error("LogFile: " + message, gse);
+            ConsoleError.send(new SystemEvent(message));
             gse.printStackTrace();
             shutdownCMS();
         }
@@ -839,37 +815,21 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
     public synchronized void flush() {
         try {
             if (mLogSigning) {
-                try {
-                    pushSignature();
-                } catch (ELogException le) {
-                    ConsoleError.send(new SystemEvent(CMS.getUserMessage("CMS_LOG_FLUSH_LOG_FAILED", mFileName,
-                            le.toString())));
-                    le.printStackTrace();
-                    shutdownCMS();
-                }
+                pushSignature();
             }
 
             if (mLogWriter != null) {
                 mLogWriter.flush();
             }
-        } catch (IOException e) {
-            ConsoleError.send(new SystemEvent(CMS.getUserMessage("CMS_LOG_FLUSH_LOG_FAILED", mFileName, e.toString())));
+
+        } catch (Exception e) {
+            String message = CMS.getUserMessage("CMS_LOG_FLUSH_LOG_FAILED", mFileName, e.getMessage());
+            logger.error("LogFile: " + message, e);
+            ConsoleError.send(new SystemEvent(message));
             if (mLogSigning) {
-                //error in writing to signed audit log, shut down CMS
                 e.printStackTrace();
                 shutdownCMS();
             }
-        } catch (GeneralSecurityException gse) {
-            // error with signed audit log, shutdown CMS
-            ConsoleError.send(new SystemEvent(CMS.getUserMessage("CMS_LOG_FLUSH_LOG_FAILED", mFileName, gse.toString())));
-            gse.printStackTrace();
-            shutdownCMS();
-        } catch (Exception ee) {
-            ConsoleError.send(new SystemEvent(CMS.getUserMessage("CMS_LOG_FLUSH_LOG_FAILED", mFileName, ee.toString())));
-            if(mLogSigning) {
-                ee.printStackTrace();
-                shutdownCMS();
-            }
         }
 
         mBytesUnflushed = 0;
@@ -901,7 +861,7 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
      */
     public synchronized void shutdown() {
 
-        CMS.debug("Destroying LogFile(" + mFileName + ")");
+        logger.info("Destroying LogFile(" + mFileName + ")");
 
         String auditMessage = null;
 
@@ -1005,12 +965,15 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
         if (mLogWriter == null) {
             String[] params = { mFileName, entry };
 
+            String message = CMS.getUserMessage("CMS_LOG_LOGFILE_CLOSED", params);
+            logger.error("LogFile: " + message);
+            ConsoleError.send(new SystemEvent(message));
             if (mLogSigning) {
-                ConsoleError.send(new SystemEvent(CMS.getUserMessage("CMS_LOG_LOGFILE_CLOSED", params)));
                 // Failed to write to audit log, shut down CMS
                 shutdownCMS();
             }
-            throw new ELogException(CMS.getUserMessage("CMS_LOG_LOGFILE_CLOSED", params));
+            throw new ELogException(message);
+
         } else {
             try {
                 mLogWriter.write(entry, 0/*offset*/, entry.length());
@@ -1020,7 +983,7 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
                         // include newline for calculating MAC
                         mSignature.update(entry.getBytes("UTF-8"));
                     } else {
-                        CMS.debug("LogFile: mSignature is not yet ready... null in log()");
+                        logger.warn("LogFile: missing audit log signature");
                     }
                 }
                 if (mTrace) {
@@ -1060,29 +1023,35 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
                     if (mSignature != null) {
                         mSignature.update(LINE_SEP_BYTE);
                     } else {
-                        CMS.debug("LogFile: mSignature is null in log() 2");
+                        logger.warn("LogFile: missing audit log signature");
                     }
                 }
+
             } catch (IOException e) {
-                ConsoleError.send(new SystemEvent(CMS.getUserMessage("CMS_LOG_WRITE_FAILED", mFileName, entry,
-                        e.toString())));
+                String message = CMS.getUserMessage("CMS_LOG_WRITE_FAILED", mFileName, entry, e.getMessage());
+                logger.error("LogFile: " + message);
+                ConsoleError.send(new SystemEvent(message));
                 if (mLogSigning) {
                     // Failed to write to audit log, shut down CMS
                     e.printStackTrace();
                     shutdownCMS();
                 }
+
             } catch (IllegalStateException e) {
-                CMS.debug("LogFile: exception thrown in log(): " + e.toString());
-                ConsoleError.send(new SignedAuditEvent(CMS.getLogMessage(LOG_SIGNED_AUDIT_EXCEPTION, e.toString())));
+                String message = CMS.getLogMessage(LOG_SIGNED_AUDIT_EXCEPTION, e.getMessage());
+                logger.error("LogFile: " + message, e);
+                ConsoleError.send(new SignedAuditEvent(message));
+
             } catch (GeneralSecurityException gse) {
                 // DJN: handle error
-                CMS.debug("LogFile: exception thrown in log(): "
-                        + gse.toString());
-                gse.printStackTrace();
-                ConsoleError.send(new SignedAuditEvent(CMS.getLogMessage(
-                        LOG_SIGNED_AUDIT_EXCEPTION, gse.toString())));
+                String message = CMS.getLogMessage(LOG_SIGNED_AUDIT_EXCEPTION, gse.getMessage());
+                logger.error("LogFile: " + message, gse);
+                ConsoleError.send(new SignedAuditEvent(message));
+
             } catch (Exception ee) { // Make darn sure we got everything
-                ConsoleError.send(new SignedAuditEvent(CMS.getLogMessage(LOG_SIGNED_AUDIT_EXCEPTION, ee.toString())));
+                String message = CMS.getLogMessage(LOG_SIGNED_AUDIT_EXCEPTION, ee.getMessage());
+                logger.error("LogFile: " + message, ee);
+                ConsoleError.send(new SignedAuditEvent(message));
                 if (mLogSigning) {
                     // Failed to write to audit log, shut down CMS
                     ee.printStackTrace();
@@ -1147,7 +1116,7 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
             return;
         }
 
-        CMS.debug("LogFile: event type not selected: " + type);
+        logger.debug("LogFile: event type not selected: " + type);
     }
 
     public void filter(SignedAuditEvent ev) throws ELogException {
@@ -1423,7 +1392,7 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
                     lineNo++;
 
                 } catch (IOException e) {
-                    CMS.getLogger().log(ILogger.EV_SYSTEM, ILogger.S_OTHER,
+                    Logger.getLogger().log(ILogger.EV_SYSTEM, ILogger.S_OTHER,
                             ILogger.LL_FAILURE,
                             CMS.getLogMessage("LOGGING_READ_ERROR", fileName,
                                     Integer.toString(lineNo)));
@@ -1490,13 +1459,13 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
             try {
                 fBuffer.close();
             } catch (IOException e) {
-                CMS.getLogger().log(ILogger.EV_SYSTEM, ILogger.S_OTHER,
+                Logger.getLogger().log(ILogger.EV_SYSTEM, ILogger.S_OTHER,
                         ILogger.LL_FAILURE, "logging:" + fileName +
                                 " failed to close for reading");
             }
 
         } catch (FileNotFoundException e) {
-            CMS.getLogger().log(ILogger.EV_SYSTEM, ILogger.S_OTHER,
+            Logger.getLogger().log(ILogger.EV_SYSTEM, ILogger.S_OTHER,
                     ILogger.LL_FAILURE,
                     CMS.getLogMessage("LOGGING_FILE_NOT_FOUND",
                             fileName));
@@ -1550,7 +1519,7 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
                         entries.elementAt(i).getEntry(), "");
             }
         } catch (Exception e) {
-            CMS.getLogger().log(ILogger.EV_SYSTEM, ILogger.S_OTHER,
+            Logger.getLogger().log(ILogger.EV_SYSTEM, ILogger.S_OTHER,
                     ILogger.LL_WARN,
                     "System log parse error");
         }
