@@ -28,7 +28,6 @@ import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IAttrSet;
 import com.netscape.certsrv.base.IConfigStore;
-import com.netscape.certsrv.base.IPrettyPrintFormat;
 import com.netscape.certsrv.common.NameValuePairs;
 import com.netscape.certsrv.pattern.Pattern;
 import com.netscape.certsrv.profile.EProfileException;
@@ -40,6 +39,7 @@ import com.netscape.certsrv.property.EPropertyException;
 import com.netscape.certsrv.property.IDescriptor;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.cms.profile.common.EnrollProfile;
+import com.netscape.cmscore.cert.PrettyPrintFormat;
 
 import netscape.security.extensions.KerberosName;
 import netscape.security.util.DerInputStream;
@@ -291,7 +291,7 @@ public abstract class EnrollDefault implements IPolicyDefault, ICertInfoPolicyDe
     }
 
     public String toHexString(byte data[]) {
-        IPrettyPrintFormat pp = CMS.getPrettyPrintFormat(":");
+        PrettyPrintFormat pp = new PrettyPrintFormat(":");
         String s = pp.toHexString(data, 0, 16);
         StringTokenizer st = new StringTokenizer(s, "\n");
         StringBuffer buffer = new StringBuffer();
@@ -672,7 +672,7 @@ public abstract class EnrollDefault implements IPolicyDefault, ICertInfoPolicyDe
         return true;
     }
 
-    protected String buildRecords(Vector<NameValuePairs> recs) throws EPropertyException {
+    protected static String buildRecords(Vector<NameValuePairs> recs) {
         StringBuffer sb = new StringBuffer();
 
         for (int i = 0; i < recs.size(); i++) {
@@ -739,7 +739,7 @@ public abstract class EnrollDefault implements IPolicyDefault, ICertInfoPolicyDe
         return v;
     }
 
-    protected String getGeneralNameType(GeneralName gn)
+    protected static String getGeneralNameType(GeneralName gn)
             throws EPropertyException {
         int type = gn.getType();
 
@@ -763,7 +763,8 @@ public abstract class EnrollDefault implements IPolicyDefault, ICertInfoPolicyDe
         throw new EPropertyException("Unsupported type: " + type);
     }
 
-    protected String getGeneralNameValue(GeneralName gn) throws EPropertyException {
+    protected static String getGeneralNameValue(GeneralName gn)
+            throws EPropertyException {
         String s = gn.toString();
         int type = gn.getType();
 
