@@ -30,6 +30,8 @@ import com.netscape.certsrv.ldap.ELdapException;
 import com.netscape.certsrv.ldap.ELdapServerDownException;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.publish.ILdapPublisher;
+import com.netscape.cms.logging.Logger;
+import com.netscape.cmscore.ldapconn.PKISocketFactory;
 
 import netscape.ldap.LDAPAttribute;
 import netscape.ldap.LDAPConnection;
@@ -49,7 +51,7 @@ import netscape.ldap.LDAPv2;
  * @version $Revision$, $Date$
  */
 public class LdapCrlPublisher implements ILdapPublisher, IExtendedPluginInfo {
-    private ILogger mLogger = CMS.getLogger();
+    private Logger mLogger = Logger.getLogger();
     protected IConfigStore mConfig = null;
     boolean mInited = false;
 
@@ -172,9 +174,9 @@ public class LdapCrlPublisher implements ILdapPublisher, IExtendedPluginInfo {
                 String cert_nick = mConfig.getString("clientCertNickname", null);
                 LDAPSSLSocketFactoryExt sslSocket;
                 if (cert_nick != null) {
-                    sslSocket = CMS.getLdapJssSSLSocketFactory(cert_nick);
+                    sslSocket = new PKISocketFactory(cert_nick);
                 } else {
-                    sslSocket = CMS.getLdapJssSSLSocketFactory();
+                    sslSocket = new PKISocketFactory(true);
                 }
                 String mgr_dn = mConfig.getString("bindDN", null);
                 String mgr_pwd = mConfig.getString("bindPWD", null);
