@@ -92,6 +92,7 @@ import com.netscape.cms.logging.Logger;
 import com.netscape.cms.logging.SignedAuditLogger;
 import com.netscape.cms.servlet.profile.SSLClientCertProvider;
 import com.netscape.cmscore.security.JssSubsystem;
+import com.netscape.cmscore.security.PWCBsdr;
 import com.netscape.cmsutil.crypto.CryptoUtil;
 import com.netscape.cmsutil.scep.CRSPKIMessage;
 import com.netscape.cmsutil.util.Utils;
@@ -100,6 +101,7 @@ import netscape.ldap.LDAPAttribute;
 import netscape.ldap.LDAPAttributeSet;
 import netscape.ldap.LDAPConnection;
 import netscape.ldap.LDAPEntry;
+import netscape.security.extensions.CertInfo;
 import netscape.security.pkcs.PKCS10;
 import netscape.security.pkcs.PKCS10Attribute;
 import netscape.security.pkcs.PKCS10Attributes;
@@ -170,7 +172,7 @@ public class CRSEnrollment extends HttpServlet {
     private String[] mAllowedEncryptionAlgorithm;
     private SecureRandom mRandom = null;
     private int mNonceSizeLimit = 0;
-    protected ILogger mLogger = CMS.getLogger();
+    protected Logger mLogger = Logger.getLogger();
     private ICertificateAuthority ca;
     /* for hashing challenge password */
     protected MessageDigest mSHADigest = null;
@@ -1171,7 +1173,7 @@ public class CRSEnrollment extends HttpServlet {
 
             // Here, we make a new CertInfo - it's a new start for a certificate
 
-            X509CertInfo certInfo = CMS.getDefaultX509CertInfo();
+            X509CertInfo certInfo = new CertInfo();
 
             // get some stuff out of the request
             X509Key key = p10.getSubjectPublicKeyInfo();
@@ -1974,7 +1976,7 @@ public class CRSEnrollment extends HttpServlet {
                     internalKeyStorageToken = null;
                 }
                 if (!mUseCA && internalKeyStorageToken == null) {
-                    PasswordCallback cb = CMS.getPasswordCallback();
+                    PasswordCallback cb = new PWCBsdr();
                     keyStorageToken.login(cb); // ONE_TIME by default.
                 }
                 signingCert = cm.findCertByNickname(mNickname);
