@@ -22,6 +22,7 @@ import java.security.cert.CertificateException;
 import java.util.Locale;
 import java.util.Vector;
 
+import org.dogtagpki.legacy.core.policy.GeneralNameUtil;
 import org.dogtagpki.legacy.policy.IEnrollmentPolicy;
 import org.dogtagpki.legacy.policy.IGeneralNameAsConstraintsConfig;
 import org.dogtagpki.legacy.policy.IPolicyProcessor;
@@ -437,7 +438,7 @@ class Subtree {
         mMax = mConfig.getInteger(PROP_MAX, DEF_MAX);
         if (mMax < -1)
             mMax = -1;
-        mBase = CMS.createGeneralNameAsConstraintsConfig(
+        mBase = new GeneralNameUtil.GeneralNameAsConstraintsConfig(
                     mNameDot + PROP_BASE, mConfig.getSubStore(PROP_BASE),
                     true, policyEnabled);
 
@@ -458,7 +459,7 @@ class Subtree {
 
         if (name != null && name.length() >= 0)
             nameDot = name + ".";
-        CMS.getGeneralNameConfigDefaultParams(nameDot + PROP_BASE, true, params);
+        GeneralNameUtil.GeneralNameConfig.getDefaultParams(nameDot + PROP_BASE, true, params);
         params.addElement(nameDot + PROP_MIN + "=" + DEF_MIN);
         params.addElement(nameDot + PROP_MAX + "=" + DEF_MAX);
     }
@@ -468,7 +469,7 @@ class Subtree {
 
         if (name != null && name.length() > 0)
             nameDot = name + ".";
-        CMS.getGeneralNameConfigExtendedPluginInfo(nameDot + PROP_BASE, true, info);
+        GeneralNameUtil.GeneralNameConfig.getExtendedPluginInfo(nameDot + PROP_BASE, true, info);
         info.addElement(nameDot + PROP_MIN + ";" + MINMAX_INFO);
         info.addElement(nameDot + PROP_MAX + ";" + MINMAX_INFO);
     }
