@@ -25,19 +25,16 @@ import java.security.Principal;
 import java.security.PublicKey;
 import java.security.SecureRandom;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Collection;
 
 import org.apache.commons.lang.StringUtils;
 import org.mozilla.jss.CryptoManager;
-import org.mozilla.jss.NoSuchTokenException;
 import org.mozilla.jss.NotInitializedException;
 import org.mozilla.jss.crypto.CryptoToken;
 import org.mozilla.jss.crypto.ObjectNotFoundException;
 import org.mozilla.jss.crypto.PrivateKey;
 import org.mozilla.jss.crypto.TokenException;
 import org.mozilla.jss.crypto.X509Certificate;
-import org.mozilla.jss.util.IncorrectPasswordException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -48,8 +45,11 @@ import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.PKIException;
 import com.netscape.certsrv.ca.ICertificateAuthority;
 import com.netscape.certsrv.dbs.certdb.ICertificateRepository;
+import com.netscape.certsrv.system.AdminSetupRequest;
+import com.netscape.certsrv.system.AdminSetupResponse;
 import com.netscape.certsrv.system.ConfigurationRequest;
 import com.netscape.certsrv.system.ConfigurationResponse;
+import com.netscape.certsrv.system.KeyBackupRequest;
 import com.netscape.certsrv.system.SystemCertData;
 import com.netscape.certsrv.system.SystemConfigResource;
 import com.netscape.certsrv.usrgrp.IUGSubsystem;
@@ -67,6 +67,8 @@ import com.netscape.cmscore.dbs.DBSubsystem;
 import com.netscape.cmscore.security.JssSubsystem;
 import com.netscape.cmscore.usrgrp.UGSubsystem;
 import com.netscape.cmsutil.crypto.CryptoUtil;
+import com.netscape.cmsutil.password.IPasswordStore;
+import com.netscape.cmsutil.util.Utils;
 
 import netscape.security.x509.X509CertImpl;
 
@@ -78,6 +80,9 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
 
     public final static Logger logger = LoggerFactory.getLogger(SystemConfigService.class);
 
+    public static final String ECC_INTERNAL_ADMIN_CERT_PROFILE = "caECAdminCert";
+    public static final String RSA_INTERNAL_ADMIN_CERT_PROFILE = "caAdminCert";
+
     public IConfigStore cs;
     public String csType;
     public String csSubsystem;
@@ -85,8 +90,6 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
     public boolean isMasterCA = false;
     public String instanceRoot;
 
-    public static String SUCCESS = "0";
-
     public SystemConfigService() throws EBaseException {
         cs = CMS.getConfigStore();
         csType = cs.getString("cs.type");
@@ -128,23 +131,18 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
 
     public void configure(ConfigurationRequest data, ConfigurationResponse response) throws Exception {
 
+        validatePin(data.getPin());
 
         if (csState.equals("1")) {
-            throw new BadRequestException("System is already configured");
+            throw new BadRequestException("System already configured");
         }
 
         logger.debug("SystemConfigService: request: " + data);
         validateRequest(data);
 
-        Collection<String> certList = getCertList(data);
-
-        // specify module and log into token
-        logger.debug("=== Token Authentication ===");
+        logger.debug("=== Token Configuration ===");
         String token = data.getToken();
-        if (CryptoUtil.isInternalToken(token)) {
-            token = CryptoUtil.INTERNAL_TOKEN_FULL_NAME;
-        }
-        loginToken(data, token);
+        configureToken(data, token);
 
         // configure security domain
         logger.debug("=== Security Domain Configuration ===");
@@ -152,77 +150,212 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
 
         // configure subsystem
         logger.debug("=== Subsystem Configuration ===");
-        configureSubsystem(data, certList, token, domainXML);
+        configureSubsystem(data, token, domainXML);
 
         // configure hierarchy
         logger.debug("=== Hierarchy Configuration ===");
         configureHierarchy(data);
 
-        // configure database
-        logger.debug("=== Database Configuration ===");
-        try {
-            configureDatabase(data);
-            cs.commit(false);
-        } catch (EBaseException e) {
-            logger.error("Unable to commit config parameters to file: " + e.getMessage(), e);
-            throw new PKIException("Unable to commit config parameters to file", e);
-        }
-        initializeDatabase(data);
-
-        reinitSubsystems();
-
+        logger.debug("=== Configure CA Cert Chain ===");
         configureCACertChain(data, domainXML);
+    }
 
-        Collection<Cert> certs = new ArrayList<Cert>();
-        processCerts(data, certList, certs);
-        handleCerts(certs);
-        response.setSystemCerts(SystemCertDataFactory.create(certs));
+    @Override
+    public void setupDatabase(ConfigurationRequest request) throws Exception {
 
-        // backup keys
-        logger.debug("=== Backup Keys ===");
-        if (data.getBackupKeys().equals("true")) {
-            backupKeys(data);
-        }
+        logger.debug("SystemConfigService: setupDatabase()");
 
-        // configure admin
-        logger.debug("=== Admin Configuration ===");
-        if (!data.isClone()) {
-            configureAdministrator(data, response);
-        }
-
-        // create or update security domain
-        logger.debug("=== Finalization ===");
-        setupSecurityDomain(data);
-        setupDBUser(data);
-        finalizeConfiguration(data);
-
-        cs.putInteger("cs.state", 1);
-
-        // update serial numbers for clones
-
-        // save some variables, remove remaining preops
         try {
+            validatePin(request.getPin());
+
+            if (csState.equals("1")) {
+                throw new BadRequestException("System already configured");
+            }
+
+            configureDatabase(request);
+            cs.commit(false);
+
+            initializeDatabase(request);
+            reinitSubsystems();
+
+        } catch (PKIException e) { // normal response
+            logger.error("Configuration failed: " + e.getMessage());
+            throw e;
+
+        } catch (Throwable e) { // unexpected error
+            logger.error("Configuration failed: " + e.getMessage(), e);
+            throw e;
+        }
+    }
+
+    @Override
+    public ConfigurationResponse configureCerts(ConfigurationRequest request) throws Exception {
+
+        logger.debug("SystemConfigService: configureCerts()");
+
+        try {
+            validatePin(request.getPin());
+
+            if (csState.equals("1")) {
+                throw new BadRequestException("System already configured");
+            }
+
+            ConfigurationResponse response = new ConfigurationResponse();
+
+            logger.debug("=== Process Certs ===");
+            Collection<Cert> certs = new ArrayList<Cert>();
+            processCerts(request, certs);
+
+            response.setSystemCerts(SystemCertDataFactory.create(certs));
+
+            return response;
+
+        } catch (PKIException e) { // normal response
+            logger.error("Configuration failed: " + e.getMessage());
+            throw e;
+
+        } catch (Throwable e) { // unexpected error
+            logger.error("Configuration failed: " + e.getMessage(), e);
+            throw e;
+        }
+    }
+
+    @Override
+    public AdminSetupResponse setupAdmin(AdminSetupRequest request) throws Exception {
+
+        logger.debug("SystemConfigService: setupAdmin()");
+
+        try {
+            validatePin(request.getPin());
+
+            if (csState.equals("1")) {
+                throw new BadRequestException("System already configured");
+            }
+
+            if (StringUtils.isEmpty(request.getAdminUID())) {
+                throw new BadRequestException("Missing admin UID");
+            }
+
+            if (StringUtils.isEmpty(request.getAdminPassword())) {
+                throw new BadRequestException("Missing admin password");
+            }
+
+            if (StringUtils.isEmpty(request.getAdminEmail())) {
+                throw new BadRequestException("Missing admin email");
+            }
+
+            if (StringUtils.isEmpty(request.getAdminName())) {
+                throw new BadRequestException("Missing admin name");
+            }
+
+            boolean importAdminCert = Boolean.parseBoolean(request.getImportAdminCert());
+
+            if (importAdminCert) {
+                if (StringUtils.isEmpty(request.getAdminCert())) {
+                    throw new BadRequestException("Missing admin certificate");
+                }
+
+            } else {
+                if (StringUtils.isEmpty(request.getAdminCertRequest())) {
+                    throw new BadRequestException("Missing admin certificate request");
+                }
+
+                if (StringUtils.isEmpty(request.getAdminCertRequestType())) {
+                    throw new BadRequestException("Missing admin certificate request type");
+                }
+
+                if (StringUtils.isEmpty(request.getAdminSubjectDN())) {
+                    throw new BadRequestException("Missing admin subject DN");
+                }
+            }
+
+            AdminSetupResponse response = new AdminSetupResponse();
+
+            createAdminUser(request);
+
+            X509CertImpl cert = createAdminCert(request);
+            updateAdminUserCert(request, cert);
+
+            String b64cert = Utils.base64encodeSingleLine(cert.getEncoded());
+            logger.debug("SystemConfigService: admin cert: " + b64cert);
+
+            SystemCertData adminCert = response.getAdminCert();
+            adminCert.setCert(b64cert);
+
+            return response;
+
+        } catch (PKIException e) { // normal response
+            logger.error("Configuration failed: " + e.getMessage());
+            throw e;
+
+        } catch (Throwable e) { // unexpected error
+            logger.error("Configuration failed: " + e.getMessage(), e);
+            throw e;
+        }
+    }
+
+    @Override
+    public void finalizeConfiguration(ConfigurationRequest request) throws Exception {
+
+        logger.debug("SystemConfigService: finalizeConfiguration()");
+
+        try {
+            validatePin(request.getPin());
+
+            if (csState.equals("1")) {
+                throw new BadRequestException("System already configured");
+            }
+
+            cs.putInteger("cs.state", 1);
             ConfigurationUtils.removePreopConfigEntries();
-        } catch (EBaseException e) {
-            logger.error("Errors when removing preop config entries: " + e.getMessage(), e);
-            throw new PKIException("Errors when removing preop config entries: " + e, e);
-        }
 
-        response.setStatus(SUCCESS);
-    }
+        } catch (PKIException e) { // normal response
+            logger.error("Configuration failed: " + e.getMessage());
+            throw e;
 
-    private void setupDBUser(ConfigurationRequest data) {
-        try {
-            if (!data.getSharedDB()) ConfigurationUtils.setupDBUser();
-        } catch (Exception e) {
-            logger.error("Errors in creating or updating dbuser: " + e.getMessage(), e);
-            throw new PKIException("Errors in creating or updating dbuser: " + e);
+        } catch (Throwable e) { // unexpected error
+            logger.error("Configuration failed: " + e.getMessage(), e);
+            throw e;
         }
     }
 
-    private void setupSecurityDomain(ConfigurationRequest data) {
+    @Override
+    public void setupDatabaseUser(ConfigurationRequest request) throws Exception {
+
+        logger.debug("SystemConfigService: setupDatabaseUser()");
+
         try {
-            String securityDomainType = data.getSecurityDomainType();
+            validatePin(request.getPin());
+
+            if (csState.equals("1")) {
+                throw new BadRequestException("System already configured");
+            }
+
+            if (!request.getSharedDB()) ConfigurationUtils.setupDBUser();
+
+        } catch (PKIException e) { // normal response
+            logger.error("Configuration failed: " + e.getMessage());
+            throw e;
+
+        } catch (Throwable e) { // unexpected error
+            logger.error("Configuration failed: " + e.getMessage(), e);
+            throw e;
+        }
+    }
+
+    @Override
+    public void setupSecurityDomain(ConfigurationRequest request) throws Exception {
+
+        logger.debug("SystemConfigService: setupSecurityDomain()");
+
+        try {
+            validatePin(request.getPin());
+
+            if (csState.equals("1")) {
+                throw new BadRequestException("System already configured");
+            }
+
+            String securityDomainType = request.getSecurityDomainType();
             if (securityDomainType.equals(ConfigurationRequest.NEW_DOMAIN)) {
                 logger.debug("Creating new security domain");
                 ConfigurationUtils.createSecurityDomain();
@@ -231,7 +364,7 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
 
                 // switch out security domain parameters from issuing CA security domain
                 // to subordinate CA hosted security domain
-                cs.putString("securitydomain.name", data.getSubordinateSecurityDomainName());
+                cs.putString("securitydomain.name", request.getSubordinateSecurityDomainName());
                 cs.putString("securitydomain.host", CMS.getEENonSSLHost());
                 cs.putString("securitydomain.httpport", CMS.getEENonSSLPort());
                 cs.putString("securitydomain.httpsagentport", CMS.getAgentPort());
@@ -245,36 +378,29 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
             cs.putString("service.securityDomainPort", CMS.getAgentPort());
             cs.putString("securitydomain.store", "ldap");
             cs.commit(false);
-        } catch (Exception e) {
-            logger.error("Error while updating security domain: " + e.getMessage(), e);
-            throw new PKIException("Error while updating security domain: " + e);
+
+        } catch (PKIException e) { // normal response
+            logger.error("Configuration failed: " + e.getMessage());
+            throw e;
+
+        } catch (Throwable e) { // unexpected error
+            logger.error("Configuration failed: " + e.getMessage(), e);
+            throw e;
         }
     }
 
-    public Collection<String> getCertList(ConfigurationRequest request) {
-
-        Collection<String> certList = new ArrayList<String>();
-
-        try {
-            String value = cs.getString("preop.cert.list");
-            certList.addAll(Arrays.asList(value.split(",")));
-
-        } catch (Exception e) {
-            logger.error("Unable to get certList from config file: " + e.getMessage(), e);
-            throw new PKIException("Unable to get certList from config file: " + e, e);
-        }
-
-        return certList;
-    }
-
     public void processCerts(
             ConfigurationRequest request,
-            Collection<String> certList,
             Collection<Cert> certs) throws Exception {
 
+        CMSEngine engine = (CMSEngine) CMS.getCMSEngine();
+
         boolean generateServerCert = !request.getGenerateServerCert().equalsIgnoreCase("false");
         boolean generateSubsystemCert = request.getGenerateSubsystemCert();
 
+        String value = cs.getString("preop.cert.list");
+        String[] certList = value.split(",");
+
         for (String tag : certList) {
 
             logger.debug("=== Processing " + tag + " cert ===");
@@ -299,7 +425,7 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
                 updateConfiguration(request, certData, "subsystem");
 
                 // get parameters needed for cloning
-                updateCloneConfiguration(certData, "subsystem");
+                updateCloneConfiguration(request, certData, "subsystem");
                 continue;
             }
 
@@ -312,6 +438,13 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
                     certData);
 
             certs.add(cert);
+
+            String subsystem = cert.getSubsystem();
+            ConfigurationUtils.handleCert(cert);
+
+            if (tag.equals("signing") && subsystem.equals("ca")) {
+                engine.reinit(ICertificateAuthority.ID);
+            }
         }
 
         // make sure to commit changes here for step 1
@@ -328,10 +461,16 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
             ) throws Exception {
 
         String tag = certData.getTag();
-        String token = certData.getToken();
-
         logger.debug("SystemConfigService.processKeyPair(" + tag + ")");
 
+        String tokenName = certData.getToken();
+        if (StringUtils.isEmpty(tokenName)) {
+            tokenName = request.getToken();
+        }
+
+        logger.debug("SystemConfigService: token: " + tokenName);
+        CryptoToken token = CryptoUtil.getKeyStorageToken(tokenName);
+
         String keytype = certData.getKeyType() != null ? certData.getKeyType() : "rsa";
 
         String keyalgorithm = certData.getKeyAlgorithm();
@@ -361,7 +500,7 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
         try {
 
             logger.debug("SystemConfigService: loading existing key pair from NSS database");
-            KeyPair pair = ConfigurationUtils.loadKeyPair(certData.getNickname(), certData.getToken());
+            KeyPair pair = ConfigurationUtils.loadKeyPair(certData.getNickname(), tokenName);
 
             logger.debug("SystemConfigService: storing key pair into CS.cfg");
             ConfigurationUtils.storeKeyPair(cs, tag, pair);
@@ -395,6 +534,9 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
 
         String tag = certData.getTag();
         String tokenName = certData.getToken();
+        if (StringUtils.isEmpty(tokenName)) {
+            tokenName = request.getToken();
+        }
 
         logger.debug("SystemConfigService.processCert(" + tag + ")");
 
@@ -414,13 +556,14 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
             fullName = nickname;
         }
 
-        logger.debug("SystemConfigService: checking " + tag + " cert in NSS database");
+        logger.debug("SystemConfigService: loading " + tag + " cert: " + fullName);
 
         CryptoManager cm = CryptoManager.getInstance();
         X509Certificate x509Cert;
         try {
             x509Cert = cm.findCertByNickname(fullName);
         } catch (ObjectNotFoundException e) {
+            logger.warn("SystemConfigService: cert not found: " + fullName);
             x509Cert = null;
         }
 
@@ -500,29 +643,16 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
         return cert;
     }
 
-    public void handleCerts(Collection<Cert> certs) throws Exception {
-
-        CMSEngine engine = (CMSEngine) CMS.getCMSEngine();
-
-        for (Cert cert : certs) {
-
-            String tag = cert.getCertTag();
-            String subsystem = cert.getSubsystem();
-
-            logger.debug("=== Handling " + tag + " cert ===");
-
-            ConfigurationUtils.handleCert(cert);
-
-            if (tag.equals("signing") && subsystem.equals("ca")) {
-                engine.reinit(ICertificateAuthority.ID);
-            }
-        }
-    }
-
-    private void updateCloneConfiguration(SystemCertData cdata, String tag) throws NotInitializedException,
+    private void updateCloneConfiguration(
+            ConfigurationRequest request,
+            SystemCertData cdata,
+            String tag) throws NotInitializedException,
             ObjectNotFoundException, TokenException {
 
         String tokenName = cdata.getToken();
+        if (StringUtils.isEmpty(tokenName)) {
+            tokenName = request.getToken();
+        }
 
         // TODO - some of these parameters may only be valid for RSA
         CryptoManager cryptoManager = CryptoManager.getInstance();
@@ -562,90 +692,140 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
     }
 
     private void updateConfiguration(ConfigurationRequest data, SystemCertData cdata, String tag) {
-        if (CryptoUtil.isInternalToken(cdata.getToken())) {
+        String tokenName = cdata.getToken();
+        if (StringUtils.isEmpty(tokenName)) {
+            tokenName = data.getToken();
+        }
+
+        if (CryptoUtil.isInternalToken(tokenName)) {
             cs.putString(csSubsystem + ".cert." + tag + ".nickname", cdata.getNickname());
         } else {
-            cs.putString(csSubsystem + ".cert." + tag + ".nickname", cdata.getToken() +
+            cs.putString(csSubsystem + ".cert." + tag + ".nickname", tokenName +
                     ":" + cdata.getNickname());
         }
 
         cs.putString(csSubsystem + "." + tag + ".nickname", cdata.getNickname());
-        cs.putString(csSubsystem + "." + tag + ".tokenname", cdata.getToken());
+        cs.putString(csSubsystem + "." + tag + ".tokenname", StringUtils.defaultString(tokenName));
         cs.putString(csSubsystem + "." + tag + ".dn", cdata.getSubjectDN());
     }
 
-    public void backupKeys(ConfigurationRequest request) {
+    @Override
+    public void backupKeys(KeyBackupRequest request) throws Exception {
+
+        logger.debug("SystemConfigService: backupKeys()");
+
         try {
+            validatePin(request.getPin());
+
+            if (csState.equals("1")) {
+                throw new BadRequestException("System already configured");
+            }
+
+            if (request.getBackupFile() == null || request.getBackupFile().length() <= 0) {
+                //TODO: also check for valid path, perhaps by touching file there
+                throw new BadRequestException("Invalid key backup file name");
+            }
+
+            if (request.getBackupPassword() == null || request.getBackupPassword().length() < 8) {
+                throw new BadRequestException("Key backup password must be at least 8 characters");
+            }
+
             ConfigurationUtils.backupKeys(request.getBackupPassword(), request.getBackupFile());
-        } catch (Exception e) {
-            logger.error("Error in creating pkcs12 to backup keys and certs: " + e.getMessage(), e);
-            throw new PKIException("Error in creating pkcs12 to backup keys and certs: " + e);
+
+        } catch (PKIException e) { // normal response
+            logger.error("Configuration failed: " + e.getMessage());
+            throw e;
+
+        } catch (Throwable e) { // unexpected error
+            logger.error("Configuration failed: " + e.getMessage(), e);
+            throw e;
         }
     }
 
-    public void finalizeConfiguration(ConfigurationRequest request) {
-    }
-
-    public void configureAdministrator(ConfigurationRequest data, ConfigurationResponse response)
-            throws Exception {
-
-        X509CertImpl admincerts[] = new X509CertImpl[1];
-        ConfigurationUtils.createAdmin(data.getAdminUID(), data.getAdminEmail(),
-                data.getAdminName(), data.getAdminPassword());
+    public X509CertImpl createAdminCert(AdminSetupRequest data) throws Exception {
 
         if (data.getImportAdminCert().equalsIgnoreCase("true")) {
 
-            String b64 = CryptoUtil.stripCertBrackets(data.getAdminCert().trim());
-            b64 = CryptoUtil.normalizeCertStr(b64);
+            String cert = data.getAdminCert();
+            logger.info("SystemConfigService: Importing admin cert: " + cert);
             // standalone admin cert is already stored into CS.cfg by configuration.py
 
-            // Convert Admin Cert to X509CertImpl
+            String b64 = CryptoUtil.stripCertBrackets(cert.trim());
+            b64 = CryptoUtil.normalizeCertStr(b64);
             byte[] b = CryptoUtil.base64Decode(b64);
-            admincerts[0] = new X509CertImpl(b);
 
-        } else {
-
-            String adminSubjectDN = data.getAdminSubjectDN();
-            cs.putString("preop.cert.admin.dn", adminSubjectDN);
-
-            if (csType.equals("CA")) {
-                ConfigurationUtils.createAdminCertificate(data.getAdminCertRequest(),
-                        data.getAdminCertRequestType(), adminSubjectDN);
-
-                String serialno = cs.getString("preop.admincert.serialno.0");
-                ICertificateAuthority ca = (ICertificateAuthority) CMS.getSubsystem(ICertificateAuthority.ID);
-                ICertificateRepository repo = ca.getCertificateRepository();
-                admincerts[0] = repo.getX509Certificate(new BigInteger(serialno, 16));
-
-            } else {
-                String type = cs.getString("preop.ca.type", "");
-                String ca_hostname = "";
-                int ca_port = -1;
-                if (type.equals("sdca")) {
-                    ca_hostname = cs.getString("preop.ca.hostname");
-                    ca_port = cs.getInteger("preop.ca.httpsport");
-                } else {
-                    ca_hostname = cs.getString("securitydomain.host", "");
-                    ca_port = cs.getInteger("securitydomain.httpseeport");
-                }
-                logger.debug("Calculated admin cert profile: " + data.getAdminProfileID());
-                String b64 = ConfigurationUtils.submitAdminCertRequest(ca_hostname, ca_port,
-                        data.getAdminProfileID(), data.getAdminCertRequestType(),
-                        data.getAdminCertRequest(), adminSubjectDN);
-                b64 = CryptoUtil.stripCertBrackets(b64.trim());
-                byte[] b = CryptoUtil.base64Decode(b64);
-                admincerts[0] = new X509CertImpl(b);
-            }
+            return new X509CertImpl(b);
         }
 
+        String adminSubjectDN = data.getAdminSubjectDN();
+        cs.putString("preop.cert.admin.dn", adminSubjectDN);
+
+        if (csType.equals("CA")) {
+
+            logger.info("SystemConfigService: Generating admin cert");
+
+            ConfigurationUtils.createAdminCertificate(data.getAdminCertRequest(),
+                    data.getAdminCertRequestType(), adminSubjectDN);
+
+            String serialno = cs.getString("preop.admincert.serialno.0");
+            ICertificateAuthority ca = (ICertificateAuthority) CMS.getSubsystem(ICertificateAuthority.ID);
+            ICertificateRepository repo = ca.getCertificateRepository();
+
+            return repo.getX509Certificate(new BigInteger(serialno, 16));
+        }
+
+        logger.info("SystemConfigService: Requesting admin cert from CA");
+
+        String type = cs.getString("preop.ca.type", "");
+        String ca_hostname = "";
+        int ca_port = -1;
+
+        if (type.equals("sdca")) {
+            ca_hostname = cs.getString("preop.ca.hostname");
+            ca_port = cs.getInteger("preop.ca.httpsport");
+        } else {
+            ca_hostname = cs.getString("securitydomain.host", "");
+            ca_port = cs.getInteger("securitydomain.httpseeport");
+        }
+
+        String keyType = data.getAdminKeyType();
+        String profileID;
+
+        if ("ecc".equalsIgnoreCase(keyType)) {
+            profileID = ECC_INTERNAL_ADMIN_CERT_PROFILE;
+        } else { // rsa
+            profileID = RSA_INTERNAL_ADMIN_CERT_PROFILE;
+        }
+
+        logger.debug("SystemConfigService: profile: " + profileID);
+
+        String b64 = ConfigurationUtils.submitAdminCertRequest(ca_hostname, ca_port,
+                profileID, data.getAdminCertRequestType(),
+                data.getAdminCertRequest(), adminSubjectDN);
+
+        b64 = CryptoUtil.stripCertBrackets(b64.trim());
+        byte[] b = CryptoUtil.base64Decode(b64);
+
+        return new X509CertImpl(b);
+    }
+
+    public void createAdminUser(AdminSetupRequest request) throws Exception {
+
+        ConfigurationUtils.createAdmin(request.getAdminUID(), request.getAdminEmail(),
+                request.getAdminName(), request.getAdminPassword());
+
         CMSEngine engine = (CMSEngine) CMS.getCMSEngine();
         engine.reinit(IUGSubsystem.ID);
+    }
+
+    public void updateAdminUserCert(AdminSetupRequest request, X509CertImpl adminCert) throws Exception {
+
+        X509CertImpl[] adminCerts = new X509CertImpl[] { adminCert };
 
         IUGSubsystem ug = (IUGSubsystem) CMS.getSubsystem(IUGSubsystem.ID);
-        IUser user = ug.getUser(data.getAdminUID());
-        user.setX509Certificates(admincerts);
+        IUser user = ug.getUser(request.getAdminUID());
+        user.setX509Certificates(adminCerts);
         ug.addUserCert(user);
-        response.setAdminCert(admincerts[0]);
     }
 
     public void configureDatabase(ConfigurationRequest data) {
@@ -721,15 +901,13 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
                 replicationPassword = Integer.toString(random.nextInt());
             }
 
-            IConfigStore psStore = null;
-            String passwordFile = null;
-            passwordFile = cs.getString("passwordFile");
-            psStore = CMS.createFileConfigStore(passwordFile);
-            psStore.putString("internaldb", data.getBindpwd());
-            if (StringUtils.isEmpty(psStore.getString("replicationdb", null))) {
-                psStore.putString("replicationdb", replicationPassword);
+            IPasswordStore psStore = null;
+            psStore = CMS.getPasswordStore();
+            psStore.putPassword("internaldb", data.getBindpwd());
+            if (StringUtils.isEmpty(psStore.getPassword("replicationdb", 0))) {
+                psStore.putPassword("replicationdb", replicationPassword);
             }
-            psStore.commit(false);
+            psStore.commit();
 
             ConfigurationUtils.enableUSNPlugin();
             ConfigurationUtils.populateDB();
@@ -814,7 +992,8 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
                     cs.putInteger("preop.ca.httpsadminport", admin_port);
 
                     if (!data.isClone() && !data.getSystemCertsImported()) {
-                        ConfigurationUtils.importCertChain(host, admin_port, "/ca/admin/ca/getCertChain", "ca");
+                        String certchain = ConfigurationUtils.getCertChain(host, admin_port, "/ca/admin/ca/getCertChain");
+                        ConfigurationUtils.importCertChain(certchain, "ca");
                     }
 
                     if (csType.equals("CA")) {
@@ -828,7 +1007,11 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
         }
     }
 
-    private void configureClone(ConfigurationRequest data, Collection<String> certList, String token, String domainXML) throws Exception {
+    private void configureClone(ConfigurationRequest data, String token, String domainXML) throws Exception {
+
+        String value = cs.getString("preop.cert.list");
+        String[] certList = value.split(",");
+
         for (String tag : certList) {
             if (tag.equals("sslserver")) {
                 cs.putBoolean("preop.cert." + tag + ".enable", true);
@@ -854,8 +1037,10 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
             logger.debug("SystemConfigService: import certificate chain from master");
             int masterAdminPort = ConfigurationUtils.getPortFromSecurityDomain(domainXML,
                     masterHost, masterPort, "CA", "SecurePort", "SecureAdminPort");
-            ConfigurationUtils.importCertChain(masterHost, masterAdminPort,
-                    "/ca/admin/ca/getCertChain", "clone");
+
+            String certchain = ConfigurationUtils.getCertChain(masterHost, masterAdminPort,
+                    "/ca/admin/ca/getCertChain");
+            ConfigurationUtils.importCertChain(certchain, "clone");
         }
 
         logger.debug("SystemConfigService: get configuration entries from master");
@@ -938,7 +1123,8 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
 
         if (!data.getSystemCertsImported()) {
             logger.debug("Getting security domain cert chain");
-            ConfigurationUtils.importCertChain(host, port, "/ca/admin/ca/getCertChain", "securitydomain");
+            String certchain = ConfigurationUtils.getCertChain(host, port, "/ca/admin/ca/getCertChain");
+            ConfigurationUtils.importCertChain(certchain, "securitydomain");
         }
 
         getInstallToken(data, host, port);
@@ -998,7 +1184,7 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
     }
 
     public void configureSubsystem(ConfigurationRequest request,
-            Collection<String> certList, String token, String domainXML) throws Exception {
+            String token, String domainXML) throws Exception {
 
         cs.putString("preop.subsystem.name", request.getSubsystemName());
 
@@ -1010,50 +1196,27 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
         } else {
             cs.putString("preop.subsystem.select", "clone");
             cs.putString("subsystem.select", "Clone");
-            configureClone(request, certList, token, domainXML);
+            configureClone(request, token, domainXML);
         }
     }
 
-    public void loginToken(ConfigurationRequest data, String token) {
-        cs.putString("preop.module.token", token);
-
-        if (!CryptoUtil.isInternalToken(token)) {
-            try {
-                logger.debug("Logging into token " + token);
-                CryptoToken ctoken = CryptoUtil.getKeyStorageToken(token);
-                String tokenpwd = data.getTokenPassword();
-                ConfigurationUtils.loginToken(ctoken, tokenpwd);
-
-            } catch (NotInitializedException e) {
-                logger.error("Token is not initialized: " + e.getMessage(), e);
-                throw new PKIException("Token is not initialized: " + e, e);
-
-            } catch (NoSuchTokenException e) {
-                logger.error("No such key storage token: " + token, e);
-                throw new BadRequestException("No such key storage token: " + token, e);
-
-            } catch (TokenException e) {
-                logger.error("Token Exception: " + e.getMessage(), e);
-                throw new PKIException("Token Exception: " + e, e);
-
-            } catch (IncorrectPasswordException e) {
-                throw new BadRequestException("Incorrect password for token " + token, e);
-            }
-        }
+    public void configureToken(ConfigurationRequest data, String token) {
+        cs.putString("preop.module.token", StringUtils.defaultString(token));
     }
 
-    private void validateRequest(ConfigurationRequest data) throws Exception {
+    private void validatePin(String pin) throws Exception {
 
-        // validate installation pin
-        String pin = data.getPin();
         if (pin == null) {
-            throw new BadRequestException("No preop pin provided");
+            throw new BadRequestException("Missing configuration PIN");
         }
 
         String preopPin = cs.getString("preop.pin");
         if (!preopPin.equals(pin)) {
-            throw new BadRequestException("Incorrect pin provided");
+            throw new BadRequestException("Invalid configuration PIN");
         }
+    }
+
+    private void validateRequest(ConfigurationRequest data) throws Exception {
 
         // validate legal stand-alone PKI subsystems
         if (data.getStandAlone()) {
@@ -1213,62 +1376,10 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
             data.setReplicateSchema("true");
         }
 
-        if ((data.getBackupKeys() != null) && data.getBackupKeys().equals("true")) {
-            if (! data.getToken().equals(CryptoUtil.INTERNAL_TOKEN_FULL_NAME)) {
-                throw new BadRequestException("HSMs cannot publish private keys to PKCS #12 files");
-            }
-
-            if ((data.getBackupFile() == null) || (data.getBackupFile().length()<=0)) {
-                //TODO: also check for valid path, perhaps by touching file there
-                throw new BadRequestException("Invalid key backup file name");
-            }
-
-            if ((data.getBackupPassword() == null) || (data.getBackupPassword().length()<8)) {
-                throw new BadRequestException("key backup password must be at least 8 characters");
-            }
-        } else {
-            data.setBackupKeys("false");
-        }
-
         if (csType.equals("CA") && (data.getHierarchy() == null)) {
             throw new BadRequestException("Hierarchy is required for CA, not provided");
         }
 
-        if (!data.isClone()) {
-            if ((data.getAdminUID() == null) || (data.getAdminUID().length() == 0)) {
-                throw new BadRequestException("Admin UID not provided");
-            }
-            if ((data.getAdminPassword() == null) || (data.getAdminPassword().length() == 0)) {
-                throw new BadRequestException("Admin Password not provided");
-            }
-            if ((data.getAdminEmail() == null) || (data.getAdminEmail().length() == 0)) {
-                throw new BadRequestException("Admin UID not provided");
-            }
-            if ((data.getAdminName() == null) || (data.getAdminName().length() == 0)) {
-                throw new BadRequestException("Admin name not provided");
-            }
-
-            if (data.getImportAdminCert() == null) {
-                data.setImportAdminCert("false");
-            }
-
-            if (data.getImportAdminCert().equalsIgnoreCase("true")) {
-                if (data.getAdminCert() == null) {
-                    throw new BadRequestException("Admin Cert not provided");
-                }
-            } else {
-                if ((data.getAdminCertRequest() == null) || (data.getAdminCertRequest().length() == 0)) {
-                    throw new BadRequestException("Admin cert request not provided");
-                }
-                if ((data.getAdminCertRequestType() == null) || (data.getAdminCertRequestType().length() == 0)) {
-                    throw new BadRequestException("Admin cert request type not provided");
-                }
-                if ((data.getAdminSubjectDN() == null) || (data.getAdminSubjectDN().length() == 0)) {
-                    throw new BadRequestException("Admin subjectDN not provided");
-                }
-            }
-        }
-
         if (data.getGenerateServerCert() == null) {
             data.setGenerateServerCert("true");
         }
