@@ -23,12 +23,8 @@ import java.io.File;
 import java.io.FileReader;
 import java.io.IOException;
 import java.math.BigInteger;
-import java.security.NoSuchAlgorithmException;
 import java.security.Security;
 import java.security.SignatureException;
-import java.security.cert.Certificate;
-import java.security.cert.CertificateEncodingException;
-import java.security.cert.X509CRL;
 import java.security.cert.X509Certificate;
 import java.text.MessageFormat;
 import java.util.ArrayList;
@@ -50,68 +46,43 @@ import javax.servlet.http.HttpServlet;
 
 import org.apache.commons.lang.StringUtils;
 import org.apache.xerces.parsers.DOMParser;
-import org.dogtagpki.legacy.core.policy.GeneralNameUtil;
-import org.dogtagpki.legacy.policy.IGeneralNameAsConstraintsConfig;
-import org.dogtagpki.legacy.policy.IGeneralNamesAsConstraintsConfig;
-import org.dogtagpki.legacy.policy.IGeneralNamesConfig;
-import org.dogtagpki.legacy.policy.ISubjAltNameConfig;
-import org.mozilla.jss.CertificateUsage;
 import org.mozilla.jss.CryptoManager;
 import org.mozilla.jss.crypto.CryptoToken;
 import org.mozilla.jss.crypto.ObjectNotFoundException;
 import org.mozilla.jss.crypto.PrivateKey;
 import org.mozilla.jss.crypto.Signature;
 import org.mozilla.jss.crypto.SignatureAlgorithm;
-import org.mozilla.jss.util.PasswordCallback;
 import org.w3c.dom.Element;
 import org.w3c.dom.NodeList;
 
 import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.apps.ICMSEngine;
-import com.netscape.certsrv.apps.ICommandQueue;
 import com.netscape.certsrv.authentication.ISharedToken;
 import com.netscape.certsrv.authority.IAuthority;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IArgBlock;
-import com.netscape.certsrv.base.ICRLPrettyPrint;
-import com.netscape.certsrv.base.ICertPrettyPrint;
 import com.netscape.certsrv.base.IConfigStore;
-import com.netscape.certsrv.base.IExtPrettyPrint;
-import com.netscape.certsrv.base.IPrettyPrintFormat;
 import com.netscape.certsrv.base.ISecurityDomainSessionTable;
 import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.certsrv.base.ITimeSource;
 import com.netscape.certsrv.base.SessionContext;
-import com.netscape.certsrv.ca.ICRLIssuingPoint;
 import com.netscape.certsrv.ca.ICertificateAuthority;
 import com.netscape.certsrv.common.Constants;
 import com.netscape.certsrv.common.ICMSRequest;
 import com.netscape.certsrv.common.NameValuePairs;
-import com.netscape.certsrv.connector.IHttpConnection;
-import com.netscape.certsrv.connector.IPKIMessage;
 import com.netscape.certsrv.connector.IRemoteAuthority;
-import com.netscape.certsrv.connector.IRequestEncoder;
 import com.netscape.certsrv.connector.IResender;
 import com.netscape.certsrv.dbs.certdb.ICertificateRepository;
 import com.netscape.certsrv.dbs.crldb.ICRLIssuingPointRecord;
 import com.netscape.certsrv.dbs.repository.IRepositoryRecord;
 import com.netscape.certsrv.kra.IKeyRecoveryAuthority;
-import com.netscape.certsrv.ldap.ELdapException;
-import com.netscape.certsrv.ldap.ILdapAuthInfo;
-import com.netscape.certsrv.ldap.ILdapConnFactory;
-import com.netscape.certsrv.ldap.ILdapConnInfo;
 import com.netscape.certsrv.logging.ConsoleError;
 import com.netscape.certsrv.logging.ELogException;
-import com.netscape.certsrv.logging.IAuditor;
 import com.netscape.certsrv.logging.ILogEvent;
 import com.netscape.certsrv.logging.ILogEventListener;
 import com.netscape.certsrv.logging.ILogQueue;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.logging.SystemEvent;
-import com.netscape.certsrv.notification.IEmailFormProcessor;
-import com.netscape.certsrv.notification.IEmailResolver;
-import com.netscape.certsrv.notification.IEmailResolverKeys;
-import com.netscape.certsrv.notification.IEmailTemplate;
 import com.netscape.certsrv.notification.IMailNotification;
 import com.netscape.certsrv.password.IPasswordCheck;
 import com.netscape.certsrv.profile.IEnrollProfile;
@@ -127,39 +98,22 @@ import com.netscape.cmscore.authorization.AuthzSubsystem;
 import com.netscape.cmscore.base.ArgBlock;
 import com.netscape.cmscore.base.FileConfigStore;
 import com.netscape.cmscore.base.SubsystemRegistry;
-import com.netscape.cmscore.cert.CertPrettyPrint;
-import com.netscape.cmscore.cert.CertUtils;
-import com.netscape.cmscore.cert.CrlCachePrettyPrint;
-import com.netscape.cmscore.cert.CrlPrettyPrint;
-import com.netscape.cmscore.cert.ExtPrettyPrint;
 import com.netscape.cmscore.cert.OidLoaderSubsystem;
 import com.netscape.cmscore.cert.X500NameSubsystem;
-import com.netscape.cmscore.connector.HttpConnection;
-import com.netscape.cmscore.connector.HttpPKIMessage;
-import com.netscape.cmscore.connector.HttpRequestEncoder;
 import com.netscape.cmscore.connector.Resender;
 import com.netscape.cmscore.dbs.CRLIssuingPointRecord;
 import com.netscape.cmscore.dbs.CertificateRepository;
 import com.netscape.cmscore.dbs.DBSubsystem;
 import com.netscape.cmscore.dbs.RepositoryRecord;
 import com.netscape.cmscore.jobs.JobsScheduler;
-import com.netscape.cmscore.ldapconn.LdapAnonConnFactory;
-import com.netscape.cmscore.ldapconn.LdapAuthInfo;
-import com.netscape.cmscore.ldapconn.LdapBoundConnFactory;
 import com.netscape.cmscore.ldapconn.LdapBoundConnection;
 import com.netscape.cmscore.ldapconn.LdapConnInfo;
 import com.netscape.cmscore.ldapconn.PKISocketFactory;
-import com.netscape.cmscore.logging.Auditor;
 import com.netscape.cmscore.logging.LogSubsystem;
-import com.netscape.cmscore.notification.EmailFormProcessor;
-import com.netscape.cmscore.notification.EmailResolverKeys;
-import com.netscape.cmscore.notification.EmailTemplate;
-import com.netscape.cmscore.notification.ReqCertSANameEmailResolver;
 import com.netscape.cmscore.registry.PluginRegistry;
 import com.netscape.cmscore.request.CertRequestConstants;
 import com.netscape.cmscore.request.RequestSubsystem;
 import com.netscape.cmscore.security.JssSubsystem;
-import com.netscape.cmscore.security.PWCBsdr;
 import com.netscape.cmscore.security.PWsdrCache;
 import com.netscape.cmscore.session.LDAPSecurityDomainSessionTable;
 import com.netscape.cmscore.session.SecurityDomainSessionTable;
@@ -168,7 +122,6 @@ import com.netscape.cmscore.time.SimpleTimeSource;
 import com.netscape.cmscore.usrgrp.UGSubsystem;
 import com.netscape.cmscore.util.Debug;
 import com.netscape.cmsutil.crypto.CryptoUtil;
-import com.netscape.cmsutil.net.ISocketFactory;
 import com.netscape.cmsutil.password.IPasswordStore;
 import com.netscape.cmsutil.password.NuxwdogPasswordStore;
 import com.netscape.cmsutil.util.Cert;
@@ -177,19 +130,12 @@ import com.netscape.cmsutil.util.Utils;
 import netscape.ldap.LDAPConnection;
 import netscape.ldap.LDAPException;
 import netscape.ldap.LDAPSSLSocketFactoryExt;
-import netscape.ldap.LDAPSocketFactory;
-import netscape.security.extensions.CertInfo;
 import netscape.security.pkcs.ContentInfo;
 import netscape.security.pkcs.PKCS7;
 import netscape.security.pkcs.SignerInfo;
-import netscape.security.util.ObjectIdentifier;
 import netscape.security.x509.AlgorithmId;
 import netscape.security.x509.CertificateChain;
-import netscape.security.x509.Extension;
-import netscape.security.x509.GeneralName;
-import netscape.security.x509.X509CRLImpl;
 import netscape.security.x509.X509CertImpl;
-import netscape.security.x509.X509CertInfo;
 
 public class CMSEngine implements ICMSEngine {
 
@@ -209,6 +155,7 @@ public class CMSEngine implements ICMSEngine {
 
     public static final SubsystemRegistry mSSReg = SubsystemRegistry.getInstance();
 
+    public String name;
     public String instanceDir; /* path to instance <server-root>/cert-<instance-name> */
     private String instanceId;
     private int pid;
@@ -266,17 +213,15 @@ public class CMSEngine implements ICMSEngine {
     };
 
     private static final int PW_OK =0;
-    private static final int PW_BAD_SETUP = 1;
+    //private static final int PW_BAD_SETUP = 1;
     private static final int PW_INVALID_PASSWORD = 2;
     private static final int PW_CANNOT_CONNECT = 3;
     private static final int PW_NO_USER = 4;
     private static final int PW_MAX_ATTEMPTS = 3;
 
 
-    /**
-     * private constructor.
-     */
-    public CMSEngine() {
+    public CMSEngine(String name) {
+        this.name = name;
     }
 
     /**
@@ -459,7 +404,7 @@ public class CMSEngine implements ICMSEngine {
         String host = info.getHost();
         int port = info.getPort();
 
-        LDAPConnection conn = new LDAPConnection(getLDAPSocketFactory(info.getSecure()));
+        LDAPConnection conn = new LDAPConnection(new PKISocketFactory(info.getSecure()));
 
         logger.debug("testLDAPConnection connecting to " + host + ":" + port);
 
@@ -500,6 +445,9 @@ public class CMSEngine implements ICMSEngine {
      */
     public void init(ISubsystem owner, IConfigStore config)
             throws EBaseException {
+
+        logger.info("Initializing " + name + " subsystem");
+
         mOwner = owner;
         mConfig = config;
         int state = mConfig.getInteger("cs.state");
@@ -849,62 +797,12 @@ public class CMSEngine implements ICMSEngine {
         return info[ADMIN][PORT];
     }
 
-    public IHttpConnection getHttpConnection(IRemoteAuthority authority,
-            ISocketFactory factory) {
-        return new HttpConnection(authority, factory);
-    }
-
-    public IHttpConnection getHttpConnection(IRemoteAuthority authority,
-            ISocketFactory factory, int timeout) {
-        return new HttpConnection(authority, factory, timeout);
-    }
-
     public IResender getResender(IAuthority authority, String nickname,
             String clientCiphers,
             IRemoteAuthority remote, int interval) {
         return new Resender(authority, nickname, clientCiphers, remote, interval);
     }
 
-    public IPKIMessage getHttpPKIMessage() {
-        return new HttpPKIMessage();
-    }
-
-    public ILdapConnInfo getLdapConnInfo(IConfigStore config)
-            throws EBaseException, ELdapException {
-        return new LdapConnInfo(config);
-    }
-
-    public LDAPSSLSocketFactoryExt getLdapJssSSLSocketFactory(
-            String certNickname) {
-        return new PKISocketFactory(certNickname);
-    }
-
-    public LDAPSSLSocketFactoryExt getLdapJssSSLSocketFactory() {
-        return new PKISocketFactory(true);
-    }
-
-    public LDAPSocketFactory getLDAPSocketFactory(boolean secure) {
-        return new PKISocketFactory(secure);
-    }
-
-    public ILdapAuthInfo getLdapAuthInfo() {
-        return new LdapAuthInfo();
-    }
-
-    public ILdapConnFactory getLdapBoundConnFactory(String id)
-            throws ELdapException {
-        return new LdapBoundConnFactory(id);
-    }
-
-    public ILdapConnFactory getLdapAnonConnFactory(String id)
-            throws ELdapException {
-        return new LdapAnonConnFactory(id);
-    }
-
-    public IRequestEncoder getHttpRequestEncoder() {
-        return new HttpRequestEncoder();
-    }
-
     public Enumeration<String> getSubsystemNames() {
         return mSSReg.keys();
     }
@@ -1385,21 +1283,6 @@ public class CMSEngine implements ICMSEngine {
         mServerCertNickname = newName;
     }
 
-    public String getFingerPrint(Certificate cert)
-            throws CertificateEncodingException, NoSuchAlgorithmException {
-        return CertUtils.getFingerPrint(cert);
-    }
-
-    public String getFingerPrints(Certificate cert)
-            throws NoSuchAlgorithmException, CertificateEncodingException {
-        return CertUtils.getFingerPrints(cert);
-    }
-
-    public String getFingerPrints(byte[] certDer)
-            throws NoSuchAlgorithmException {
-        return CertUtils.getFingerPrints(certDer);
-    }
-
     public String getUserMessage(Locale locale, String msgID, String params[]) {
         // if locale is null, try to get it out from session context
         if (locale == null) {
@@ -1603,81 +1486,6 @@ public class CMSEngine implements ICMSEngine {
         return getLogMessage(msgID, params);
     }
 
-    public void getSubjAltNameConfigDefaultParams(String name,
-            Vector<String> params) {
-        GeneralNameUtil.SubjAltNameGN.getDefaultParams(name, params);
-    }
-
-    public void getSubjAltNameConfigExtendedPluginInfo(String name,
-            Vector<String> params) {
-        GeneralNameUtil.SubjAltNameGN.getExtendedPluginInfo(name, params);
-    }
-
-    public ISubjAltNameConfig createSubjAltNameConfig(String name, IConfigStore config, boolean isValueConfigured)
-            throws EBaseException {
-        return new GeneralNameUtil.SubjAltNameGN(name, config, isValueConfigured);
-    }
-
-    public GeneralName form_GeneralNameAsConstraints(String generalNameChoice, String value) throws EBaseException {
-        return GeneralNameUtil.form_GeneralNameAsConstraints(generalNameChoice, value);
-    }
-
-    public GeneralName form_GeneralName(String generalNameChoice,
-            String value) throws EBaseException {
-        return GeneralNameUtil.form_GeneralName(generalNameChoice, value);
-    }
-
-    public void getGeneralNameConfigDefaultParams(String name,
-            boolean isValueConfigured, Vector<String> params) {
-        GeneralNameUtil.GeneralNameConfig.getDefaultParams(name, isValueConfigured, params);
-    }
-
-    public void getGeneralNamesConfigDefaultParams(String name,
-            boolean isValueConfigured, Vector<String> params) {
-        GeneralNameUtil.GeneralNamesConfig.getDefaultParams(name, isValueConfigured, params);
-    }
-
-    public void getGeneralNameConfigExtendedPluginInfo(String name,
-            boolean isValueConfigured, Vector<String> info) {
-        GeneralNameUtil.GeneralNameConfig.getExtendedPluginInfo(name, isValueConfigured, info);
-    }
-
-    public void getGeneralNamesConfigExtendedPluginInfo(String name,
-            boolean isValueConfigured, Vector<String> info) {
-        GeneralNameUtil.GeneralNamesConfig.getExtendedPluginInfo(name, isValueConfigured, info);
-    }
-
-    public IGeneralNamesConfig createGeneralNamesConfig(String name,
-            IConfigStore config, boolean isValueConfigured,
-            boolean isPolicyEnabled) throws EBaseException {
-        return new GeneralNameUtil.GeneralNamesConfig(name, config, isValueConfigured, isPolicyEnabled);
-    }
-
-    public IGeneralNameAsConstraintsConfig createGeneralNameAsConstraintsConfig(String name, IConfigStore config,
-            boolean isValueConfigured,
-            boolean isPolicyEnabled) throws EBaseException {
-        return new GeneralNameUtil.GeneralNameAsConstraintsConfig(name, config, isValueConfigured, isPolicyEnabled);
-    }
-
-    public IGeneralNamesAsConstraintsConfig createGeneralNamesAsConstraintsConfig(String name, IConfigStore config,
-            boolean isValueConfigured,
-            boolean isPolicyEnabled) throws EBaseException {
-        return new GeneralNameUtil.GeneralNamesAsConstraintsConfig(name, config, isValueConfigured, isPolicyEnabled);
-    }
-
-    public ObjectIdentifier checkOID(String attrName, String value)
-            throws EBaseException {
-        return CertUtils.checkOID(attrName, value);
-    }
-
-    public String BtoA(byte data[]) {
-        return Utils.base64encode(data, true);
-    }
-
-    public byte[] AtoB(String data) {
-        return Utils.base64decode(data);
-    }
-
     public String getEncodedCert(X509Certificate cert) {
         try {
             return Cert.HEADER + "\n" +
@@ -1688,50 +1496,6 @@ public class CMSEngine implements ICMSEngine {
         }
     }
 
-    public void verifySystemCerts() throws Exception {
-        CertUtils.verifySystemCerts();
-    }
-
-    public void verifySystemCertByTag(String tag) throws Exception {
-        CertUtils.verifySystemCertByTag(tag);
-    }
-
-    public void verifySystemCertByNickname(String nickname, String certificateUsage) throws Exception {
-        CertUtils.verifySystemCertByNickname(nickname, certificateUsage);
-    }
-
-    public CertificateUsage getCertificateUsage(String certusage) {
-        return CertUtils.getCertificateUsage(certusage);
-    }
-
-    public boolean isSigningCert(X509Certificate cert) {
-        return CertUtils.isSigningCert((X509CertImpl) cert);
-    }
-
-    public boolean isEncryptionCert(X509Certificate cert) {
-        return CertUtils.isEncryptionCert((X509CertImpl) cert);
-    }
-
-    public X509CertInfo getDefaultX509CertInfo() {
-        return new CertInfo();
-    }
-
-    public IEmailResolverKeys getEmailResolverKeys() {
-        return new EmailResolverKeys();
-    }
-
-    public IEmailResolver getReqCertSANameEmailResolver() {
-        return new ReqCertSANameEmailResolver();
-    }
-
-    public IEmailFormProcessor getEmailFormProcessor() {
-        return new EmailFormProcessor();
-    }
-
-    public IEmailTemplate getEmailTemplate(String path) {
-        return new EmailTemplate(path);
-    }
-
     public IMailNotification getMailNotification() {
         try {
             String className = mConfig.getString("notificationClassName",
@@ -1745,26 +1509,6 @@ public class CMSEngine implements ICMSEngine {
         }
     }
 
-    public IPrettyPrintFormat getPrettyPrintFormat(String delimiter) {
-        return new com.netscape.cmscore.cert.PrettyPrintFormat(delimiter);
-    }
-
-    public IExtPrettyPrint getExtPrettyPrint(Extension e, int indent) {
-        return new ExtPrettyPrint(e, indent);
-    }
-
-    public ICertPrettyPrint getCertPrettyPrint(X509Certificate cert) {
-        return new CertPrettyPrint(cert);
-    }
-
-    public ICRLPrettyPrint getCRLPrettyPrint(X509CRL crl) {
-        return new CrlPrettyPrint((X509CRLImpl) crl);
-    }
-
-    public ICRLPrettyPrint getCRLCachePrettyPrint(ICRLIssuingPoint ip) {
-        return new CrlCachePrettyPrint(ip);
-    }
-
     public IPasswordCheck getPasswordChecker() {
         try {
             String className = mConfig.getString("passwordCheckerClass",
@@ -1810,14 +1554,6 @@ public class CMSEngine implements ICMSEngine {
         return tokenClass;
     }
 
-    public ILogger getLogger() {
-        return Logger.getLogger();
-    }
-
-    public IAuditor getAuditor() {
-        return Auditor.getAuditor();
-    }
-
     private void startupSubsystems(Map<String, SubsystemInfo> subsystems)
             throws EBaseException {
 
@@ -1833,7 +1569,6 @@ public class CMSEngine implements ICMSEngine {
     }
 
     public boolean areRequestsDisabled() {
-        logger.debug("CMSEngine: in areRequestsDisabled");
         return CommandQueue.mShuttingDown;
     }
 
@@ -1891,7 +1626,7 @@ public class CMSEngine implements ICMSEngine {
      */
     public void shutdown() {
 
-        logger.info("Shutting down");
+        logger.info("Shutting down " + name + " subsystem");
 
         /*
                 CommandQueue commandQueue = new CommandQueue();
@@ -1935,7 +1670,7 @@ public class CMSEngine implements ICMSEngine {
      * Added extra call to shutdown the web server.
      */
     public void forceShutdown() {
-        logger.debug("CMSEngine.forceShutdown()...begins graceful shutdown.");
+        logger.debug("CMSEngine.forceShutdown()");
         autoShutdown(false /*no restart*/);
     }
 
@@ -1945,7 +1680,8 @@ public class CMSEngine implements ICMSEngine {
 
     public void autoShutdown(boolean restart) {
 
-        logger.info("Shutting down");
+        logger.info("CMSEngine: Shutting down " + name + " subsystem");
+
         logger.debug("CMSEngine: restart: " + restart);
 
         // update restart tracker so we don't go into infinite restart loop
@@ -2012,6 +1748,27 @@ public class CMSEngine implements ICMSEngine {
 
     }
 
+    public void disableSubsystem() {
+
+        logger.info("CMSEngine: Disabling " + name + " subsystem");
+
+        try {
+            String subsystemID = name.toLowerCase();
+            ProcessBuilder pb = new ProcessBuilder("pki-server", "subsystem-disable", "-i", instanceId, subsystemID);
+            logger.debug("Command: " + String.join(" ", pb.command()));
+
+            Process process = pb.inheritIO().start();
+            int rc = process.waitFor();
+
+            if (rc != 0) {
+                logger.error("CMSEngine: Unable to disable " + name + " subsystem. RC: " + rc);
+            }
+
+        } catch (Exception e) {
+            logger.error("CMSEngine: Unable to disable " + name + " subsystem: " + e.getMessage(), e);
+        }
+    }
+
     private void shutdownSubsystems(Map<String, SubsystemInfo> subsystems) {
         // reverse list of subsystems
         List<SubsystemInfo> list = new ArrayList<>(subsystems.values());
@@ -2048,10 +1805,6 @@ public class CMSEngine implements ICMSEngine {
         }
     }
 
-    public PasswordCallback getPasswordCallback() {
-        return new PWCBsdr();
-    }
-
     public int getPID() {
         if (pid != 0) return pid;
 
@@ -2120,10 +1873,6 @@ public class CMSEngine implements ICMSEngine {
         }
     }
 
-    public ICommandQueue getCommandQueue() {
-        return new CommandQueue();
-    }
-
     private ICertificateRepository getCertDB() {
         ICertificateRepository certDB = null;
 
