@@ -52,6 +52,7 @@ import com.netscape.certsrv.publish.PublisherProxy;
 import com.netscape.certsrv.publish.RulePlugin;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.IRequestNotifier;
+import com.netscape.cms.logging.Logger;
 import com.netscape.cmscore.dbs.CertRecord;
 import com.netscape.cmscore.util.Debug;
 
@@ -77,7 +78,7 @@ public class PublisherProcessor implements
     private IConfigStore mConfig = null;
     private IConfigStore mLdapConfig = null;
     private String mId = null;
-    private ILogger mLogger = CMS.getLogger();
+    private Logger mLogger = Logger.getLogger();
 
     protected ICertAuthority mAuthority = null;
     protected LdapRequestListener mLdapRequestListener = null;
