@@ -17,17 +17,15 @@
 // --- END COPYRIGHT BLOCK ---
 package com.netscape.cmscore.ldapconn;
 
-import netscape.ldap.LDAPConnection;
-import netscape.ldap.LDAPException;
-import netscape.ldap.LDAPSocketFactory;
-
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.ldap.ELdapException;
 import com.netscape.certsrv.ldap.ELdapServerDownException;
 import com.netscape.certsrv.ldap.ILdapBoundConnFactory;
-import com.netscape.certsrv.logging.ILogger;
+
+import netscape.ldap.LDAPConnection;
+import netscape.ldap.LDAPException;
+import netscape.ldap.LDAPSocketFactory;
 
 /**
  * Factory for getting LDAP Connections to a LDAP server with the same
@@ -37,6 +35,8 @@ import com.netscape.certsrv.logging.ILogger;
  */
 public class LdapBoundConnFactory implements ILdapBoundConnFactory {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(LdapBoundConnFactory.class);
+
     protected String id;
 
     protected int mMinConns = 5;
@@ -44,8 +44,6 @@ public class LdapBoundConnFactory implements ILdapBoundConnFactory {
     protected LdapConnInfo mConnInfo = null;
     protected LdapAuthInfo mAuthInfo = null;
 
-    private ILogger mLogger = CMS.getLogger();
-
     public static final String PROP_MINCONNS = "minConns";
     public static final String PROP_MAXCONNS = "maxConns";
     public static final String PROP_LDAPCONNINFO = "ldapconn";
@@ -75,12 +73,12 @@ public class LdapBoundConnFactory implements ILdapBoundConnFactory {
      * must be followed by init(IConfigStore)
      */
     public LdapBoundConnFactory(String id) {
-        CMS.debug("Creating LdapBoundConnFactor(" + id + ")");
+        logger.debug("Creating LdapBoundConnFactor(" + id + ")");
         this.id = id;
     }
 
     public LdapBoundConnFactory(String id, boolean defErrorIfDown) {
-        CMS.debug("Creating LdapBoundConnFactor(" + id + ")");
+        logger.debug("Creating LdapBoundConnFactor(" + id + ")");
         this.id = id;
         mDefErrorIfDown = defErrorIfDown;
     }
@@ -107,7 +105,7 @@ public class LdapBoundConnFactory implements ILdapBoundConnFactory {
      */
     public LdapBoundConnFactory(String id, int minConns, int maxConns,
             LdapConnInfo connInfo, LdapAuthInfo authInfo) throws ELdapException {
-        CMS.debug("Creating LdapBoundConnFactory(" + id + ")");
+        logger.debug("Creating LdapBoundConnFactory(" + id + ")");
         this.id = id;
         init(minConns, maxConns, connInfo, authInfo);
     }
@@ -118,20 +116,22 @@ public class LdapBoundConnFactory implements ILdapBoundConnFactory {
     public void init(IConfigStore config)
             throws ELdapException, EBaseException {
 
-        CMS.debug("LdapBoundConnFactory: init ");
-        LdapConnInfo connInfo =
-                new LdapConnInfo(config.getSubStore(PROP_LDAPCONNINFO));
+        logger.debug("LdapBoundConnFactory: initialization");
+
+        int minConns = config.getInteger(PROP_MINCONNS, mMinConns);
+        int maxConns = config.getInteger(PROP_MAXCONNS, mMaxConns);
+
+        LdapConnInfo connInfo = new LdapConnInfo(config.getSubStore(PROP_LDAPCONNINFO));
+
+        LdapAuthInfo authInfo = new LdapAuthInfo(config.getSubStore(PROP_LDAPAUTHINFO),
+                connInfo.getHost(), connInfo.getPort(), connInfo.getSecure());
 
         mErrorIfDown = config.getBoolean(PROP_ERROR_IF_DOWN, mDefErrorIfDown);
 
         doCloning = config.getBoolean("doCloning", true);
+        logger.debug("LdapBoundConnFactory: doCloning: " + doCloning);
 
-        CMS.debug("LdapBoundConnFactory:doCloning " + doCloning);
-        init(config.getInteger(PROP_MINCONNS, mMinConns),
-                config.getInteger(PROP_MAXCONNS, mMaxConns),
-                connInfo,
-                new LdapAuthInfo(config.getSubStore(PROP_LDAPAUTHINFO),
-                        connInfo.getHost(), connInfo.getPort(), connInfo.getSecure()));
+        init(minConns, maxConns, connInfo, authInfo);
     }
 
     /**
@@ -147,11 +147,21 @@ public class LdapBoundConnFactory implements ILdapBoundConnFactory {
     private void init(int minConns, int maxConns,
             LdapConnInfo connInfo, LdapAuthInfo authInfo)
             throws ELdapException {
-        if (minConns <= 0 || maxConns <= 0 || minConns > maxConns)
-            throw new ELdapException(
-                    CMS.getUserMessage("CMS_LDAP_INVALID_NUMCONN_PARAMETERS"));
-        if (connInfo == null || authInfo == null)
-            throw new IllegalArgumentException("connInfo or authInfo is null!");
+
+        if (minConns <= 0)
+            throw new ELdapException("Invalid minimum number of connections: " + minConns);
+
+        if (maxConns <= 0)
+            throw new ELdapException("Invalid maximum number of connections: " + maxConns);
+
+        if (minConns > maxConns)
+            throw new ELdapException("Minimum number of connections is bigger than maximum: " + minConns + " > " + maxConns);
+
+        if (connInfo == null)
+            throw new IllegalArgumentException("Missing connection info");
+
+        if (authInfo == null)
+            throw new IllegalArgumentException("Missing authentication info");
 
         mMinConns = minConns;
         mMaxConns = maxConns;
@@ -161,16 +171,14 @@ public class LdapBoundConnFactory implements ILdapBoundConnFactory {
         mConns = new BoundConnection[mMaxConns];
 
         // Create connection handle and make initial connection
-        CMS.debug(
-                "init: before makeConnection errorIfDown is " + mErrorIfDown);
         makeConnection(mErrorIfDown);
 
-        CMS.debug(
-                "initializing with mininum " + mMinConns + " and maximum " + mMaxConns +
-                        " connections to " +
-                        "host " + mConnInfo.getHost() + " port " + mConnInfo.getPort() +
-                        ", secure connection, " + mConnInfo.getSecure() +
-                        ", authentication type " + mAuthInfo.getAuthType());
+        logger.debug("LdapBoundConnFactory: mininum: " + mMinConns);
+        logger.debug("LdapBoundConnFactory: maximum: " + mMaxConns);
+        logger.debug("LdapBoundConnFactory: host: " + mConnInfo.getHost());
+        logger.debug("LdapBoundConnFactory: port: " + mConnInfo.getPort());
+        logger.debug("LdapBoundConnFactory: secure: " + mConnInfo.getSecure());
+        logger.debug("LdapBoundConnFactory: authentication: " + mAuthInfo.getAuthType());
 
         // initalize minimum number of connection handles available.
         makeMinimum();
@@ -182,28 +190,22 @@ public class LdapBoundConnFactory implements ILdapBoundConnFactory {
      * @exception ELdapException if any error occurs.
      */
     protected void makeConnection(boolean errorIfDown) throws ELdapException {
-        CMS.debug("makeConnection: errorIfDown " + errorIfDown);
+        logger.debug("LdapBoundConnFactory: makeConnection(" + errorIfDown + ")");
         try {
             mMasterConn = new BoundConnection(mConnInfo, mAuthInfo);
         } catch (LDAPException e) {
             if (e.getLDAPResultCode() == LDAPException.UNAVAILABLE) {
                 // need to intercept this because message from LDAP is
                 // "DSA is unavailable" which confuses with DSA PKI.
-                log(ILogger.LL_FAILURE,
-                        CMS.getLogMessage("CMSCORE_LDAPCONN_CONNECT_SERVER",
-                                mConnInfo.getHost(),
-                                Integer.toString(mConnInfo.getPort())));
+                String message = "LDAP server is unavailable: " + mConnInfo.getHost() + ":" + mConnInfo.getPort();
+                logger.error("LdapBoundConnFactory: " + message, e);
                 if (errorIfDown) {
-                    throw new ELdapServerDownException(
-                            CMS.getUserMessage("CMS_LDAP_SERVER_UNAVAILABLE",
-                                    mConnInfo.getHost(), "" + mConnInfo.getPort()));
+                    throw new ELdapServerDownException(message, e);
                 }
             } else {
-                log(ILogger.LL_FAILURE,
-                        CMS.getLogMessage("CMSCORE_LDAPCONN_FAILED_SERVER", e.toString()));
-                throw new ELdapException(
-                        CMS.getUserMessage("CMS_LDAP_CONNECT_TO_LDAP_SERVER_FAILED",
-                                mConnInfo.getHost(), "" + (Integer.valueOf(mConnInfo.getPort())), e.toString()));
+                String message = "Unable to connect to LDAP server: " + e.getMessage();
+                logger.error("LdapBoundConnFactory: " + message, e);
+                throw new ELdapException(message, e);
             }
         }
     }
@@ -214,7 +216,7 @@ public class LdapBoundConnFactory implements ILdapBoundConnFactory {
      * @exception ELdapException if any error occurs.
      */
     private LdapBoundConnection makeNewConnection(boolean errorIfDown) throws ELdapException {
-        CMS.debug("LdapBoundConnFactory:In makeNewConnection: errorIfDown " + errorIfDown);
+        logger.debug("LdapBoundConnFactory: makeNewConnection(" + errorIfDown + ")");
         LdapBoundConnection conn = null;
         try {
             conn = new BoundConnection(mConnInfo, mAuthInfo);
@@ -222,21 +224,15 @@ public class LdapBoundConnFactory implements ILdapBoundConnFactory {
             if (e.getLDAPResultCode() == LDAPException.UNAVAILABLE) {
                 // need to intercept this because message from LDAP is
                 // "DSA is unavailable" which confuses with DSA PKI.
-                log(ILogger.LL_FAILURE,
-                        CMS.getLogMessage("CMSCORE_LDAPCONN_CONNECT_SERVER",
-                                mConnInfo.getHost(),
-                                Integer.toString(mConnInfo.getPort())));
+                String message = "LDAP server is unavailable: " + mConnInfo.getHost() + ":" + mConnInfo.getPort();
+                logger.error("LdapBoundConnFactory: " + message, e);
                 if (errorIfDown) {
-                    throw new ELdapServerDownException(
-                            CMS.getUserMessage("CMS_LDAP_SERVER_UNAVAILABLE",
-                                    mConnInfo.getHost(), "" + mConnInfo.getPort()));
+                    throw new ELdapServerDownException(message, e);
                 }
             } else {
-                log(ILogger.LL_FAILURE,
-                        CMS.getLogMessage("CMSCORE_LDAPCONN_FAILED_SERVER", e.toString()));
-                throw new ELdapException(
-                        CMS.getUserMessage("CMS_LDAP_CONNECT_TO_LDAP_SERVER_FAILED",
-                                mConnInfo.getHost(), "" + (Integer.valueOf(mConnInfo.getPort())), e.toString()));
+                String message = "Unable to connect to LDAP server: " + e.getMessage();
+                logger.error("LdapBoundConnFactory: " + message, e);
+                throw new ELdapException(message, e);
             }
         }
 
@@ -253,8 +249,8 @@ public class LdapBoundConnFactory implements ILdapBoundConnFactory {
 
         if (mNumConns < mMinConns && mTotal <= mMaxConns) {
             increment = Math.min(mMinConns - mNumConns, mMaxConns - mTotal);
-            CMS.debug(
-                    "increasing minimum connections by " + increment);
+            logger.debug("LdapBoundConnFactory: increasing minimum connections by " + increment);
+
             for (int i = increment - 1; i >= 0; i--) {
 
                 if (doCloning == true) {
@@ -264,10 +260,12 @@ public class LdapBoundConnFactory implements ILdapBoundConnFactory {
                 }
 
             }
+
             mTotal += increment;
             mNumConns += increment;
-            CMS.debug("new total available connections " + mTotal);
-            CMS.debug("new number of connections " + mNumConns);
+
+            logger.debug("LdapBoundConnFactory: total connections: " + mTotal);
+            logger.debug("LdapBoundConnFactory: number of connections: " + mNumConns);
         }
     }
 
@@ -321,36 +319,31 @@ public class LdapBoundConnFactory implements ILdapBoundConnFactory {
             throws ELdapException {
         boolean waited = false;
 
-        CMS.debug("In LdapBoundConnFactory::getConn()");
+        logger.debug("LdapBoundConnFactory: getting a connection");
+
         if (mMasterConn != null)
-            CMS.debug("masterConn is connected: " + mMasterConn.isConnected());
+            logger.debug("LdapBoundConnFactory: master connection is connected: " + mMasterConn.isConnected());
         else
-            CMS.debug("masterConn is null.");
+            logger.debug("LdapBoundConnFactory: master connection is null");
 
         if (mMasterConn == null || !mMasterConn.isConnected()) {
             try {
                 makeConnection(true);
             } catch (ELdapException e) {
                 mMasterConn = null;
-                CMS.debug("Can't create master connection in LdapBoundConnFactory::getConn! " + e.toString());
+                logger.error("LdapBoundConnFactory: Unable to create master connection: " + e.getMessage(), e);
                 throw e;
             }
         }
 
         if (mNumConns == 0)
             makeMinimum();
+
         if (mNumConns == 0) {
             if (!waitForConn)
                 return null;
             try {
-                CMS.debug("getConn: out of ldap connections");
-                log(ILogger.LL_WARN,
-                        "Ran out of ldap connections available " +
-                                "in ldap connection pool to " +
-                                mConnInfo.getHost() + ":" + mConnInfo.getPort() + ". " +
-                                "This could be a temporary condition or an indication of " +
-                                "something more serious that can cause the server to " +
-                                "hang.");
+                logger.warn("LdapBoundConnFactory: out of LDAP connections");
                 waited = true;
                 while (mNumConns == 0)
                     wait();
@@ -365,14 +358,14 @@ public class LdapBoundConnFactory implements ILdapBoundConnFactory {
             isConnected = conn.isConnected();
         }
 
-        CMS.debug("getConn: conn is connected " + isConnected);
+        logger.debug("LdapBoundConnFactory: connection already connected: " + isConnected);
 
         //If masterConn is still alive, lets try to bring this one
         //back to life
 
         if ((isConnected == false) && (mMasterConn != null)
                 && (mMasterConn.isConnected() == true)) {
-            CMS.debug("Attempt to bring back down connection.");
+            logger.debug("LdapBoundConnFactory: reestablishing connection");
 
             if (doCloning == true) {
                 mConns[mNumConns] = (BoundConnection) mMasterConn.clone();
@@ -385,17 +378,15 @@ public class LdapBoundConnFactory implements ILdapBoundConnFactory {
             }
             conn = mConns[mNumConns];
 
-            CMS.debug("Re-animated connection: " + conn);
+            logger.debug("LdapBoundConnFactory: connection reestablished");
         }
 
         mConns[mNumConns] = null;
 
         if (waited) {
-            log(ILogger.LL_WARN,
-                    "Ldap connections are available again in ldap connection pool " +
-                            "to " + mConnInfo.getHost() + ":" + mConnInfo.getPort());
+            logger.warn("LdapBoundConnFactory: connections are available for " + mConnInfo.getHost() + ":" + mConnInfo.getPort());
         }
-        CMS.debug("getConn: mNumConns now " + mNumConns);
+        logger.debug("LdapBoundConnFactory: number of connections: " + mNumConns);
 
         return conn;
     }
@@ -427,32 +418,24 @@ public class LdapBoundConnFactory implements ILdapBoundConnFactory {
         if (conn instanceof BoundConnection) {
             boundconn = (BoundConnection) conn;
         } else {
-            log(ILogger.LL_WARN, "returnConn : Connection is not an BoundConnection");
+            logger.warn("LdapBoundConnFactory: Unable to return connection: not a bound connection");
             return;
         }
 
         if (boundconn.getFacId() != mConns) {
-            log(ILogger.LL_WARN, "returnConn: unknown connection.");
+            logger.warn("LdapBoundConnFactory: Unknown connection");
         }
+
         for (int i = 0; i < mNumConns; i++) {
             if (mConns[i] == conn) {
-                CMS.debug(
-                        "returnConn: previously returned connection.");
+                logger.warn("LdapBoundConnFactory: Connection already returned");
             }
         }
-        mConns[mNumConns++] = boundconn;
-        CMS.debug("returnConn: mNumConns now " + mNumConns);
-        notify();
-    }
 
-    /**
-     * handy routine for logging in this class.
-     */
-    private void log(int level, String msg) {
-        mLogger.log(ILogger.EV_SYSTEM, ILogger.S_LDAP, level,
-                "In Ldap (bound) connection pool to" +
-                        " host " + mConnInfo.getHost() +
-                        " port " + mConnInfo.getPort() + ", " + msg);
+        mConns[mNumConns++] = boundconn;
+        logger.debug("LdapBoundConnFactory: number of connections: " + mNumConns);
+
+        notify();
     }
 
     protected void finalize()
@@ -468,34 +451,32 @@ public class LdapBoundConnFactory implements ILdapBoundConnFactory {
      */
     public synchronized void reset()
             throws ELdapException {
-        CMS.debug("Destroying LdapBoundConnFactory(" + id + ")");
+        logger.debug("Destroying LdapBoundConnFactory(" + id + ")");
         if (mNumConns == mTotal) {
             for (int i = 0; i < mNumConns; i++) {
                 try {
                     mConns[i].disconnect();
                 } catch (LDAPException e) {
-                    e.printStackTrace();
+                    logger.warn("LdapBoundConnFactory: Unable to disconnect: " + e.getMessage(), e);
                 }
                 mConns[i] = null;
             }
             if (mMasterConn != null) {
                 try {
-                    log(ILogger.LL_INFO, "disconnecting masterConn");
+                    logger.debug("LdapBoundConnFactory: disconnecting master connection");
                     mMasterConn.disconnect();
                 } catch (LDAPException e) {
-                    e.printStackTrace();
-                    log(ILogger.LL_FAILURE,
-                            CMS.getLogMessage("CMSCORE_LDAPCONN_CANNOT_RESET",
-                                    e.toString()));
+                    String message = "Unable to disconnect master connection: " + e.getMessage();
+                    logger.warn("LdapBoundConnFactory: " + message, e);
                 }
             }
             mMasterConn = null;
             mTotal = 0;
             mNumConns = 0;
         } else {
-            CMS.debug(
-                    "Cannot reset factory: connections not all returned");
-            throw new ELdapException(CMS.getUserMessage("CMS_LDAP_CANNOT_RESET_CONNFAC"));
+            String message = "Unable to reset LDAP connection factory due to outstanding connections";
+            logger.error("LdapBoundConnFactory: " + message);
+            throw new ELdapException(message);
         }
 
         if (mAuthInfo != null) {
