@@ -22,8 +22,6 @@ import java.io.InputStream;
 import java.math.BigInteger;
 import java.util.Arrays;
 import java.util.Enumeration;
-import java.util.Hashtable;
-import java.util.LinkedHashMap;
 import java.util.TreeMap;
 import java.util.TreeSet;
 
@@ -44,6 +42,7 @@ import com.netscape.certsrv.registry.IPluginRegistry;
 import com.netscape.certsrv.util.AsyncLoader;
 import com.netscape.cms.servlet.csadmin.GetStatus;
 import com.netscape.cmscore.base.LDAPConfigStore;
+import com.netscape.cmscore.ldapconn.LdapBoundConnFactory;
 import com.netscape.cmsutil.ldap.LDAPUtil;
 
 import netscape.ldap.LDAPAttribute;
@@ -96,15 +95,13 @@ public class LDAPProfileSubsystem
         logger.debug("LDAPProfileSubsystem: start init");
 
         // (re)init member collections
-        mProfiles = new LinkedHashMap<String, IProfile>();
-        mProfileClassIds = new Hashtable<String, String>();
         entryUSNs = new TreeMap<>();
         nsUniqueIds = new TreeMap<>();
         deletedNsUniqueIds = new TreeSet<>();
 
         IConfigStore cs = CMS.getConfigStore();
         IConfigStore dbCfg = cs.getSubStore("internaldb");
-        dbFactory = CMS.getLdapBoundConnFactory("LDAPProfileSubsystem");
+        dbFactory = new LdapBoundConnFactory("LDAPProfileSubsystem");
         dbFactory.init(dbCfg);
 
         mConfig = config;
