@@ -88,6 +88,7 @@ import com.netscape.certsrv.common.NameValuePairs;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.security.ICryptoSubsystem;
 import com.netscape.certsrv.security.KeyCertData;
+import com.netscape.cms.logging.Logger;
 import com.netscape.cmscore.cert.CertPrettyPrint;
 import com.netscape.cmscore.cert.CertUtils;
 import com.netscape.cmscore.util.Debug;
@@ -119,7 +120,7 @@ public final class JssSubsystem implements ICryptoSubsystem {
     private static final String mId = ID;
     protected IConfigStore mConfig = null;
     private boolean mInited = false;
-    private ILogger mLogger = null;
+    private Logger mLogger = null;
     private CryptoManager mCryptoManager = null;
     private SecureRandom random;
     private String obscureMethod = "zeroes";
@@ -272,7 +273,7 @@ public final class JssSubsystem implements ICryptoSubsystem {
 
         CMS.debug("JssSubsystem: initializing JSS subsystem");
 
-        mLogger = CMS.getLogger();
+        mLogger = Logger.getLogger();
 
         if (mInited) {
             // This used to throw an exeception (e.g. - on Solaris).
@@ -823,23 +824,14 @@ public final class JssSubsystem implements ICryptoSubsystem {
         }
     }
 
-    public KeyPair getKeyPair(String tokenName, String alg,
+    public KeyPair getKeyPair(CryptoToken token, String alg,
             int keySize) throws EBaseException {
-        return getKeyPair(tokenName, alg, keySize, null);
+        return getKeyPair(token, alg, keySize, null);
     }
 
-    public KeyPair getKeyPair(String tokenName, String alg,
+    public KeyPair getKeyPair(CryptoToken token, String alg,
             int keySize, PQGParams pqg) throws EBaseException {
 
-        CryptoToken token = null;
-
-        try {
-            token = CryptoUtil.getKeyStorageToken(tokenName);
-        } catch (Exception e) {
-            log(ILogger.LL_FAILURE, "Unable to find token: " + tokenName);
-            throw new EBaseException(e);
-        }
-
         KeyPairAlgorithm kpAlg = null;
 
         if (alg.equals("RSA"))
@@ -940,14 +932,14 @@ public final class JssSubsystem implements ICryptoSubsystem {
     }
 
     public KeyPair getKeyPair(KeyCertData properties) throws EBaseException {
-        String tokenname = CryptoUtil.INTERNAL_TOKEN_NAME;
+        String tokenName = CryptoUtil.INTERNAL_TOKEN_NAME;
         String keyType = "RSA";
         int keyLength = 512;
 
         String tmp = (String) properties.get(Constants.PR_TOKEN_NAME);
 
         if (!CryptoUtil.isInternalToken(tmp))
-            tokenname = tmp;
+            tokenName = tmp;
         tmp = (String) properties.get(Constants.PR_KEY_TYPE);
         if (tmp != null)
             keyType = tmp;
@@ -955,38 +947,47 @@ public final class JssSubsystem implements ICryptoSubsystem {
         if (tmp != null)
             keyLength = Integer.parseInt(tmp);
 
-        KeyPair pair = getKeyPair(tokenname, keyType, keyLength);
+        CryptoToken token;
+        try {
+            token = CryptoUtil.getKeyStorageToken(tokenName);
+        } catch (NotInitializedException | NoSuchTokenException e) {
+            throw new EBaseException("Unable to find token: " + tokenName, e);
+        }
+
+        KeyPair pair = getKeyPair(token, keyType, keyLength);
 
         return pair;
     }
 
     public KeyPair getECCKeyPair(KeyCertData properties) throws EBaseException {
-        String token = CryptoUtil.INTERNAL_TOKEN_NAME;
+        String tokenName = CryptoUtil.INTERNAL_TOKEN_NAME;
         String keyCurve = "nistp521";
-        String certType = null;
-        KeyPair pair = null;
 
         String tmp = (String) properties.get(Constants.PR_TOKEN_NAME);
         if (tmp != null)
-            token = tmp;
+            tokenName = tmp;
 
         tmp = (String) properties.get(Constants.PR_KEY_CURVENAME);
         if (tmp != null)
             keyCurve = tmp;
 
-        certType = (String) properties.get(Constants.RS_ID);
+        String certType = (String) properties.get(Constants.RS_ID);
 
-        pair = getECCKeyPair(token, keyCurve, certType);
+        CryptoToken token;
+        try {
+            token = CryptoUtil.getKeyStorageToken(tokenName);
+        } catch (NotInitializedException | NoSuchTokenException e) {
+            throw new EBaseException("Unable to find token: " + tokenName, e);
+        }
+
+        KeyPair pair = getECCKeyPair(token, keyCurve, certType);
 
         return pair;
     }
 
-    public KeyPair getECCKeyPair(String token, String keyCurve, String certType) throws EBaseException {
+    public KeyPair getECCKeyPair(CryptoToken token, String keyCurve, String certType) throws EBaseException {
         KeyPair pair = null;
 
-        if (CryptoUtil.isInternalToken(token))
-            token = CryptoUtil.INTERNAL_TOKEN_NAME;
-
         if ((keyCurve == null) || (keyCurve.equals("")))
             keyCurve = "nistp521";
 
@@ -1930,7 +1931,7 @@ public final class JssSubsystem implements ICryptoSubsystem {
 
             if (impl != null) {
                 print = new CertPrettyPrint(impl);
-                fingerPrint = CMS.getFingerPrints(impl.getEncoded());
+                fingerPrint = CertUtils.getFingerPrints(impl.getEncoded());
             }
 
             if ((print != null) && (fingerPrint != "")) {
