@@ -18,7 +18,8 @@
 # All rights reserved.
 #
 
-from __future__ import absolute_import, print_function
+from __future__ import absolute_import
+from __future__ import print_function
 
 import getopt
 import os
@@ -37,36 +38,72 @@ class AuditCLI(pki.cli.CLI):
             'audit', 'Audit management commands')
 
         self.parent = parent
+        self.add_module(AuditConfigShowCLI(self))
+        self.add_module(AuditConfigModifyCLI(self))
         self.add_module(AuditEventFindCLI(self))
+        self.add_module(AuditEventShowCLI(self))
         self.add_module(AuditEventEnableCLI(self))
-        self.add_module(AuditEventUpdateCLI(self))
         self.add_module(AuditEventDisableCLI(self))
+        self.add_module(AuditEventUpdateCLI(self))
         self.add_module(AuditFileFindCLI(self))
         self.add_module(AuditFileVerifyCLI(self))
-        self.add_module(AuditConfigModifyCLI(self))
+
+    @staticmethod
+    def print_audit_config(subsystem):
+
+        name = 'log.instance.SignedAudit.%s'
+
+        enabled = subsystem.config[name % 'enable'].lower() == 'true'
+
+        fileName = subsystem.config[name % 'fileName']
+        bufferSize = subsystem.config[name % 'bufferSize']
+        flushInterval = subsystem.config[name % 'flushInterval']
+
+        maxFileSize = subsystem.config[name % 'maxFileSize']
+        rolloverInterval = subsystem.config[name % 'rolloverInterval']
+        expirationTime = subsystem.config[name % 'expirationTime']
+
+        logSigning = subsystem.config[name % 'logSigning'].lower() == 'true'
+        signedAuditCertNickname = subsystem.config[name % 'signedAuditCertNickname']
+
+        print('  Enabled: %s' % enabled)
+
+        print('  Log File: %s' % fileName)
+        print('  Buffer Size (bytes): %s' % bufferSize)
+        print('  Flush Interval (seconds): %s' % flushInterval)
+
+        print('  Max File Size (bytes): %s' % maxFileSize)
+        print('  Rollover Interval (seconds): %s' % rolloverInterval)
+        print('  Expiration Time (seconds): %s' % expirationTime)
+
+        print('  Log Signing: %s' % logSigning)
+        print('  Signing Certificate: %s' % signedAuditCertNickname)
+
+    @staticmethod
+    def print_audit_event_config(event):
+        print('  Event Name: %s' % event.get('name'))
+        print('  Enabled: %s' % event.get('enabled'))
+        print('  Filter: %s' % event.get('filter'))
 
 
-class AuditConfigModifyCLI(pki.cli.CLI):
+class AuditConfigShowCLI(pki.cli.CLI):
 
     def __init__(self, parent):
-        super(AuditConfigModifyCLI, self).__init__(
-            'config-mod', 'Enable/Disable signed audit logs')
+        super(AuditConfigShowCLI, self).__init__(
+            'config-show', 'Display audit configuration')
         self.parent = parent
 
     def print_help(self):
-        print('Usage: pki-server %s-audit-config-mod [OPTIONS]' % self.parent.parent.name)
+        print('Usage: pki-server %s-audit-config-show [OPTIONS]' % self.parent.parent.name)
         print()
         print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
-        print('      --enabled <True|False>         Show enabled/disabled events only.')
-        print('      --fileSize                     Set Audit file size. (Default 2000)')
         print('      --help                         Show help message.')
         print()
 
     def execute(self, argv):
         try:
             opts, _ = getopt.gnu_getopt(argv, 'i:v', [
-                'instance=', 'fileSize=',
-                'enabled=',
+                'instance=',
                 'verbose', 'help'])
 
         except getopt.GetoptError as e:
@@ -75,26 +112,11 @@ class AuditConfigModifyCLI(pki.cli.CLI):
             sys.exit(1)
 
         instance_name = 'pki-tomcat'
-        enabled = None
-        file_size = 2000
+
         for o, a in opts:
             if o in ('-i', '--instance'):
                 instance_name = a
 
-            elif o == '--enabled':
-                if a.lower().title() not in ['True', 'False']:
-                    raise ValueError("Not valid input. Specify True or False")
-                if a.lower() == 'true':
-                    enabled = True
-                else:
-                    enabled = False
-
-            elif o == '--fileSize':
-                if o.isdigit():
-                    file_size = o
-                else:
-                    raise ValueError("Not valid input, Specify file size in digits")
-
             elif o == '--help':
                 self.print_help()
                 sys.exit()
@@ -113,18 +135,173 @@ class AuditConfigModifyCLI(pki.cli.CLI):
 
         subsystem_name = self.parent.parent.name
         subsystem = instance.get_subsystem(subsystem_name)
+
         if not subsystem:
             print('ERROR: No %s subsystem in instance %s.'
                   % (subsystem_name.upper(), instance_name))
             sys.exit(1)
 
-        subsystem.signed_audit_log(enabled, file_size)
-        subsystem.save()
-        if enabled:
-            self.print_message("Signed Audit enabled for {}".format(instance_name))
+        AuditCLI.print_audit_config(subsystem)
+
+
+class AuditConfigModifyCLI(pki.cli.CLI):
+
+    def __init__(self, parent):
+        super(AuditConfigModifyCLI, self).__init__(
+            'config-mod', 'Modify audit configuration')
+        self.parent = parent
+
+    def print_help(self):
+        print('Usage: pki-server %s-audit-config-mod [OPTIONS]' % self.parent.parent.name)
+        print()
+        print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
+        print('      --enabled <True|False>         Enable/disable audit logging.')
+        print('      --logFile <path>               Set log file.')
+        print('      --bufferSize <size>            Set buffer size (bytes).')
+        print('      --flushInterval <interval>     Set flush interval (seconds).')
+        print('      --maxFileSize <size>           Set maximum file size (bytes).')
+        print('      --rolloverInterval <interval>  Set rollover interval (seconds).')
+        print('      --expirationTime <time>        Set expiration time (seconds).')
+        print('      --logSigning <True|False>      Enable/disable log signing.')
+        print('      --signingCert <nickname>       Set signing certificate.')
+        print('      --help                         Show help message.')
+        print()
+
+    def execute(self, argv):
+        try:
+            opts, _ = getopt.gnu_getopt(argv, 'i:v', [
+                'instance=',
+                'enabled=',
+                'logFile=', 'bufferSize=', 'flushInterval=',
+                'maxFileSize=', 'rolloverInterval=', 'expirationTime=',
+                'logSigning=', 'signingCert=',
+                'verbose', 'help'])
+
+        except getopt.GetoptError as e:
+            print('ERROR: ' + str(e))
+            self.print_help()
+            sys.exit(1)
+
+        instance_name = 'pki-tomcat'
+        enabled = None
+        logFile = None
+        bufferSize = None
+        flushInterval = None
+        maxFileSize = None
+        rolloverInterval = None
+        expirationTime = None
+        logSigning = None
+        signingCert = None
+
+        for o, a in opts:
+            if o in ('-i', '--instance'):
+                instance_name = a
+
+            elif o == '--enabled':
+                if a.lower().title() not in ['True', 'False']:
+                    raise ValueError("Invalid input: Enabled must be True or False")
+                enabled = a.lower() == 'true'
+
+            elif o == '--logFile':
+                logFile = a
+
+            elif o == '--bufferSize':
+                if not a.isdigit():
+                    raise ValueError("Invalid input: Buffer size must be a number")
+                bufferSize = a
+
+            elif o == '--flushInterval':
+                if not a.isdigit():
+                    raise ValueError("Invalid input: Flush interval must be a number")
+                flushInterval = a
+
+            elif o == '--maxFileSize':
+                if not a.isdigit():
+                    raise ValueError("Invalid input: Max file size must be a number")
+                maxFileSize = a
+
+            elif o == '--rolloverInterval':
+                if not a.isdigit():
+                    raise ValueError("Invalid input: Rollover interval must be a number")
+                rolloverInterval = a
+
+            elif o == '--expirationTime':
+                if not a.isdigit():
+                    raise ValueError("Invalid input: Expiration time must be a number")
+                expirationTime = a
+
+            elif o == '--logSigning':
+                if a.lower().title() not in ['True', 'False']:
+                    raise ValueError("Invalid input: Log signing must be True or False")
+                logSigning = a.lower() == 'true'
+
+            elif o == '--signingCert':
+                signingCert = a
+
+            elif o == '--help':
+                self.print_help()
+                sys.exit()
+
+            else:
+                print('ERROR: unknown option ' + o)
+                self.print_help()
+                sys.exit(1)
+
+        instance = pki.server.PKIInstance(instance_name)
+        if not instance.is_valid():
+            print('ERROR: Invalid instance %s.' % instance_name)
+            sys.exit(1)
+
+        instance.load()
+
+        subsystem_name = self.parent.parent.name
+        subsystem = instance.get_subsystem(subsystem_name)
+
+        if not subsystem:
+            print('ERROR: No %s subsystem in instance %s.'
+                  % (subsystem_name.upper(), instance_name))
+            sys.exit(1)
+
+        name = 'log.instance.SignedAudit.%s'
+
+        if enabled is None:
+            pass
+        elif enabled:
+            subsystem.config[name % 'enable'] = 'true'
         else:
-            self.print_message("Signed Audit disabled for {}".format(instance_name))
-        self.print_message("You might need to restart the instance")
+            subsystem.config[name % 'enable'] = 'false'
+
+        if logFile:
+            subsystem.config[name % 'fileName'] = logFile
+
+        if bufferSize:
+            subsystem.config[name % 'bufferSize'] = bufferSize
+
+        if flushInterval:
+            subsystem.config[name % 'flushInterval'] = flushInterval
+
+        if maxFileSize:
+            subsystem.config[name % 'maxFileSize'] = maxFileSize
+
+        if rolloverInterval:
+            subsystem.config[name % 'rolloverInterval'] = rolloverInterval
+
+        if expirationTime:
+            subsystem.config[name % 'expirationTime'] = expirationTime
+
+        if logSigning is None:
+            pass
+        elif logSigning:
+            subsystem.config[name % 'logSigning'] = 'true'
+        else:
+            subsystem.config[name % 'logSigning'] = 'false'
+
+        if signingCert:
+            subsystem.config[name % 'signedAuditCertNickname'] = signingCert
+
+        subsystem.save()
+
+        AuditCLI.print_audit_config(subsystem)
 
 
 class AuditEventFindCLI(pki.cli.CLI):
@@ -193,7 +370,7 @@ class AuditEventFindCLI(pki.cli.CLI):
                   % (subsystem_name.upper(), instance_name))
             sys.exit(1)
 
-        events = subsystem.find_audit_events(enabled)
+        events = subsystem.find_audit_event_configs(enabled)
 
         self.print_message('%s entries matched' % len(events))
 
@@ -209,6 +386,80 @@ class AuditEventFindCLI(pki.cli.CLI):
             print('  Filter: %s' % event.get('filter'))
 
 
+class AuditEventShowCLI(pki.cli.CLI):
+
+    def __init__(self, parent):
+        super(AuditEventShowCLI, self).__init__(
+            'event-show', 'Show audit event configuration')
+
+        self.parent = parent
+
+    def print_help(self):
+        print('Usage: pki-server %s-audit-event-show [OPTIONS] <event name>'
+              % self.parent.parent.name)
+        print()
+        print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --help                         Show help message.')
+        print()
+
+    def execute(self, argv):
+
+        try:
+            opts, args = getopt.gnu_getopt(argv, 'i:v', [
+                'instance=',
+                'verbose', 'help'])
+
+        except getopt.GetoptError as e:
+            print('ERROR: ' + str(e))
+            self.print_help()
+            sys.exit(1)
+
+        instance_name = 'pki-tomcat'
+
+        for o, a in opts:
+            if o in ('-i', '--instance'):
+                instance_name = a
+
+            elif o in ('-v', '--verbose'):
+                self.set_verbose(True)
+
+            elif o == '--help':
+                self.print_help()
+                sys.exit()
+
+            else:
+                print('ERROR: unknown option ' + o)
+                self.print_help()
+                sys.exit(1)
+
+        if len(args) == 0:
+            raise getopt.GetoptError("Missing event name.")
+
+        if len(args) > 1:
+            raise getopt.GetoptError("Too many arguments specified.")
+
+        event_name = args[0]
+
+        instance = pki.server.PKIInstance(instance_name)
+        if not instance.is_valid():
+            print('ERROR: Invalid instance %s.' % instance_name)
+            sys.exit(1)
+
+        instance.load()
+
+        subsystem_name = self.parent.parent.name
+        subsystem = instance.get_subsystem(subsystem_name)
+
+        if not subsystem:
+            print('ERROR: No %s subsystem in instance %s.'
+                  % (subsystem_name.upper(), instance_name))
+            sys.exit(1)
+
+        event = subsystem.get_audit_event_config(event_name)
+        AuditCLI.print_audit_event_config(event)
+
+
 class AuditEventEnableCLI(pki.cli.CLI):
 
     def __init__(self, parent):
@@ -275,17 +526,23 @@ class AuditEventEnableCLI(pki.cli.CLI):
                   % (subsystem_name.upper(), instance_name))
             sys.exit(1)
 
-        msg = None
         enabled = subsystem.enable_audit_event(event_name)
+        subsystem.save()
+
+        msg = None
         if enabled:
             msg = 'Event "{}" enabled successfully. You may need to ' \
                   'restart the instance.'.format(event_name)
         else:
             msg = 'Event "{}" may be already enabled.'.format(event_name)
+
         print(len(msg) * '-')
         print(msg)
         print(len(msg) * '-')
 
+        event = subsystem.get_audit_event_config(event_name)
+        AuditCLI.print_audit_event_config(event)
+
 
 class AuditEventUpdateCLI(pki.cli.CLI):
 
@@ -318,14 +575,14 @@ class AuditEventUpdateCLI(pki.cli.CLI):
             sys.exit(1)
 
         instance_name = 'pki-tomcat'
-        filter_name = None
+        event_filter = None
 
         for o, a in opts:
             if o in ('-i', '--instance'):
                 instance_name = a
 
             elif o in ('-f', '--filter'):
-                filter_name = a
+                event_filter = a
 
             elif o in ('-v', '--verbose'):
                 self.set_verbose(True)
@@ -360,7 +617,11 @@ class AuditEventUpdateCLI(pki.cli.CLI):
                   % (subsystem_name.upper(), instance_name))
             sys.exit(1)
 
-        subsystem.update_audit_event_filter(event_name, filter_name)
+        subsystem.update_audit_event_filter(event_name, event_filter)
+        subsystem.save()
+
+        event = subsystem.get_audit_event_config(event_name)
+        AuditCLI.print_audit_event_config(event)
 
 
 class AuditEventDisableCLI(pki.cli.CLI):
@@ -430,8 +691,10 @@ class AuditEventDisableCLI(pki.cli.CLI):
                   % (subsystem_name.upper(), instance_name))
             sys.exit(1)
 
-        msg = None
         disable = subsystem.disable_audit_event(event_name)
+        subsystem.save()
+
+        msg = None
         if disable:
             msg = 'Audit event "{}" disabled. You may need to restart the ' \
                   'instance.'.format(event_name)
@@ -442,6 +705,9 @@ class AuditEventDisableCLI(pki.cli.CLI):
         print(msg)
         print(len(msg) * '-')
 
+        event = subsystem.get_audit_event_config(event_name)
+        AuditCLI.print_audit_event_config(event)
+
 
 class AuditFileFindCLI(pki.cli.CLI):
 
