@@ -29,6 +29,7 @@ import tempfile
 
 import pki.cli
 import pki.server.cli.audit
+import pki.server.cli.config
 
 
 class CACLI(pki.cli.CLI):
@@ -40,6 +41,7 @@ class CACLI(pki.cli.CLI):
         self.add_module(CACertCLI())
         self.add_module(CACloneCLI())
         self.add_module(pki.server.cli.audit.AuditCLI(self))
+        self.add_module(pki.server.cli.config.SubsystemConfigCLI(self))
 
 
 class CACertCLI(pki.cli.CLI):
@@ -102,7 +104,7 @@ class CACertChainExportCLI(pki.cli.CLI):
                 pkcs12_file = a
 
             elif o == '--pkcs12-password':
-                pkcs12_password = a
+                pkcs12_password = a.encode()
 
             elif o == '--pkcs12-password-file':
                 with io.open(a, 'rb') as f:
@@ -146,7 +148,7 @@ class CACertChainExportCLI(pki.cli.CLI):
 
         try:
             pkcs12_password_file = os.path.join(tmpdir, 'pkcs12_password.txt')
-            with open(pkcs12_password_file, 'w') as f:
+            with open(pkcs12_password_file, 'wb') as f:
                 f.write(pkcs12_password)
 
             subsystem.export_cert_chain(pkcs12_file, pkcs12_password_file)
@@ -381,7 +383,7 @@ class CAClonePrepareCLI(pki.cli.CLI):
                 pkcs12_file = a
 
             elif o == '--pkcs12-password':
-                pkcs12_password = a
+                pkcs12_password = a.encode()
 
             elif o == '--pkcs12-password-file':
                 with io.open(a, 'rb') as f:
@@ -425,7 +427,7 @@ class CAClonePrepareCLI(pki.cli.CLI):
 
         try:
             pkcs12_password_file = os.path.join(tmpdir, 'pkcs12_password.txt')
-            with open(pkcs12_password_file, 'w') as f:
+            with open(pkcs12_password_file, 'wb') as f:
                 f.write(pkcs12_password)
 
             subsystem.export_system_cert(
