@@ -33,6 +33,7 @@ import time
 
 import pki.cli
 import pki.server.cli.audit
+import pki.server.cli.config
 
 
 KRA_VLVS = ['allKeys', 'kraAll',
@@ -53,6 +54,7 @@ class KRACLI(pki.cli.CLI):
         self.add_module(KRACloneCLI())
         self.add_module(KRADBCLI())
         self.add_module(pki.server.cli.audit.AuditCLI(self))
+        self.add_module(pki.server.cli.config.SubsystemConfigCLI(self))
 
 
 class KRACloneCLI(pki.cli.CLI):
@@ -105,7 +107,7 @@ class KRAClonePrepareCLI(pki.cli.CLI):
                 pkcs12_file = a
 
             elif o == '--pkcs12-password':
-                pkcs12_password = a
+                pkcs12_password = a.encode()
 
             elif o == '--pkcs12-password-file':
                 with io.open(a, 'rb') as f:
@@ -148,7 +150,7 @@ class KRAClonePrepareCLI(pki.cli.CLI):
 
         try:
             pkcs12_password_file = os.path.join(tmpdir, 'pkcs12_password.txt')
-            with open(pkcs12_password_file, 'w') as f:
+            with open(pkcs12_password_file, 'wb') as f:
                 f.write(pkcs12_password)
 
             subsystem.export_system_cert(
