@@ -377,7 +377,12 @@ class SubsystemCertCLI(pki.cli.CLI):
         print('  Serial No: %s' % cert['serial_number'])
         print('  Cert ID: %s' % cert['id'])
         print('  Nickname: %s' % cert['nickname'])
-        print('  Token: %s' % cert['token'])
+
+        token = cert['token']
+        if not token:
+            token = pki.nssdb.INTERNAL_TOKEN_FULL_NAME
+
+        print('  Token: %s' % token)
 
         if show_all:
             print('  Certificate: %s' % cert['data'])
@@ -453,17 +458,23 @@ class SubsystemCertFindCLI(pki.cli.CLI):
             print('ERROR: No %s subsystem in instance '
                   '%s.' % (subsystem_name, instance_name))
             sys.exit(1)
-        results = subsystem.find_system_certs()
 
-        self.print_message('%s entries matched' % len(results))
+        certs = subsystem.get_cert_infos()
+
+        self.print_message('%s entries matched' % len(certs))
 
         first = True
-        for cert in results:
+        for cert in certs:
             if first:
                 first = False
             else:
                 print()
 
+            if cert['nickname']:
+                cert_info = subsystem.get_nssdb_cert_info(cert['id'])
+                if cert_info:
+                    cert.update(cert_info)
+
             SubsystemCertCLI.print_subsystem_cert(cert, show_all)
 
 
@@ -836,6 +847,8 @@ class SubsystemCertUpdateCLI(pki.cli.CLI):
                 nickname=subsystem_cert['nickname'],
                 cert_file=cert_file)
 
+        # Retrieve the cert info from NSSDB
+        # Note: This reloads `data` object if --cert option is provided
         data = nssdb.get_cert(
             nickname=subsystem_cert['nickname'],
             output_format='base64')
@@ -998,7 +1011,10 @@ class SubsystemCertValidateCLI(pki.cli.CLI):
 
         print('  Usage: %s' % usage)
 
-        token = cert.get('token', '')
+        token = cert['token']
+        if not token:
+            token = pki.nssdb.INTERNAL_TOKEN_FULL_NAME
+
         print('  Token: %s' % token)
 
         # normalize internal token into None
@@ -1041,10 +1057,11 @@ class SubsystemCertValidateCLI(pki.cli.CLI):
             return True
 
         except subprocess.CalledProcessError as e:
-            if e.returncode == 1:
-                print('  Status: INVALID')
+            if e.output:
+                status = e.output.decode('utf-8')
             else:
-                print('  Status: ERROR: %s' % e.output)
+                status = 'ERROR'
+            print('  Status: %s' % status)
             return False
 
         finally:
