@@ -33,6 +33,7 @@ import time
 
 import pki.cli
 import pki.server.cli.audit
+import pki.server.cli.config
 
 
 TPS_VLV_PATH = '/usr/share/pki/tps/conf/vlv.ldif'
@@ -48,6 +49,7 @@ class TPSCLI(pki.cli.CLI):
         self.add_module(TPSCloneCLI())
         self.add_module(TPSDBCLI())
         self.add_module(pki.server.cli.audit.AuditCLI(self))
+        self.add_module(pki.server.cli.config.SubsystemConfigCLI(self))
 
 
 class TPSCloneCLI(pki.cli.CLI):
@@ -100,7 +102,7 @@ class TPSClonePrepareCLI(pki.cli.CLI):
                 pkcs12_file = a
 
             elif o == '--pkcs12-password':
-                pkcs12_password = a
+                pkcs12_password = a.encode()
 
             elif o == '--pkcs12-password-file':
                 with io.open(a, 'rb') as f:
@@ -143,13 +145,11 @@ class TPSClonePrepareCLI(pki.cli.CLI):
 
         try:
             pkcs12_password_file = os.path.join(tmpdir, 'pkcs12_password.txt')
-            with open(pkcs12_password_file, 'w') as f:
+            with open(pkcs12_password_file, 'wb') as f:
                 f.write(pkcs12_password)
 
             subsystem.export_system_cert(
                 'subsystem', pkcs12_file, pkcs12_password_file)
-            subsystem.export_system_cert(
-                'signing', pkcs12_file, pkcs12_password_file, append=True)
             subsystem.export_system_cert(
                 'audit_signing', pkcs12_file, pkcs12_password_file, append=True)
             instance.export_external_certs(
