@@ -98,6 +98,7 @@ PKI_ARCHIVE_MANIFEST_MESSAGE_1 = "archiving manifest into '%s'"
 PKI_OSERROR_1 = "OSError:  %s!"
 PKI_SHUTIL_ERROR_1 = "shutil.Error:  %s!"
 PKI_SUBPROCESS_ERROR_1 = "subprocess.CalledProcessError:  %s!"
+PKI_SUBPROCESS_ERROR_2 = "subprocess.CalledProcessError:  %s! %s"
 PKI_SYMLINK_ALREADY_EXISTS_1 = "Symlink '%s' already exists!"
 PKI_SYMLINK_ALREADY_EXISTS_NOT_A_SYMLINK_1 = \
     "Symlink '%s' already exists BUT it is NOT a symlink!"
@@ -188,7 +189,6 @@ PKIHELPER_CERTUTIL_MISSING_PATH = "certutil:  Missing '-d path' option!"
 PKIHELPER_CERTUTIL_MISSING_SERIAL_NUMBER = \
     "certutil:  Missing '-m serial-number' option!"
 PKIHELPER_CERTUTIL_MISSING_SUBJECT = "certutil:  Missing '-s subject' option!"
-PKIHELPER_CERTUTIL_MISSING_TOKEN = "certutil:  Missing '-h token' option!"
 PKIHELPER_CERTUTIL_MISSING_TRUSTARGS = \
     "certutil:  Missing '-t trustargs' option!"
 PKIHELPER_CERTUTIL_MISSING_VALIDITY_PERIOD = \
@@ -272,6 +272,8 @@ PKIHELPER_NAMESPACE_COLLISION_2 = \
     "PKI instance '%s' would produce a namespace collision with '%s'!"
 PKIHELPER_NAMESPACE_RESERVED_NAME_2 = \
     "PKI instance '%s' is already a reserved name under '%s'!"
+PKIHELPER_LOG_REUSE = \
+    "previous logs of PKI instance '%s' already exist. Appending logs to '%s'"
 PKIHELPER_NCIPHER_RESTART_1 = "executing '%s'"
 PKIHELPER_NOISE_FILE_2 = \
     "generating noise file called '%s' and filling it with '%d' random bytes"
@@ -320,7 +322,6 @@ PKIHELPER_SECURITY_DOMAIN_UPDATE_SUCCESS_2 = \
     "security domain '%s'"
 PKIHELPER_SELINUX_DISABLED = "Selinux is disabled.  Not checking port contexts"
 PKIHELPER_SET_MODE_1 = "setting ownerships, permissions, and acls on '%s'"
-PKIHELPER_SLOT_SUBSTITUTION_2 = "slot substitution: '%s' ==> '%s'"
 PKIHELPER_SSLGET_OUTPUT_1 = '''
     Dump of 'sslget' output:
     =====================================================
@@ -358,10 +359,6 @@ PKIHELPER_USER_ADD_UID_KEYERROR_1 = "KeyError:  pki_uid %s"
 
 PKI_CONFIG_ADMIN_CERT_SAVE_2 = "saving %s Admin Certificate to file: %s"
 PKI_CONFIG_ADMIN_CERT_ATOB_1 = "converting %s Admin Certificate to binary:"
-PKI_CONFIG_CDATA_TAG = "tag:"
-PKI_CONFIG_CDATA_CERT = "cert:"
-PKI_CONFIG_CDATA_REQUEST = "request:"
-PKI_CONFIG_CONFIGURING_PKI_DATA = "configuring PKI configuration data."
 PKI_CONFIG_CONSTRUCTING_PKI_DATA = "constructing PKI configuration data."
 PKI_CONFIG_PKCS10_SUPPORT_ONLY = \
     "only the 'pkcs10' certificate request type is currently supported"
@@ -397,7 +394,6 @@ PKI_CONFIG_EXTERNAL_CSR_SAVE_PKI_SUBSYSTEM_2 = (
     "saving %s Subsystem CSR to file: %s")
 PKI_CONFIG_JAVA_CONFIGURATION_EXCEPTION = \
     "Exception from Java Configuration Servlet:"
-PKI_CONFIG_RESPONSE_ADMIN_CERT = "adminCert:"
 PKI_CONFIG_RESPONSE_STATUS = "status:"
 PKI_CONFIG_NOT_YET_IMPLEMENTED_1 = " %s NOT YET IMPLEMENTED"
 PKI_CHECK_STATUS_MESSAGE = '''
