@@ -82,7 +82,11 @@ class PKIConfigParser:
         (None, 'pki_ssl_server_subject_dn',
          None, 'pki_sslserver_subject_dn'),
         (None, 'pki_ssl_server_token',
-         None, 'pki_sslserver_token')
+         None, 'pki_sslserver_token'),
+        (None, 'pki_database_path',
+         None, 'pki_server_database_path'),
+        (None, 'pki_pin',
+         None, 'pki_server_database_password'),
     ]
 
     DEPRECATED_CA_PARAMS = [
@@ -268,7 +272,7 @@ class PKIConfigParser:
         default_https_port = '8443'
 
         application_version = str(pki.util.Version(
-            pki.implementation_version()))
+            pki.specification_version()))
 
         self.deployer.main_config = configparser.SafeConfigParser({
             'application_version': application_version,
@@ -423,6 +427,7 @@ class PKIConfigParser:
                     'pki_pin',
                     'pki_replication_password',
                     'pki_security_domain_password',
+                    'pki_server_database_password',
                     'pki_server_pkcs12_password',
                     'pki_token_password')
 
@@ -663,9 +668,8 @@ class PKIConfigParser:
         if not token:
             token = self.mdict.get('pki_token_name')
 
-        # normalize internal token name
-        if not pki.nssdb.normalize_token(token):
-            token = pki.nssdb.INTERNAL_TOKEN_FULL_NAME
+        # normalize token name
+        token = pki.nssdb.normalize_token(token)
 
         # update cert token
         self.mdict[name] = token
@@ -691,25 +695,6 @@ class PKIConfigParser:
 
             self.deployer.flatten_master_dict()
 
-            instance = pki.server.PKIInstance(self.mdict['pki_instance_name'])
-            instance.load()
-
-            internal_token = self.mdict['pki_self_signed_token']
-
-            # if instance already exists and has password, reuse the password
-            if internal_token in instance.passwords:
-                self.mdict['pki_pin'] = instance.passwords.get(internal_token)
-
-            # otherwise, use user-provided password if specified
-            elif 'pki_pin' in self.mdict:
-                pass
-
-            # otherwise, generate a random password
-            else:
-                self.mdict['pki_pin'] = pki.generate_password()
-
-            self.mdict['pki_client_pin'] = pki.generate_password()
-
             pkilogging.sensitive_parameters = \
                 self.mdict['sensitive_parameters'].split()
 
@@ -1039,7 +1024,7 @@ class PKIConfigParser:
                     "+TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA," + \
                     "-TLS_RSA_WITH_3DES_EDE_CBC_SHA," + \
                     "-TLS_RSA_WITH_AES_128_CBC_SHA," + \
-                    "+TLS_RSA_WITH_AES_256_CBC_SHA," + \
+                    "-TLS_RSA_WITH_AES_256_CBC_SHA," + \
                     "-TLS_ECDHE_ECDSA_WITH_3DES_EDE_CBC_SHA," + \
                     "+TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA," + \
                     "-TLS_ECDHE_RSA_WITH_3DES_EDE_CBC_SHA," + \
@@ -1055,13 +1040,15 @@ class PKIConfigParser:
                     "-TLS_DHE_RSA_WITH_AES_256_CBC_SHA256," + \
                     "-TLS_DHE_RSA_WITH_AES_128_GCM_SHA256," + \
                     "-TLS_RSA_WITH_AES_128_CBC_SHA256," + \
-                    "+TLS_RSA_WITH_AES_256_CBC_SHA256," + \
+                    "-TLS_RSA_WITH_AES_256_CBC_SHA256," + \
                     "-TLS_RSA_WITH_AES_128_GCM_SHA256," + \
                     "+TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256," + \
                     "+TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256," + \
                     "-TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA," + \
                     "-TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256," + \
-                    "-TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256"
+                    "-TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256," + \
+                    "+TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384," + \
+                    "+TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384"
             else:
                 self.mdict['TOMCAT_SSL_RANGE_CIPHERS_SLOT'] = \
                     "-TLS_ECDH_ECDSA_WITH_AES_128_CBC_SHA," + \
@@ -1090,12 +1077,16 @@ class PKIConfigParser:
                     "+TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256," + \
                     "-TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256," + \
                     "+TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256," + \
-                    "+TLS_RSA_WITH_AES_128_CBC_SHA256," + \
-                    "+TLS_RSA_WITH_AES_256_CBC_SHA256," + \
+                    "-TLS_RSA_WITH_AES_128_CBC_SHA256," + \
+                    "-TLS_RSA_WITH_AES_256_CBC_SHA256," + \
                     "-TLS_RSA_WITH_AES_128_GCM_SHA256," + \
                     "-TLS_RSA_WITH_3DES_EDE_CBC_SHA," + \
-                    "+TLS_RSA_WITH_AES_128_CBC_SHA," + \
-                    "+TLS_RSA_WITH_AES_256_CBC_SHA"
+                    "-TLS_RSA_WITH_AES_128_CBC_SHA," + \
+                    "-TLS_RSA_WITH_AES_256_CBC_SHA," + \
+                    "+TLS_DHE_RSA_WITH_AES_256_GCM_SHA384," + \
+                    "+TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384," + \
+                    "+TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384," + \
+                    "-TLS_RSA_WITH_AES_256_GCM_SHA384"
 
             if self.deployer.architecture == 64:
                 self.mdict['NUXWDOG_JNI_PATH_SLOT'] = (
@@ -1134,13 +1125,13 @@ class PKIConfigParser:
                     self.mdict['pki_instance_configuration_path'],
                     "password.conf")
             self.mdict['pki_cert_database'] = \
-                os.path.join(self.mdict['pki_database_path'],
+                os.path.join(self.mdict['pki_server_database_path'],
                              "cert8.db")
             self.mdict['pki_key_database'] = \
-                os.path.join(self.mdict['pki_database_path'],
+                os.path.join(self.mdict['pki_server_database_path'],
                              "key3.db")
             self.mdict['pki_secmod_database'] = \
-                os.path.join(self.mdict['pki_database_path'],
+                os.path.join(self.mdict['pki_server_database_path'],
                              "secmod.db")
             self.mdict['pki_self_signed_nickname'] = \
                 self.mdict['pki_sslserver_nickname']
@@ -1165,11 +1156,6 @@ class PKIConfigParser:
                     self.mdict['pki_subsystem_configuration_path'],
                     "password.conf")
 
-            if not len(self.mdict['pki_client_database_password']):
-                # use randomly generated client 'pin'
-                self.mdict['pki_client_database_password'] = \
-                    str(self.mdict['pki_client_pin'])
-
             # Configuration scriptlet
             # 'Security Domain' Configuration name/value pairs
             # 'Subsystem Name'  Configuration name/value pairs
@@ -1296,7 +1282,7 @@ class PKIConfigParser:
                 # NOTE:  ALWAYS store the PKCS #12 backup keys file
                 #        in with the NSS "server" security databases
                 self.mdict['pki_backup_keys_p12'] = \
-                    self.mdict['pki_database_path'] + "/" + \
+                    self.mdict['pki_server_database_path'] + "/" + \
                     self.mdict['pki_subsystem'].lower() + "_" + \
                     "backup" + "_" + "keys" + "." + "p12"
 
