@@ -20,6 +20,7 @@
 
 # System Imports
 from __future__ import absolute_import
+import logging
 import os
 
 # PKI Deployment Imports
@@ -27,6 +28,10 @@ from .. import pkiconfig as config
 from .. import pkimessages as log
 from .. import pkiscriptlet
 
+logger = logging.LoggerAdapter(
+    logging.getLogger('instance'),
+    extra={'indent': ''})
+
 
 # PKI Deployment Instance Layout Scriptlet
 class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
@@ -34,12 +39,10 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
     def spawn(self, deployer):
 
         if config.str2bool(deployer.mdict['pki_skip_installation']):
-            config.pki_log.info(log.SKIP_INSTANCE_SPAWN_1, __name__,
-                                extra=config.PKI_INDENTATION_LEVEL_1)
+            logger.info('Skipping instance creation')
             return
 
-        config.pki_log.info(log.INSTANCE_SPAWN_1, __name__,
-                            extra=config.PKI_INDENTATION_LEVEL_1)
+        logger.info('Creating instance')
 
         # if this is not the first subsystem, skip
         if len(deployer.instance.tomcat_instance_subsystems()) != 1:
@@ -166,13 +169,6 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
                     deployer.mdict['pki_instance_lib'],
                     name))
 
-        # Link /var/lib/pki/<instance>/lib/log4j.properties
-        # to /usr/share/pki/server/conf/log4j.properties.
-        deployer.symlink.create(
-            os.path.join(deployer.mdict['pki_source_server_path'],
-                         "log4j.properties"),
-            deployer.mdict['pki_instance_lib_log4j_properties'])
-
         # Link /var/lib/pki/<instance>/common to /usr/share/pki/server/common
         deployer.symlink.create(
             '/usr/share/pki/server/common',
@@ -212,10 +208,10 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         deployer.systemd.daemon_reload()
 
         # establish shared NSS security databases for this instance
-        deployer.directory.create(deployer.mdict['pki_database_path'])
+        deployer.directory.create(deployer.mdict['pki_server_database_path'])
         # establish instance convenience symbolic links
         deployer.symlink.create(
-            deployer.mdict['pki_database_path'],
+            deployer.mdict['pki_server_database_path'],
             deployer.mdict['pki_instance_database_link'])
         deployer.symlink.create(
             deployer.mdict['pki_instance_configuration_path'],
@@ -237,8 +233,7 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
     def destroy(self, deployer):
 
-        config.pki_log.info(log.INSTANCE_DESTROY_1, __name__,
-                            extra=config.PKI_INDENTATION_LEVEL_1)
+        logger.info('Removing instance')
 
         # if this is not the last subsystem, skip
         if len(deployer.instance.tomcat_instance_subsystems()) != 0:
@@ -256,10 +251,13 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
         # remove Tomcat instance base
         deployer.directory.delete(deployer.mdict['pki_instance_path'])
-        # remove Tomcat instance logs
-        deployer.directory.delete(deployer.mdict['pki_instance_log_path'])
+
+        # remove Tomcat instance logs only if --remove-logs is specified
+        if deployer.mdict['pki_remove_logs']:
+            deployer.directory.delete(deployer.mdict['pki_instance_log_path'])
+
         # remove shared NSS security database path for this instance
-        deployer.directory.delete(deployer.mdict['pki_database_path'])
+        deployer.directory.delete(deployer.mdict['pki_server_database_path'])
         # remove Tomcat instance configuration
         deployer.directory.delete(
             deployer.mdict['pki_instance_configuration_path'])
@@ -276,8 +274,7 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 # Don't copy the shared ldif files:
 # schema.ldif, manager.ldif, database.ldif
 def file_ignore_callback_src_server(src, names):
-    config.pki_log.info(log.FILE_EXCLUDE_CALLBACK_2, src, names,
-                        extra=config.PKI_INDENTATION_LEVEL_1)
+    logger.debug(log.FILE_EXCLUDE_CALLBACK_2, src, names)
 
     return {
         'catalina.properties',
@@ -286,7 +283,6 @@ def file_ignore_callback_src_server(src, names):
         'database.ldif',
         'manager.ldif',
         'pki.xml',
-        'log4j.properties',
         'logging.properties',
         'serverCertNick.conf'
     }
