@@ -102,6 +102,12 @@ def main(argv):
         action='store_true',
         help='skip installation step')
 
+    parser.optional.add_argument(
+        '--enforce-hostname',
+        dest='enforce_hostname',
+        action='store_true',
+        help='enforce strict hostname/FQDN checks')
+
     args = parser.process_command_line_arguments()
 
     config.default_deployment_cfg = \
@@ -113,6 +119,12 @@ def main(argv):
             args.user_deployment_cfg).strip('[\']')
 
     parser.validate()
+
+    # Currently the only logic in deployer's validation is the
+    # hostname check; at some point this might need to be updated.
+    if args.enforce_hostname:
+        deployer.validate()
+
     interactive = False
 
     if config.user_deployment_cfg is None:
@@ -733,7 +745,8 @@ def check_ds(parser):
                 sys.exit(1)
 
     except ldap.LDAPError as e:
-        print('ERROR:  Unable to access directory server: ' +
+        server = parser.protocol + '://' + parser.hostname + ':' + parser.port
+        print('ERROR:  Unable to access directory server (' + server + '): ' +
               e.args[0]['desc'])
         sys.exit(1)
 
@@ -751,9 +764,17 @@ def print_external_ca_step_one_information(mdict):
     print("      The %s subsystem of the '%s' instance is still incomplete." %
           (deployer.subsystem_name, mdict['pki_instance_name']))
     print()
-    print("      A CSR for the CA certificate has been generated at:\n"
-          "            %s"
-          % mdict['pki_ca_signing_csr_path'])
+    print("      NSS database: %s" % mdict['pki_server_database_path'])
+    print()
+
+    signing_csr = mdict['pki_ca_signing_csr_path']
+
+    if signing_csr:
+        print("      A CSR for the CA signing certificate has been generated in:")
+        print("            %s" % mdict['pki_ca_signing_csr_path'])
+    else:
+        print("      No CSR has been generated for CA signing certificate.")
+
     print(log.PKI_RUN_INSTALLATION_STEP_TWO)
     print(log.PKI_SPAWN_INFORMATION_FOOTER)
 
@@ -764,13 +785,35 @@ def print_kra_step_one_information(mdict):
     print("      The %s subsystem of the '%s' instance is still incomplete." %
           (deployer.subsystem_name, mdict['pki_instance_name']))
     print()
-    print("      The CSRs for KRA certificates have been generated in:")
-    print("          storage:       %s" % mdict['pki_storage_csr_path'])
-    print("          transport:     %s" % mdict['pki_transport_csr_path'])
-    print("          subsystem:     %s" % mdict['pki_subsystem_csr_path'])
-    print("          SSL server:    %s" % mdict['pki_sslserver_csr_path'])
-    print("          audit signing: %s" % mdict['pki_audit_signing_csr_path'])
-    print("          admin:         %s" % mdict['pki_admin_csr_path'])
+    print("      NSS database: %s" % mdict['pki_server_database_path'])
+    print()
+
+    storage_csr = mdict['pki_storage_csr_path']
+    transport_csr = mdict['pki_transport_csr_path']
+    subsystem_csr = mdict['pki_subsystem_csr_path']
+    sslserver_csr = mdict['pki_sslserver_csr_path']
+    audit_csr = mdict['pki_audit_signing_csr_path']
+    admin_csr = mdict['pki_admin_csr_path']
+
+    if storage_csr or transport_csr or subsystem_csr or sslserver_csr \
+            or audit_csr or admin_csr:
+        print("      The CSRs for KRA certificates have been generated in:")
+    else:
+        print("      No CSRs have been generated for KRA certificates.")
+
+    if storage_csr:
+        print("          storage:       %s" % storage_csr)
+    if transport_csr:
+        print("          transport:     %s" % transport_csr)
+    if subsystem_csr:
+        print("          subsystem:     %s" % subsystem_csr)
+    if sslserver_csr:
+        print("          SSL server:    %s" % sslserver_csr)
+    if audit_csr:
+        print("          audit signing: %s" % audit_csr)
+    if admin_csr:
+        print("          admin:         %s" % admin_csr)
+
     print(log.PKI_RUN_INSTALLATION_STEP_TWO)
     print(log.PKI_SPAWN_INFORMATION_FOOTER)
 
@@ -781,12 +824,31 @@ def print_ocsp_step_one_information(mdict):
     print("      The %s subsystem of the '%s' instance is still incomplete." %
           (deployer.subsystem_name, mdict['pki_instance_name']))
     print()
-    print("      The CSRs for OCSP certificates have been generated in:")
-    print("          OCSP signing:  %s" % mdict['pki_ocsp_signing_csr_path'])
-    print("          subsystem:     %s" % mdict['pki_subsystem_csr_path'])
-    print("          SSL server:    %s" % mdict['pki_sslserver_csr_path'])
-    print("          audit signing: %s" % mdict['pki_audit_signing_csr_path'])
-    print("          admin:         %s" % mdict['pki_admin_csr_path'])
+    print("      NSS database: %s" % mdict['pki_server_database_path'])
+    print()
+
+    signing_csr = mdict['pki_ocsp_signing_csr_path']
+    subsystem_csr = mdict['pki_subsystem_csr_path']
+    sslserver_csr = mdict['pki_sslserver_csr_path']
+    audit_csr = mdict['pki_audit_signing_csr_path']
+    admin_csr = mdict['pki_admin_csr_path']
+
+    if signing_csr or subsystem_csr or sslserver_csr or audit_csr or admin_csr:
+        print("      The CSRs for OCSP certificates have been generated in:")
+    else:
+        print("      No CSRs have been generated for OCSP certificates.")
+
+    if signing_csr:
+        print("          OCSP signing:  %s" % signing_csr)
+    if subsystem_csr:
+        print("          subsystem:     %s" % subsystem_csr)
+    if sslserver_csr:
+        print("          SSL server:    %s" % sslserver_csr)
+    if audit_csr:
+        print("          audit signing: %s" % audit_csr)
+    if admin_csr:
+        print("          admin:         %s" % admin_csr)
+
     print(log.PKI_RUN_INSTALLATION_STEP_TWO)
     print(log.PKI_SPAWN_INFORMATION_FOOTER)
 
