@@ -209,7 +209,8 @@ public class PKCS12Util {
     public void addKeyBag(PKCS12KeyInfo keyInfo, Password password,
             SEQUENCE encSafeContents) throws Exception {
 
-        logger.debug("Creating key bag for " + keyInfo.getFriendlyName());
+        byte[] keyID = keyInfo.getID();
+        logger.debug(" - Key ID: " + Hex.encodeHexString(keyID));
 
         ASN1Value content;
 
@@ -220,8 +221,6 @@ public class PKCS12Util {
             content = new ANY(epkiBytes);
 
         } else {
-            logger.debug("Encrypting private key for " + keyInfo.getFriendlyName());
-
             PrivateKey privateKey = keyInfo.getPrivateKey();
             if (privateKey == null) {
                 throw new Exception("Missing private key for " + keyInfo.getFriendlyName());
@@ -291,10 +290,12 @@ public class PKCS12Util {
     public void addCertBag(PKCS12CertInfo certInfo,
             SEQUENCE safeContents) throws Exception {
 
-        logger.debug("Creating cert bag for " + certInfo.getFriendlyName());
+        byte[] id = certInfo.getID();
+        logger.debug(" - Certificate ID: " + Hex.encodeHexString(id));
 
-        ASN1Value cert = new OCTET_STRING(certInfo.cert.getEncoded());
-        CertBag certBag = new CertBag(CertBag.X509_CERT_TYPE, cert);
+        X509CertImpl cert = certInfo.getCert();
+        ASN1Value certAsn1 = new OCTET_STRING(cert.getEncoded());
+        CertBag certBag = new CertBag(CertBag.X509_CERT_TYPE, certAsn1);
 
         SET certAttrs = createCertBagAttrs(certInfo);
 
@@ -306,20 +307,24 @@ public class PKCS12Util {
 
         SET attrs = new SET();
 
+        String friendlyName = keyInfo.getFriendlyName();
+        logger.debug("   Friendly name: " + friendlyName);
+
         SEQUENCE subjectAttr = new SEQUENCE();
         subjectAttr.addElement(SafeBag.FRIENDLY_NAME);
 
         SET subjectSet = new SET();
-        subjectSet.addElement(new BMPString(keyInfo.getFriendlyName()));
+        subjectSet.addElement(new BMPString(friendlyName));
         subjectAttr.addElement(subjectSet);
 
         attrs.addElement(subjectAttr);
 
+        byte[] keyID = keyInfo.getID();
         SEQUENCE localKeyAttr = new SEQUENCE();
         localKeyAttr.addElement(SafeBag.LOCAL_KEY_ID);
 
         SET localKeySet = new SET();
-        localKeySet.addElement(new OCTET_STRING(keyInfo.id));
+        localKeySet.addElement(new OCTET_STRING(keyID));
         localKeyAttr.addElement(localKeySet);
 
         attrs.addElement(localKeyAttr);
@@ -331,37 +336,46 @@ public class PKCS12Util {
 
         SET attrs = new SET();
 
+        String friendlyName = certInfo.getFriendlyName();
+        logger.debug("   Friendly name: " + friendlyName);
+
         SEQUENCE nicknameAttr = new SEQUENCE();
         nicknameAttr.addElement(SafeBag.FRIENDLY_NAME);
 
         SET nicknameSet = new SET();
-        nicknameSet.addElement(new BMPString(certInfo.getFriendlyName()));
+        nicknameSet.addElement(new BMPString(friendlyName));
         nicknameAttr.addElement(nicknameSet);
 
         attrs.addElement(nicknameAttr);
 
-        if (certInfo.getID() != null) {
-            SEQUENCE localKeyAttr = new SEQUENCE();
-            localKeyAttr.addElement(SafeBag.LOCAL_KEY_ID);
+        String trustFlags = certInfo.getTrustFlags();
+        if (trustFlags != null && trustFlagsEnabled) {
+            logger.debug("   Trust flags: " + trustFlags);
 
-            SET localKeySet = new SET();
-            localKeySet.addElement(new OCTET_STRING(certInfo.id));
-            localKeyAttr.addElement(localKeySet);
-
-            attrs.addElement(localKeyAttr);
-        }
-
-        if (certInfo.trustFlags != null && trustFlagsEnabled) {
             SEQUENCE trustFlagsAttr = new SEQUENCE();
             trustFlagsAttr.addElement(PKCS12.CERT_TRUST_FLAGS_OID);
 
             SET trustFlagsSet = new SET();
-            trustFlagsSet.addElement(new BMPString(certInfo.trustFlags));
+            trustFlagsSet.addElement(new BMPString(trustFlags));
             trustFlagsAttr.addElement(trustFlagsSet);
 
             attrs.addElement(trustFlagsAttr);
         }
 
+        byte[] keyID = certInfo.getKeyID();
+        if (keyID != null) {
+            logger.debug("   Key ID: " + Hex.encodeHexString(keyID));
+
+            SEQUENCE localKeyAttr = new SEQUENCE();
+            localKeyAttr.addElement(SafeBag.LOCAL_KEY_ID);
+
+            SET localKeySet = new SET();
+            localKeySet.addElement(new OCTET_STRING(keyID));
+            localKeyAttr.addElement(localKeySet);
+
+            attrs.addElement(localKeyAttr);
+        }
+
         return attrs;
     }
 
@@ -371,7 +385,7 @@ public class PKCS12Util {
 
     public void loadFromNSS(PKCS12 pkcs12, boolean includeKey, boolean includeChain) throws Exception {
 
-        logger.info("Loading all certificate and keys from NSS database");
+        logger.info("Loading certificates and keys from NSS database");
 
         CryptoManager cm = CryptoManager.getInstance();
         CryptoToken token = cm.getInternalKeyStorageToken();
@@ -429,96 +443,104 @@ public class PKCS12Util {
 
         CryptoManager cm = CryptoManager.getInstance();
 
-        byte[] id = SafeBag.getLocalKeyIDFromCert(cert.getEncoded());
-        logger.debug("ID: " + Hex.encodeHexString(id));
+        PKCS12CertInfo certInfo = createCertInfoFromNSS(cert, friendlyName);
+        pkcs12.addCertInfo(certInfo, true);
 
-        // load cert info
-        loadCertInfoFromNSS(pkcs12, cert, id, true, friendlyName);
+        byte[] id = certInfo.getID();
+        logger.debug(" - Certificate ID: " + Hex.encodeHexString(id));
+        logger.debug("   Friendly name: " + certInfo.getFriendlyName());
+        logger.debug("   Trust flags: " + certInfo.getTrustFlags());
 
         if (includeKey) {
             // load key info if exists
-            loadKeyInfoFromNSS(pkcs12, cert, id, friendlyName);
+
+            try {
+                PrivateKey privateKey = cm.findPrivKeyByCert(cert);
+
+                PKCS12KeyInfo keyInfo = createKeyInfoFromNSS(cert, privateKey, friendlyName);
+                pkcs12.addKeyInfo(keyInfo);
+
+                byte[] keyID = keyInfo.getID();
+                certInfo.setKeyID(keyID);
+                logger.debug("   Key ID: " + Hex.encodeHexString(keyID));
+
+            } catch (ObjectNotFoundException e) {
+                logger.debug("Certificate has no private key");
+            }
         }
 
         if (includeChain) {
             // load cert chain
             X509Certificate[] certChain = cm.buildCertificateChain(cert);
+            if (certChain.length > 1) {
+                logger.debug("   Certificate Chain:");
+            }
             for (int i = 1; i < certChain.length; i++) {
-                X509Certificate c = certChain[i];
-                byte[] cid = SafeBag.getLocalKeyIDFromCert(c.getEncoded());
-                loadCertInfoFromNSS(pkcs12, c, cid, false);
+                X509Certificate caCert = certChain[i];
+
+                PKCS12CertInfo caCertInfo = createCertInfoFromNSS(caCert);
+                pkcs12.addCertInfo(caCertInfo, false);
+
+                byte[] caCertID = caCertInfo.getID();
+                logger.debug("   - Certificate ID: " + Hex.encodeHexString(caCertID));
+                logger.debug("     Friendly name: " + caCertInfo.getFriendlyName());
+                logger.debug("     Trust flags: " + caCertInfo.getTrustFlags());
             }
         }
     }
 
-    public void loadCertInfoFromNSS(
-            PKCS12 pkcs12,
-            X509Certificate cert,
-            byte[] id,
-            boolean replace) throws Exception {
+    public PKCS12CertInfo createCertInfoFromNSS(
+            X509Certificate cert) throws Exception {
 
-        loadCertInfoFromNSS(pkcs12, cert, id, replace, null);
+        return createCertInfoFromNSS(cert, null);
     }
 
-    public void loadCertInfoFromNSS(
-            PKCS12 pkcs12,
+    public PKCS12CertInfo createCertInfoFromNSS(
             X509Certificate cert,
-            byte[] id,
-            boolean replace,
             String friendlyName) throws Exception {
 
-        String nickname = cert.getNickname();
-        logger.info("Loading certificate \"" + nickname + "\" from NSS database");
+        // generate cert ID from SHA-1 hash of cert data
+        byte[] id = SafeBag.getLocalKeyIDFromCert(cert.getEncoded());
 
         if (friendlyName == null) {
-            friendlyName = nickname;
+            friendlyName = cert.getNickname();
         }
 
+        X509CertImpl certImpl = new X509CertImpl(cert.getEncoded());
+        String trustFlags = getTrustFlags(cert);
+
         PKCS12CertInfo certInfo = new PKCS12CertInfo();
-        certInfo.id = id;
+        certInfo.setID(id);
         certInfo.setFriendlyName(friendlyName);
-        certInfo.cert = new X509CertImpl(cert.getEncoded());
-        certInfo.trustFlags = getTrustFlags(cert);
+        certInfo.setCert(certImpl);
+        certInfo.setTrustFlags(trustFlags);
 
-        pkcs12.addCertInfo(certInfo, replace);
+        return certInfo;
     }
 
-    public void loadKeyInfoFromNSS(
-            PKCS12 pkcs12,
+    public PKCS12KeyInfo createKeyInfoFromNSS(
             X509Certificate cert,
-            byte[] id) throws Exception {
+            PrivateKey privateKey) throws Exception {
 
-        loadKeyInfoFromNSS(pkcs12, cert, id, null);
+        return createKeyInfoFromNSS(cert, privateKey, null);
     }
 
-    public void loadKeyInfoFromNSS(
-            PKCS12 pkcs12,
+    public PKCS12KeyInfo createKeyInfoFromNSS(
             X509Certificate cert,
-            byte[] id,
+            PrivateKey privateKey,
             String friendlyName) throws Exception {
 
-        String nickname = cert.getNickname();
-        logger.info("Loading private key for certificate \"" + nickname + "\" from NSS database");
+        byte[] keyID = privateKey.getUniqueID();
 
         if (friendlyName == null) {
-            friendlyName = nickname;
+            friendlyName = cert.getNickname();
         }
 
-        CryptoManager cm = CryptoManager.getInstance();
+        PKCS12KeyInfo keyInfo = new PKCS12KeyInfo(privateKey);
+        keyInfo.setID(keyID);
+        keyInfo.setFriendlyName(friendlyName);
 
-        try {
-            PrivateKey privateKey = cm.findPrivKeyByCert(cert);
-            logger.debug("Certificate \"" + nickname + "\" has private key");
-
-            PKCS12KeyInfo keyInfo = new PKCS12KeyInfo(privateKey);
-            keyInfo.id = id;
-            keyInfo.setFriendlyName(friendlyName);
-
-            pkcs12.addKeyInfo(keyInfo);
-
-        } catch (ObjectNotFoundException e) {
-            logger.debug("Certificate \"" + nickname + "\" has no private key");
-        }
+        return keyInfo;
     }
 
     public PFX generatePFX(PKCS12 pkcs12, Password password) throws Exception {
@@ -582,7 +604,7 @@ public class PKCS12Util {
 
         PFX pfx = generatePFX(pkcs12, password);
 
-        logger.info("Storing data into PKCS #12 file");
+        logger.info("Storing PKCS #12 data into " + filename);
         ByteArrayOutputStream bos = new ByteArrayOutputStream();
         pfx.encode(bos);
         byte[] data = bos.toByteArray();
@@ -627,10 +649,13 @@ public class PKCS12Util {
                 ANY value = (ANY) values.elementAt(0);
 
                 ByteArrayInputStream bis = new ByteArrayInputStream(value.getEncoded());
-                OCTET_STRING keyID = (OCTET_STRING) new OCTET_STRING.Template().decode(bis);
+                OCTET_STRING keyIdAsn1 = (OCTET_STRING) new OCTET_STRING.Template().decode(bis);
 
-                keyInfo.id = keyID.toByteArray();
-                logger.debug("   ID: " + Hex.encodeHexString(keyInfo.id));
+                byte[] keyID = keyIdAsn1.toByteArray();
+                keyInfo.setID(keyID);
+
+            } else {
+                logger.warn("   " + oid + ": " + attr.getValues());
             }
         }
 
@@ -646,8 +671,15 @@ public class PKCS12Util {
         OCTET_STRING certStr = (OCTET_STRING) certBag.getInterpretedCert();
         byte[] x509cert = certStr.toByteArray();
 
-        certInfo.cert = new X509CertImpl(x509cert);
-        Principal subjectDN = certInfo.cert.getSubjectDN();
+        // generate cert ID from SHA-1 hash of cert data
+        byte[] id = SafeBag.getLocalKeyIDFromCert(x509cert);
+        certInfo.setID(id);
+        logger.debug("   Certificate ID: " + Hex.encodeHexString(id));
+
+        X509CertImpl cert = new X509CertImpl(x509cert);
+        certInfo.setCert(cert);
+
+        Principal subjectDN = cert.getSubjectDN();
         logger.debug("   Subject DN: " + subjectDN);
 
         SET bagAttrs = bag.getBagAttributes();
@@ -668,17 +700,17 @@ public class PKCS12Util {
                 certInfo.setFriendlyName(friendlyName.toString());
                 logger.debug("   Friendly name: " + certInfo.getFriendlyName());
 
-
             } else if (oid.equals(SafeBag.LOCAL_KEY_ID)) {
 
                 SET values = attr.getValues();
                 ANY value = (ANY) values.elementAt(0);
 
                 ByteArrayInputStream bis = new ByteArrayInputStream(value.getEncoded());
-                OCTET_STRING keyID = (OCTET_STRING) new OCTET_STRING.Template().decode(bis);
+                OCTET_STRING keyIdAsn1 = (OCTET_STRING) new OCTET_STRING.Template().decode(bis);
 
-                certInfo.id = keyID.toByteArray();
-                logger.debug("   ID: " + Hex.encodeHexString(certInfo.id));
+                byte[] keyID = keyIdAsn1.toByteArray();
+                certInfo.setKeyID(keyID);
+                logger.debug("   Key ID: " + Hex.encodeHexString(keyID));
 
             } else if (oid.equals(PKCS12.CERT_TRUST_FLAGS_OID) && trustFlagsEnabled) {
 
@@ -686,25 +718,24 @@ public class PKCS12Util {
                 ANY value = (ANY) values.elementAt(0);
 
                 ByteArrayInputStream is = new ByteArrayInputStream(value.getEncoded());
-                BMPString trustFlags = (BMPString) (new BMPString.Template()).decode(is);
+                BMPString trustFlagsAsn1 = (BMPString) (new BMPString.Template()).decode(is);
 
-                certInfo.trustFlags = trustFlags.toString();
-                logger.debug("   Trust flags: " + certInfo.trustFlags);
+                String trustFlags = trustFlagsAsn1.toString();
+                certInfo.setTrustFlags(trustFlags);
+                logger.debug("   Trust flags: " + trustFlags);
+
+            } else {
+                logger.warn("   " + oid + ": " + attr.getValues());
             }
         }
 
-        if (certInfo.id == null) {
-            logger.debug("   ID not specified, generating new ID");
-            certInfo.id = SafeBag.getLocalKeyIDFromCert(x509cert);
-            logger.debug("   ID: " + Hex.encodeHexString(certInfo.id));
-        }
-
         if (certInfo.getFriendlyName() == null) {
             logger.debug("   Generating new friendly name");
             DN dn = new DN(subjectDN.getName());
             String[] values = dn.explodeDN(true);
-            certInfo.setFriendlyName(StringUtils.join(values, " - "));
-            logger.debug("   Friendly name: " + certInfo.friendlyName);
+            String friendlyName = StringUtils.join(values, " - ");
+            certInfo.setFriendlyName(friendlyName);
+            logger.debug("   Friendly name: " + friendlyName);
         }
 
         return certInfo;
@@ -802,7 +833,8 @@ public class PKCS12Util {
             throws CertificateException {
 
         for (PKCS12CertInfo certInfo : pkcs12.getCertInfos()) {
-            Principal certSubjectDN = certInfo.cert.getSubjectDN();
+            X509CertImpl cert = certInfo.getCert();
+            Principal certSubjectDN = cert.getSubjectDN();
             if (LDAPDN.equals(certSubjectDN.toString(), subjectDN)) return certInfo;
         }
 
@@ -815,7 +847,7 @@ public class PKCS12Util {
             String nickname,
             PKCS12KeyInfo keyInfo) throws Exception {
 
-        PKCS12CertInfo certInfo = pkcs12.getCertInfoByID(keyInfo.getID());
+        PKCS12CertInfo certInfo = pkcs12.getCertInfoByKeyID(keyInfo.getID());
         if (certInfo == null) {
             logger.debug("Private key has no certificate, ignore");
             return;
@@ -825,7 +857,8 @@ public class PKCS12Util {
         CryptoToken token = cm.getInternalKeyStorageToken();
         PK11Store store = (PK11Store)token.getCryptoStore();
 
-        X509Certificate cert = cm.importCACertPackage(certInfo.cert.getEncoded());
+        X509CertImpl certImpl = certInfo.getCert();
+        X509Certificate cert = cm.importCACertPackage(certImpl.getEncoded());
 
         // get public key
         PublicKey publicKey = cert.getPublicKey();
@@ -870,9 +903,6 @@ public class PKCS12Util {
         CryptoToken ct = cm.getInternalKeyStorageToken();
         CryptoStore store = ct.getCryptoStore();
 
-        byte[] id = certInfo.getID();
-        PKCS12KeyInfo keyInfo = pkcs12.getKeyInfoByID(id);
-
         String nickname = certInfo.getFriendlyName();
         for (X509Certificate cert : cm.findCertsByNickname(nickname)) {
             if (!overwrite) {
@@ -881,23 +911,30 @@ public class PKCS12Util {
             store.deleteCert(cert);
         }
 
+        X509CertImpl certImpl = certInfo.getCert();
         X509Certificate cert;
-        if (keyInfo != null) { // cert has key
+
+        byte[] keyID = certInfo.getKeyID();
+
+        if (keyID != null) { // cert has key
             logger.debug("Importing private key for " + certInfo.getFriendlyName());
+            PKCS12KeyInfo keyInfo = pkcs12.getKeyInfoByID(keyID);
             importKey(pkcs12, password, certInfo.getFriendlyName(), keyInfo);
 
             logger.debug("Importing user certificate " + certInfo.getFriendlyName());
             cert = cm.importUserCACertPackage(
-                    certInfo.cert.getEncoded(), certInfo.getFriendlyName());
+                    certImpl.getEncoded(), certInfo.getFriendlyName());
 
         } else { // cert has no key
             logger.debug("Importing CA certificate " + certInfo.getFriendlyName());
             // Note: JSS does not preserve CA certificate nickname
-            cert = cm.importCACertPackage(certInfo.cert.getEncoded());
+            cert = cm.importCACertPackage(certImpl.getEncoded());
         }
 
-        if (certInfo.trustFlags != null && trustFlagsEnabled)
-            setTrustFlags(cert, certInfo.trustFlags);
+        String trustFlags = certInfo.getTrustFlags();
+        if (trustFlags != null && trustFlagsEnabled) {
+            setTrustFlags(cert, trustFlags);
+        }
     }
 
     public void storeCertIntoNSS(PKCS12 pkcs12, Password password, String nickname, boolean overwrite) throws Exception {
