@@ -16,6 +16,7 @@ if test -z "${BUILDUSER}" -o -z "${BUILDUSER_UID}" -o -z "${BUILDUSER_GID}"; the
 fi
 
 ## compose_pki_core_packages doesn't run as root, create a build user
+echo "Creating build user ..."
 groupadd --non-unique -g ${BUILDUSER_GID} ${BUILDUSER}
 useradd --non-unique -u ${BUILDUSER_UID} -g ${BUILDUSER_GID} ${BUILDUSER}
 
@@ -26,11 +27,23 @@ chown ${BUILDUSER}:${BUILDUSER} ${BUILDDIR}
 # [Errno 2] No such file or directory: '/var/cache/dnf/metadata_lock.pid'
 rm -f /var/cache/dnf/metadata_lock.pid
 dnf clean all
-dnf makecache || true
-dnf makecache
+dnf makecache || :
+
+echo "Installing basic development packages ..."
+dnf install -y \
+    dnf-plugins-core sudo wget 389-ds-base @buildsys-build @development-tools \
+    --best --allowerasing
+
+# This needs to be installed inorder to use setup-ds.pl (changed to `dscreate`)
+# Only required >=28
+if [[ `echo "$VERSION" | awk '{print $1}'` -ge 28 ]]
+then
+    echo "Installing 389-ds-base-legacy-tools"
+    dnf install -y 389-ds-base-legacy-tools
+fi
+
+# Enable pki related COPR repo
+dnf copr enable -y ${COPR_REPO}
 
 # update, container might be outdated
-dnf update -y
-
-# TODO: move this into container image
-# dnf install -y rpmlint
+dnf update -y --best --allowerasing
